@@ -1,6 +1,16 @@
 import os
 # Import exception handling here due to:
 # https://github.com/pyansys/PyAEDT/pull/243
+import sys
+
+is_ironpython = "IronPython" in sys.version or ".NETFramework" in sys.version
+_pythonver = sys.version_info[0]
+try:
+    import ScriptEnv
+    ScriptEnv.Initialize("Ansoft.ElectronicsDesktop")
+    inside_desktop = True
+except:
+    inside_desktop = False
 
 try:
     from .generic.general_methods import aedt_exception_handler, generate_unique_name, retry_ntimes
