@@ -1,7 +1,7 @@
 """
 This module contains the `analysis` class.
 
-It includes common classes for file management and messaging and all 
+It includes common classes for file management and messaging and all
 calls to AEDT modules like the modeler, mesh, postprocessing, and setup.
 """
 from __future__ import absolute_import
@@ -10,17 +10,21 @@ import itertools
 import threading
 import shutil
 import warnings
+from collections import OrderedDict
+
 from ..modeler.modeler_constants import CoordinateSystemPlane, CoordinateSystemAxis, GravityDirection, Plane
 from ..modules.SolveSetup import Setup
 from ..modules.SolutionType import SolutionType, SetupTypes
 from ..modules.SetupTemplates import SetupKeys
+from ..modules.Boundary import NativeComponentObject
 from ..modules.DesignXPloration import DOESetups, DXSetups, ParametericsSetups, SensitivitySetups, StatisticalSetups, OptimizationSetups
 from .Design import Design
 from ..modules.MaterialLib import Materials
 from ..generic.general_methods import aedt_exception_handler
 from ..desktop import _pythonver
+from .. import is_ironpython
 import sys
-if "IronPython" in sys.version or ".NETFramework" in sys.version:
+if is_ironpython:
     from ..modules.PostProcessor import PostProcessor
 else:
     from ..modules.AdvancedPostProcessing import PostProcessor
@@ -28,8 +32,8 @@ else:
 
 class Analysis(Design, object):
     """Contains all common analysis functions.
-    
-    It is automatically initialized by a call from an application, such as HFSS or Q3D. 
+
+    It is automatically initialized by a call from an application, such as HFSS or Q3D.
     See the application function for its parameter descriptions.
 
     Parameters
@@ -48,7 +52,7 @@ class Analysis(Design, object):
     specified_version: str
         Version of AEDT  to use.
     NG : bool
-        Whether to run AEDT in the non-graphical mode. 
+        Whether to run AEDT in the non-graphical mode.
     AlwaysNew : bool
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
@@ -56,8 +60,8 @@ class Analysis(Design, object):
     release_on_exit : bool
         Whether to release  AEDT on exit.
     student_version : bool
-        Whether to enable the student version of AEDT. 
-    
+        Whether to enable the student version of AEDT.
+
     """
 
     def __init__(self, application, projectname, designname, solution_type, setup_name,
@@ -81,12 +85,12 @@ class Analysis(Design, object):
         self.opti_designxplorer = DXSetups(self)
         self.opti_sensitivity = SensitivitySetups(self)
         self.opti_statistical = StatisticalSetups(self)
-
+        self.native_components = self._get_native_data()
 
     @property
     def materials(self):
         """Manages materials in the project.
-        
+
         Returns
         -------
         :class:`pyaedt.modules.MaterialLib.Materials`
@@ -98,7 +102,7 @@ class Analysis(Design, object):
     @property
     def Position(self):
         """Position of the object.
-        
+
         Returns
         -------
         type
@@ -107,11 +111,10 @@ class Analysis(Design, object):
         """
         return self.modeler.Position
 
-
     @property
     def available_variations(self):
         """Available variation object.
-        
+
         Returns
         -------
         :class:`pyaedt.application.Analysis.Analysis.AvailableVariations`
@@ -123,7 +126,7 @@ class Analysis(Design, object):
     @property
     def CoordinateSystemAxis(self):
         """Coordinate system axis constant.
-        
+
         Returns
         -------
         tuple
@@ -135,7 +138,7 @@ class Analysis(Design, object):
     @property
     def CoordinateSystemPlane(self):
         """Coordinate system plane constants.
-        
+
         Returns
         -------
         tuple
@@ -147,8 +150,8 @@ class Analysis(Design, object):
     @property
     def View(self):
         """Planes. (To check if redundant to CoordinateSystemPlane.)
-       
-        
+
+
         Returns
         -------
         tuple
@@ -160,7 +163,7 @@ class Analysis(Design, object):
     @property
     def GravityDirection(self):
         """Gravity direction. (To check if redundant.)
-        
+
         Returns
         -------
         tuple
@@ -172,7 +175,7 @@ class Analysis(Design, object):
     @property
     def modeler(self):
         """Modeler.
-        
+
         Returns
         -------
         :class:`pyaedt.modeler.Modeler.Modeler`
@@ -183,7 +186,7 @@ class Analysis(Design, object):
     @property
     def mesh(self):
         """Mesh.
-        
+
         Returns
         -------
         :class:`pyaedt.modules.Mesh.Mesh`
@@ -194,7 +197,7 @@ class Analysis(Design, object):
     @property
     def post(self):
         """PostProcessor.
-        
+
         Returns
         -------
         :class:`pyaedt.modules.PostProcessor.PostProcessor`
@@ -205,7 +208,7 @@ class Analysis(Design, object):
     @property
     def osolution(self):
         """Solution.
-        
+
         Returns
         -------
         AEDT object
@@ -222,7 +225,7 @@ class Analysis(Design, object):
     @property
     def analysis_setup(self):
         """Analysis setup.
-       
+
         Returns
         -------
         str
@@ -250,7 +253,7 @@ class Analysis(Design, object):
     @property
     def existing_analysis_sweeps(self):
         """Existing analysis sweeps.
-        
+
         Returns
         -------
         list
@@ -294,7 +297,7 @@ class Analysis(Design, object):
         Returns
         -------
         str
-            Name of the last adaptive sweep if a sweep is available or 
+            Name of the last adaptive sweep if a sweep is available or
             the name of the nominal adaptive sweep if present.
         """
 
@@ -306,7 +309,7 @@ class Analysis(Design, object):
     @property
     def existing_analysis_setups(self):
         """Existing analysis setups.
-               
+
         Returns
         -------
         list
@@ -319,7 +322,7 @@ class Analysis(Design, object):
     @property
     def output_variables(self):
         """Output variables.
-     
+
         Returns
         -------
         list
@@ -339,15 +342,12 @@ class Analysis(Design, object):
             List of names of all analysis setups in the design.
 
         """
-        setups = self.oanalysis.GetSetups()
-
-        return setups
-
+        return self.oanalysis.GetSetups()
 
     @property
     def ooptimetrics(self):
-        """Optimetrics. 
-        
+        """Optimetrics.
+
         Returns
         -------
         AEDT object
@@ -358,8 +358,8 @@ class Analysis(Design, object):
 
     @property
     def ooutput_variable(self):
-        """Output variable
-        
+        """Output variable.
+
         Returns
         -------
         AEDT object
@@ -371,7 +371,7 @@ class Analysis(Design, object):
     @property
     def SimulationSetupTypes(self):
         """Simulation setup types.
-        
+
         Returns
         -------
         list
@@ -379,11 +379,10 @@ class Analysis(Design, object):
         """
         return SetupTypes()
 
-
     @property
     def SolutionTypes(self):
         """Solution types.
-        
+
         Returns
         -------
         list
@@ -391,6 +390,29 @@ class Analysis(Design, object):
         """
         return SolutionType()
 
+    @aedt_exception_handler
+    def _get_native_data(self):
+        """Retrieve Native Components data."""
+        boundaries = []
+        try:
+            data_vals = self.design_properties['ModelSetup']["GeometryCore"][
+                'GeometryOperations']['SubModelDefinitions']['NativeComponentDefinition']
+            if not isinstance(data_vals, list) and  type(data_vals) is OrderedDict:
+                boundaries.append(
+                    NativeComponentObject(self, data_vals['NativeComponentDefinitionProvider']['Type'],
+                                          data_vals['BasicComponentInfo']['ComponentName'],
+                                          data_vals))
+            for ds in data_vals:
+                try:
+                    if type(ds) is OrderedDict:
+                        boundaries.append(NativeComponentObject(self, ds['NativeComponentDefinitionProvider']['Type'],
+                                                        ds['BasicComponentInfo']['ComponentName'],
+                                                        ds))
+                except:
+                    pass
+        except:
+            pass
+        return boundaries
 
     class AvailableVariations(object):
 
@@ -413,7 +435,7 @@ class Analysis(Design, object):
         @property
         def variables(self):
             """Variables.
-            
+
             Returns
             -------
             list
@@ -501,8 +523,6 @@ class Analysis(Design, object):
                 families.append(["All"])
             return families
 
-
-
     class AxisDir(object):
         """Contains constants for the axis directions.
         """
@@ -524,7 +544,7 @@ class Analysis(Design, object):
     @aedt_exception_handler
     def get_nominal_variation(self):
         """Retrieve the nominal variation.
-        
+
         Returns
         -------
         list
@@ -540,17 +560,14 @@ class Analysis(Design, object):
         ----------
         name : str
             Name of the setup.
-            
+
         Returns
         -------
         list
             List of names of all sweeps for the setup.
 
         """
-        sweeps=[]
-
         sweeps = self.oanalysis.GetSweeps(name)
-
         return list(sweeps)
 
     @aedt_exception_handler
@@ -564,7 +581,7 @@ class Analysis(Design, object):
         filename : str
             Full path and name for the CSV file.
         exportunits : bool, optional
-            Whether to export units with the value. The default is ``True``. When ``False``, 
+            Whether to export units with the value. The default is ``True``. When ``False``,
             only the value is exported.
 
         Returns
@@ -576,11 +593,10 @@ class Analysis(Design, object):
         self.ooptimetrics.ExportParametricResults(sweepname, filename, exportunits)
         return True
 
-
     @aedt_exception_handler
     def analyze_from_initial_mesh(self):
         """Revert the solution to the initial mesh and re-run the solve.
-                
+
         Returns
         -------
         bool
@@ -590,11 +606,10 @@ class Analysis(Design, object):
         self.analyze_nominal()
         return True
 
-
     @aedt_exception_handler
     def analyse_nominal(self):
         """Revert the solution to the initial mesh and re-run the solve.
-       
+
         .. deprecated:: 0.4.0
            Use :func:`Analysis.analyze_nominal` instead.
         """
@@ -602,11 +617,10 @@ class Analysis(Design, object):
                       DeprecationWarning)
         self.analyze_nominal()
 
-
     @aedt_exception_handler
     def analyze_nominal(self):
         """Revert the solution to the initial mesh and re-run the solve.
-       
+
         Returns
         -------
         bool
@@ -615,21 +629,20 @@ class Analysis(Design, object):
         self.odesign.Analyze(self.analysis_setup)
         return True
 
-
     @aedt_exception_handler
     def generate_unique_setup_name(self, setup_name=None):
         """Generate a new setup with an unique name.
-        
+
         Parameters
         ----------
         setup_name : str, optional
             Name of the setup. The default is ``None``.
- 
+
         Returns
         -------
         str
             Name of the setup.
-        
+
         """
         if not setup_name:
             setup_name = "Setup"
@@ -648,15 +661,37 @@ class Analysis(Design, object):
         setupname : str, optional
             Name of the setup. The default is ``"MySetupAuto"``.
         setuptype : optional
-            Type of the setup. The default is ``None``, in which case 
+            Type of the setup. The default is ``None``, in which case
             the default type is applied.
         props : dict, optional
-            Dictionary of properties with values. The default is ``{}``.
+            Dictionary of analysis properties appropriate for the design and analysis.
+            If no values are passed, default values will be used.
 
         Returns
         -------
         :class:`pyaedt.modules.SolveSetup.Setup`
 
+        Examples
+        --------
+        Create a setup for SBR+ setup using advanced Doppler
+        processing for automotive radar.
+
+        >>> import pyaedt
+        >>> hfss = pyaedt.Hfss(solution_type='SBR+')
+        >>> setup1 = hfss.create_setup(setupname='Setup1')
+        >>> setup1.props["IsSbrRangeDoppler"] = True
+        >>> setup1.props["SbrRangeDopplerTimeVariable"] = "time_var"
+        >>> setup1.props["SbrRangeDopplerCenterFreq"] = "76.5GHz"
+        >>> setup1.props["SbrRangeDopplerRangeResolution"] = "0.15meter"
+        >>> setup1.props["SbrRangeDopplerRangePeriod"] = "100meter"
+        >>> setup1.props["SbrRangeDopplerVelocityResolution"] = "0.2m_per_sec"
+        >>> setup1.props["SbrRangeDopplerVelocityMin"] = "-30m_per_sec"
+        >>> setup1.props["SbrRangeDopplerVelocityMax"] = "30m_per_sec"
+        >>> setup1.props["DopplerRayDensityPerWavelength"] = "0.2"
+        >>> setup1.props["MaxNumberOfBounces"] = "3"
+        >>> setup1.update()
+        ...
+        pyaedt Info: Sweep was created correctly.
         """
         if setuptype is None:
             if self.design_type == "Icepak" and self.solution_type=="Transient":
@@ -670,6 +705,7 @@ class Analysis(Design, object):
             for el in props:
                 setup.props[el] = props[el]
             setup.update()
+
         self.analysis_setup = name
         self.setups.append(setup)
         return setup
@@ -682,13 +718,13 @@ class Analysis(Design, object):
         ----------
         setupname : str
             Name of the setup.
-        properties_dict : dict 
+        properties_dict : dict
             Dictionary containing the property to update with the value.
 
         Returns
         -------
         :class:`pyaedt.modules.SolveSetup.Setup`
-        
+
         """
         setuptype = SetupKeys.defaultSetups[self.solution_type]
         setup = Setup(self, setuptype, setupname, isnewsetup=False)
@@ -696,7 +732,6 @@ class Analysis(Design, object):
         self.analysis_setup = setupname
         return setup
 
-
     @aedt_exception_handler
     def get_setup(self, setupname):
         """Get the setup from the current design.
@@ -736,9 +771,11 @@ class Analysis(Design, object):
         """
         oModule = self.odesign.GetModule("OutputVariable")
         if variable in self.output_variables:
-            oModule.EditOutputVariable(variable, expression, variable, self.existing_analysis_sweeps[0], self.solution_type, [])
+            oModule.EditOutputVariable(variable, expression, variable,
+                                       self.existing_analysis_sweeps[0], self.solution_type, [])
         else:
-            oModule.CreateOutputVariable(variable, expression, self.existing_analysis_sweeps[0], self.solution_type, [])
+            oModule.CreateOutputVariable(
+                variable, expression, self.existing_analysis_sweeps[0], self.solution_type, [])
         return True
 
     @aedt_exception_handler
@@ -760,26 +797,28 @@ class Analysis(Design, object):
             Value of the output variable.
         """
         oModule = self.odesign.GetModule("OutputVariable")
-        assert variable in self.output_variables, "Output variable {} does not exist.".format(variable)
+        assert variable in self.output_variables, "Output variable {} does not exist.".format(
+            variable)
         nominal_variation = self.odesign.GetNominalVariation()
         sol_type = self.solution_type
-        value = oModule.GetOutputVariableValue(variable, nominal_variation, self.existing_analysis_sweeps[0], self.solution_type, [])
+        value = oModule.GetOutputVariableValue(
+            variable, nominal_variation, self.existing_analysis_sweeps[0], self.solution_type, [])
         return value
 
     @aedt_exception_handler
     def get_object_material_properties(self, object_list=None, prop_names=None):
         """Retrieve the material properties for a list of given objects and return them in a dictionary.
-        
+
         This high-level function ignores objects with no defined material properties.
 
         Parameters
         ----------
         object_list : list, optional
-            List of objects for which to get material_properties. The default is ``None``,  
-            in which case all objects are considered. 
+            List of objects for which to get material_properties. The default is ``None``,
+            in which case all objects are considered.
         prop_names : str or list
-            The property or list of properties to export.  The default is ``None``, in  
-            which case all properties are exported. 
+            The property or list of properties to export.  The default is ``None``, in
+            which case all properties are exported.
 
         Returns
         -------
@@ -808,7 +847,6 @@ class Analysis(Design, object):
                     dict[entry][prop_name] = mat_props._props[prop_name]
         return dict
 
-
     @aedt_exception_handler
     def analyze_setup(self, name):
         """Analyze a specific design setup.
@@ -837,21 +875,21 @@ class Analysis(Design, object):
 
     @aedt_exception_handler
     def solve_in_batch(self, filename=None, machine="local", run_in_thread=False):
-        """Analyze a design setup in batch mode. 
-        
+        """Analyze a design setup in batch mode.
+
         .. note::
            To use this function, the AEDT project must be closed.
 
         Parameters
         ----------
         filename : str, optional
-            Name of the setup. The default is ``None``, which means that the active project 
+            Name of the setup. The default is ``None``, which means that the active project
             is to be solved.
         machine : str, optional
-            Name of the machine if remote.  The default is ``"local"``. 
+            Name of the machine if remote.  The default is ``"local"``.
         run_in_thread : bool, optional
             Whether the batch command is to be submitted as a thread. The default is
-            ``False``. 
+            ``False``.
 
         Returns
         -------
@@ -893,7 +931,6 @@ class Analysis(Design, object):
         print("Batch Job finished")
         return True
 
-
     @aedt_exception_handler
     def submit_job(self, clustername, aedt_full_exe_path=None, numnodes=1, numcores=32, wait_for_license=True, setting_file=None):
         """Submit a job to be solved on a cluster.
@@ -903,7 +940,7 @@ class Analysis(Design, object):
         clustername : str
             Name of the cluster to submit the job to.
         aedt_full_exe_path : str, optional
-            Full path to the AEDT executable file. The default is ``None``, in which 
+            Full path to the AEDT executable file. The default is ``None``, in which
             case ``"/clustername/AnsysEM/AnsysEM2x.x/Win64/ansysedt.exe"`` is used.
         numnodes : int, optional
             Number of nodes. The default is ``1``.
@@ -913,7 +950,7 @@ class Analysis(Design, object):
              Whether to wait for the license to be validated. The default is ``True``.
         setting_file : str, optional
             Name of the file to use as a template. The default value is ``None``.
-        
+
         Returns
         -------
         type
@@ -925,15 +962,19 @@ class Analysis(Design, object):
         if not aedt_full_exe_path:
             version = self.odesktop.GetVersion()[2:6]
             if os.path.exists(r"\\"+clustername+r"\AnsysEM\AnsysEM{}\Win64\ansysedt.exe".format(version)):
-                aedt_full_exe_path = r"\\\\\\\\"+clustername+r"\\\\AnsysEM\\\\AnsysEM{}\\\\Win64\\\\ansysedt.exe".format(version)
+                aedt_full_exe_path = r"\\\\\\\\"+clustername+ \
+                    r"\\\\AnsysEM\\\\AnsysEM{}\\\\Win64\\\\ansysedt.exe".format(version)
             elif os.path.exists(r"\\"+clustername+r"\AnsysEM\AnsysEM{}\Linux64\ansysedt".format(version)):
-                aedt_full_exe_path = r"\\\\\\\\"+clustername+r"\\\\AnsysEM\\\\AnsysEM{}\\\\Linux64\\\\ansysedt".format(version)
+                aedt_full_exe_path = r"\\\\\\\\"+clustername+ \
+                    r"\\\\AnsysEM\\\\AnsysEM{}\\\\Linux64\\\\ansysedt".format(version)
             else:
-                self._messenger.add_error_message("Aedt Path doesn't exists. Please provide a full path")
+                self._messenger.add_error_message(
+                    "Aedt Path doesn't exists. Please provide a full path")
                 return False
         else:
             if not os.path.exists(aedt_full_exe_path):
-                self._messenger.add_error_message("Aedt Path doesn't exists. Please provide a full path")
+                self._messenger.add_error_message(
+                    "Aedt Path doesn't exists. Please provide a full path")
                 return False
             aedt_full_exe_path.replace("\\", "\\\\")
 
