@@ -21,10 +21,10 @@ class FieldAnalysis3D(Analysis, object):
     projectname : str, optional
         Name of the project to select or the full path to the project
         or AEDTZ archive to open. The default is ``None``, in which
-        case an attempt is made to get an active project. If no 
+        case an attempt is made to get an active project. If no
         projects are present, an empty project is created.
     designname : str, optional
-        Name of the design to select. The default is ``None``, in 
+        Name of the design to select. The default is ``None``, in
         which case an attempt is made to get an active design. If no
         designs are present, an empty design is created.
     solution_type : str, optional
@@ -32,14 +32,14 @@ class FieldAnalysis3D(Analysis, object):
         ``None``, in which case the default type is applied.
     setup_name : str, optional
         Name of the setup to use as the nominal. The default is
-        ``None``, in which case the active setup is used or 
+        ``None``, in which case the active setup is used or
         nothing is used.
     specified_version: str, optional
         Version of AEDT  to use. The default is ``None``, in which case
         the active version or latest installed version is used.
     NG : bool, optional
-        Whether to run AEDT in the non-graphical mode. The default 
-        is ``False``, in which case AEDT is launched in the graphical mode.  
+        Whether to run AEDT in the non-graphical mode. The default
+        is ``False``, in which case AEDT is launched in the graphical mode.
     AlwaysNew : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
@@ -47,10 +47,11 @@ class FieldAnalysis3D(Analysis, object):
     release_on_exit : bool, optional
         Whether to release  AEDT on exit. The default is ``False``.
     student_version : bool, optional
-        Whether to enable the student version of AEDT. The default 
+        Whether to enable the student version of AEDT. The default
         is ``False``.
-   
+
     """
+
     def __init__(self, application, projectname, designname, solution_type, setup_name=None,
                  specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
         Analysis.__init__(self, application, projectname, designname, solution_type, setup_name,
@@ -58,15 +59,13 @@ class FieldAnalysis3D(Analysis, object):
         self._modeler = Modeler3D(self)
         self._mesh = Mesh(self)
 
-
-
     @property
     def modeler(self):
         """Modeler.
 
         Returns
         -------
-        :class:`modeler.Model3D.Modeler3D`
+        :class:`pyaedt.modeler.Model3D.Modeler3D`
         """
         return self._modeler
 
@@ -117,12 +116,12 @@ class FieldAnalysis3D(Analysis, object):
 
     @aedt_exception_handler
     def get_components3d_vars(self, component3dname):
-        """Read the A3DCOMP file and check for variables. 
+        """Read the A3DCOMP file and check for variables.
 
         Parameters
         ----------
         component3dname :
-            Name of the 3D component, which must be in the ``syslib`` or ``userlib`` directory. Otherwise, 
+            Name of the 3D component, which must be in the ``syslib`` or ``userlib`` directory. Otherwise,
             you must specify the full absolute path to the AEDCOMP file with the file name and the extension.
 
         Returns
@@ -134,20 +133,32 @@ class FieldAnalysis3D(Analysis, object):
         vars = {}
         if component3dname not in self.components3d:
             if os.path.exists(component3dname):
-                with open(component3dname, 'r', errors='ignore') as f:
-                    lines = f.readlines()
-                    for line in lines:
-                        if "VariableProp(" in line:
-                            line_list = line.split("'")
-                            vars[line_list[1]] = line_list[len(line_list) - 2]
+                with open(component3dname, 'rb') as aedt_fh:
+                    temp = aedt_fh.read().splitlines()
+                _all_lines = []
+                for line in temp:
+                    try:
+                        _all_lines.append(line.decode("utf-8").lstrip('\t'))
+                    except UnicodeDecodeError:
+                        break
+                for line in _all_lines:
+                    if "VariableProp(" in line:
+                        line_list = line.split("'")
+                        vars[line_list[1]] = line_list[len(line_list) - 2]
                 return vars
             return False
-        with open(self.components3d[component3dname], 'r') as f:
-            lines = f.readlines()
-            for line in lines:
-                if "VariableProp(" in line:
-                    line_list = line.split("'")
-                    vars[line_list[1]] = line_list[len(line_list) - 2]
+        with open(self.components3d[component3dname], 'rb') as aedt_fh:
+            temp = aedt_fh.read().splitlines()
+        _all_lines = []
+        for line in temp:
+            try:
+                _all_lines.append(line.decode("utf-8").lstrip('\t'))
+            except UnicodeDecodeError:
+                break
+        for line in _all_lines:
+            if "VariableProp(" in line:
+                line_list = line.split("'")
+                vars[line_list[1]] = line_list[len(line_list) - 2]
         return vars
 
     @aedt_exception_handler
@@ -161,8 +172,8 @@ class FieldAnalysis3D(Analysis, object):
         property : str
             Name of the property,
         type : str, optional
-            Type of the property. Options are ``"boundary"``, ``"excitation"``, 
-            ``"setup",`` and ``"mesh"``. The default is ``None``.    
+            Type of the property. Options are ``"boundary"``, ``"excitation"``,
+            ``"setup",`` and ``"mesh"``. The default is ``None``.
 
         Returns
         -------
@@ -200,7 +211,8 @@ class FieldAnalysis3D(Analysis, object):
             for propserv in propservs:
                 properties = list(self.odesign.GetProperties(propserv, objectname))
                 if property in properties:
-                    val = retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
+                    val = retry_ntimes(10, self.odesign.GetPropertyValue,
+                                       propserv, objectname, property)
                     return val
         return None
 
@@ -216,20 +228,20 @@ class FieldAnalysis3D(Analysis, object):
         object_list : list, optional
             List of objects to copy. The default is ``None``.
         no_vacuum : bool, optional
-            Whether to include vacuum objects for the copied objects. 
+            Whether to include vacuum objects for the copied objects.
             The default is ``True``.
         no_pec :
-            Whether to include pec objects for the copied objects. The 
+            Whether to include pec objects for the copied objects. The
             default is ``True``.
         include_sheets :
-            Whether to include sheets for the copied objects. The 
+            Whether to include sheets for the copied objects. The
             default is ``False``.
 
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         body_list = design.modeler.primitives.solid_names
         if include_sheets:
@@ -280,7 +292,7 @@ class FieldAnalysis3D(Analysis, object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
 
         contexts = []
@@ -385,7 +397,7 @@ class FieldAnalysis3D(Analysis, object):
     @aedt_exception_handler
     def get_all_conductors_names(self):
         """Retrieve all conductors in the active design.
-                
+
         Returns
         -------
         list
@@ -404,7 +416,7 @@ class FieldAnalysis3D(Analysis, object):
     @aedt_exception_handler
     def get_all_dielectrics_names(self):
         """Retrieve all dielectrics in the active design.
-              
+
         Returns
         -------
         List
