@@ -4,13 +4,13 @@ from .Design import solutions_settings
 from ..modeler.Circuit import ModelerNexxim
 from ..modules.SetupTemplates import SetupKeys
 from ..modules.SolveSetup import SetupCircuit
-
+from ..modules.PostProcessor import CircuitPostProcessor
 
 class FieldAnalysisCircuit(Analysis):
     """FieldCircuitAnalysis class.
-    
+
     This class is for circuit analysis setup in Nexxim.
-    
+
     It is automatically initialized by a call from an application,
     such as HFSS or Q3D. See the application function for its
     parameter definitions.
@@ -19,25 +19,34 @@ class FieldAnalysisCircuit(Analysis):
     ----------
 
     """
+
+    def __init__(self, application, projectname, designname, solution_type, setup_name=None,
+                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
+        self.solution_type = solution_type
+        Analysis.__init__(self, application, projectname, designname, solution_type, setup_name,
+                          specified_version, NG, AlwaysNew, release_on_exit, student_version)
+        self._modeler = ModelerNexxim(self)
+        self._modeler.primitives.init_padstacks()
+        self._post = CircuitPostProcessor(self)
+
     @property
-    def solution_type(self):
-        """Solution type. """
-        return self._solution_type
-
-
-    @solution_type.setter
-    def solution_type(self, soltype):
-        """
-
-        Parameters
-        ----------
-        soltype : 
-            SolutionType object
+    def post(self):
+        """PostProcessor.
 
         Returns
         -------
-
+        :class:`pyaedt.modules.PostProcessor.CircuitPostProcessor`
+            PostProcessor object.
         """
+        return self._post
+
+    @property
+    def solution_type(self):
+        """Solution type."""
+        return self._solution_type
+
+    @solution_type.setter
+    def solution_type(self, soltype):
         if soltype:
             self._solution_type = solutions_settings[soltype]
         else:
@@ -58,15 +67,6 @@ class FieldAnalysisCircuit(Analysis):
         else:
             return ""
 
-    def __init__(self, application, projectname, designname, solution_type, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
-        self.solution_type = solution_type
-        Analysis.__init__(self, application, projectname, designname, solution_type, setup_name,
-                          specified_version, NG, AlwaysNew, release_on_exit, student_version)
-        self._modeler = ModelerNexxim(self)
-        self._modeler.primitives.init_padstacks()
-        #self._post = PostProcessor(self)
-
     @property
     def modeler(self):
         """Modeler object."""
@@ -85,33 +85,33 @@ class FieldAnalysisCircuit(Analysis):
     @property
     def get_excitations_name(self):
         """Excitation names.
-        
+
         Returns
         -------
         type
             BoundarySetup Module object
-        
+
         """
         ports = [p.replace('IPort@', '').split(';')[0] for p in self.modeler.oeditor.GetAllPorts()]
         return ports
 
     @property
     def get_all_sparameter_list(self, excitation_names=[]):
-        """List of all S parameters for a list of exctitations. 
+        """List of all S parameters for a list of exctitations.
 
         Parameters
         ----------
         eexcitation_names : list, optional
             List of excitations. The default is ``[]``, in which case
-            the S parameters for all excitations are to be provided. 
+            the S parameters for all excitations are to be provided.
             For example, ``["1", "2"]``.
-            
+
         Returns
         -------
         list
             List of strings representing the S parameters of the excitations.
             For example, ``"S(1,1)", "S(1,2)", "S(2,2)"``.
-            
+
 
         """
         if not excitation_names:
@@ -136,8 +136,8 @@ class FieldAnalysisCircuit(Analysis):
             the return losses for all excitations are to be provided.
             For example ``["1", "2"]``.
         excitation_name_prefix : string, optional
-             Prefix to add to the excitation names. The default is ``""``, 
-             
+             Prefix to add to the excitation names. The default is ``""``,
+
         Returns
         -------
         list
@@ -148,7 +148,8 @@ class FieldAnalysisCircuit(Analysis):
         if not excitation_names:
             excitation_names = self.get_excitations_name
         if excitation_name_prefix:
-            excitation_names = [i for i in excitation_names if excitation_name_prefix.lower() in i.lower()]
+            excitation_names = [
+                i for i in excitation_names if excitation_name_prefix.lower() in i.lower()]
         spar = []
         for i in excitation_names:
             spar.append("S({},{})".format(i, i))
@@ -157,25 +158,25 @@ class FieldAnalysisCircuit(Analysis):
     @aedt_exception_handler
     def get_all_insertion_loss_list(self, trlist=[], reclist=[], tx_prefix='', rx_prefix=''):
         """Retrieve a list of all insertion losses from two lists of excitations (driver and receiver).
-       
+
         Parameters
         ----------
         trlist : list, optional
             List of drivers. The default is ``[]``. For example, ``["1"]``.
         reclist : list, optional
-            List of receivers. The default is ``[]``. The number of drivers equals 
+            List of receivers. The default is ``[]``. The number of drivers equals
             the number of receivers. For example, ``["2"]``.
         tx_prefix : str, optional
             Prefix to add to driver names. For example, ``"DIE"``. The default is ``""``.
         rx_prefix : str, optional
             Prefix to add to receiver names. For example, ``"BGA"``. The default is ``""``.
-        
+
         Returns
         -------
         list
             List of strings representing insertion losses of the excitations.
             For example, ``["S(1,2)"]``.
-        
+
         """
         spar = []
         if not trlist:
@@ -192,7 +193,7 @@ class FieldAnalysisCircuit(Analysis):
     @aedt_exception_handler
     def get_next_xtalk_list(self, trlist=[], tx_prefix=""):
         """Retrieve a list of all the near end XTalks from a list of excitations (driver and receiver).
-        
+
         Parameters
         ----------
         trlist : list, optional
@@ -221,7 +222,7 @@ class FieldAnalysisCircuit(Analysis):
     @aedt_exception_handler
     def get_fext_xtalk_list(self, trlist=[], reclist=[], tx_prefix='', rx_prefix='', skip_same_index_couples=True):
         """Retrieve a list of all the far end XTalks from two lists of exctitations (driver and receiver).
-        
+
         Parameters
         ----------
         trlist : list, optional
@@ -236,16 +237,16 @@ class FieldAnalysisCircuit(Analysis):
             Prefix for receiver names. For examples, ``"BGA"`` The default is ``""``.
         skip_same_index_couples : bool, optional
             Whether to skip driver and receiver couples with the same index position.
-            The default is ``True``, in which case the drivers and receivers 
-            with the same index position are considered insertion losses and 
+            The default is ``True``, in which case the drivers and receivers
+            with the same index position are considered insertion losses and
             excluded from the list.
-        
+
         Returns
         -------
         list
             List of strings representing the far end XTalks of the excitations.
             For example, ``["S(1, 4)", "S(2, 3)"]``.
-            
+
         """
         fext = []
         if not trlist:
@@ -313,7 +314,6 @@ class FieldAnalysisCircuit(Analysis):
         self.setups.append(setup)
         return setup
 
-
     # @property
     # def mesh(self):
     #     return self._mesh
