@@ -5,12 +5,15 @@ def get_hpc_info(filename):
     Parameters
     ----------
     filename : str
-        Name of the file.   
+        Name of the file.
 
     Returns
     -------
-    type
-        
+    config_name : str
+        Config name.
+    design_type : str
+        Design name.
+
     """
     config_name = ''
     design_type = ''
@@ -21,7 +24,6 @@ def get_hpc_info(filename):
             elif 'DesignType=' in line:
                 design_type = line.strip().replace('DesignType=', '').replace("'", '')
     return config_name, design_type
-    pass
 
 
 def update_hpc_option(self, filnename, propertyname, propertyvalue,
@@ -34,10 +36,10 @@ def update_hpc_option(self, filnename, propertyname, propertyvalue,
         Full path and name of the configuration file. The file type can be ACF or TXT.
     propertyname : str
         Name of the property to update.
-    propertyvalue : 
+    propertyvalue :
         Value for the property.
     isvaluestring : bool, optional
-        Whether the value  is a string. The default is ``True``. 
+        Whether the value  is a string. The default is ``True``.
 
     Returns
     -------
@@ -61,17 +63,13 @@ def update_hpc_option(self, filnename, propertyname, propertyvalue,
 
 def update_simulation_cores(self, name, nc):
     """Update the HPC number of cores in the configuration file.
-    
+
     Parameters
     ----------
     name : str
-        Name of the configuration file.    
+        Name of the configuration file.
     nc : int or string
-        Number of cores.  
-
-    Returns
-    -------
-    type
+        Number of cores.
 
     """
     with open(name) as fid:
@@ -83,21 +81,17 @@ def update_simulation_cores(self, name, nc):
         new_line = fid.read().replace(old_cores, "NumCores=" + str(nc))
     with open(name, "w") as f:
         f.write(new_line)
-    return
+
 
 def update_simulation_engines(self, name, nc):
     """Update the HPC number of simulaton engines in the configuration file.
-    
+
     Parameters
     ----------
     name : str
-        Name of the configuration file.   
+        Name of the configuration file.
     nc : int or str
-        Number of simulaton engines.   
-
-    Returns
-    -------
-    type
+        Number of simulaton engines.
 
     """
     with open(name) as fid:
@@ -109,7 +103,7 @@ def update_simulation_engines(self, name, nc):
         new_line = fid.read().replace(old_cores, "NumEngines=" + str(nc))
     with open(name, "w") as f:
         f.write(new_line)
-    return
+
 
 def update_machine_name(self, name, machinename):
     """Update the machine name.
@@ -121,10 +115,6 @@ def update_machine_name(self, name, machinename):
     machinename : str
         New name of the machine.
 
-    Returns
-    -------
-    type
-
     """
     with open(name) as fid:
         for line in fid:
@@ -135,7 +125,7 @@ def update_machine_name(self, name, machinename):
         new_line = fid.read().replace(old_machine, "MachineName=\'" + str(machinename) + "\'")
     with open(name, "w") as f:
         f.write(new_line)
-    return
+
 
 def update_config_name(self, name, machinename):
     """Update the name of the machine.
@@ -150,7 +140,7 @@ def update_config_name(self, name, machinename):
     Returns
     -------
     type
-    
+
     """
     with open(name) as fid:
         for line in fid:
@@ -163,7 +153,7 @@ def update_config_name(self, name, machinename):
         new_line = fid.read().replace(old_config, "ConfigName='" + str(machinename) + "'")
     with open(name, "w") as f:
         f.write(new_line)
-    return
+
 
 def update_cluster_cores(self, file_name, param_name, param_val):
     """Update the number of cluster cores in the configuration file.
@@ -171,15 +161,11 @@ def update_cluster_cores(self, file_name, param_name, param_val):
     Parameters
     ----------
     file_name : str
-        Full path and name of the configuration file. The file type can be ACF or TXT.   
+        Full path and name of the configuration file. The file type can be ACF or TXT.
     param_name : str
-        Name of the parameter.      
+        Name of the parameter.
     param_val : int
-         New number of cluster cores. 
-
-    Returns
-    -------
-    type
+         New number of cluster cores.
 
     """
     with open(file_name) as f:
@@ -191,23 +177,19 @@ def update_cluster_cores(self, file_name, param_name, param_val):
         new_line = f.read().replace(old_line,  replacement_line)
     with open(file_name, "w") as f:
         f.write(new_line)
-    return
+
 
 def Update_hpc_template(self, file_name, param_name, param_val):
     """Update a paramerter in the HPC template file.
 
-     Parameters
+    Parameters
     ----------
     file_name : str
         Full path and name of the HPC template file.
     param_name : str
-        Name of the parameter to update.   
+        Name of the parameter to update.
     param_val : int
-        Value of the paraemeter.     
-
-    Returns
-    -------
-    type
+        Value of the parameter.
 
     """
     with open(file_name) as f:
@@ -220,4 +202,3 @@ def Update_hpc_template(self, file_name, param_name, param_val):
         new_line = f.read().replace(old_line,  replacement_line)
     with open(file_name, "w") as f:
         f.write(new_line)
-    return
