@@ -22,6 +22,7 @@ from ..generic.general_methods import is_number
 
 @aedt_exception_handler
 def dB(x, inverse=True):
+    """Convert db to decimal"""
     if inverse:
         return 20*math.log10(x)
     else:
@@ -31,19 +32,19 @@ def dB(x, inverse=True):
 @aedt_exception_handler
 def fah2kel(val, inverse=True):
     """Convert a temperature from Fahrenheit to Kelvin.
-    
+
     Parameters
     ----------
     val : float
         Temperature value in Fahrenheit.
     inverse : bool, optional
         The default is ``True``.
-	
+
     Returns
     -------
     float
         Temperature value converted to Kelvin.
-    
+
     """
     if inverse:
         return (val - 273.15) * 9 / 5 + 32
@@ -54,21 +55,21 @@ def fah2kel(val, inverse=True):
 @aedt_exception_handler
 def cel2kel(val, inverse=True):
     """Convert a temperature from Celsius to Kelvin.
-    
+
     Parameters
     ----------
     val : float
         Temperature value in Celsius.
     inverse : bool, optional
         The default is ``True``.
-    
+
     Returns
     -------
     float
         Temperature value converted to Kelvin.
-	
+
     """
-    
+
     if inverse:
         return val - 273.15
     else:
@@ -77,19 +78,19 @@ def cel2kel(val, inverse=True):
 
 @aedt_exception_handler
 def unit_system(units):
-    """Retrieve the name of the unit system associated with a unit string. 
-    
+    """Retrieve the name of the unit system associated with a unit string.
+
     Parameters
     ----------
     units : str
         Units for retrieving the associated unit system name.
-    
+
     Returns
     -------
     str
         Key from the ``AEDT_units`` when successful. For example, ``"AngularSpeed"``.
-	``False`` when the units specified are not defined in AEDT units.
-    
+    ``False`` when the units specified are not defined in AEDT units.
+
     """
     found = False
     for unit_type, unit_list in AEDT_units.items():
@@ -113,7 +114,7 @@ v2pi = 2.0 * math.pi
 m2in = 0.0254
 m2miles = 1609.344051499
 
-# Value in new units equals value in old units * scaling vactor of new units
+# Value in new units equals value in old units * scaling vector of new units
 # e.g. value_in_deg Variable("1rad") = 1 * rad2deg
 AEDT_units = {
     'AngularSpeed': {'deg_per_hr': hour2sec * deg2rad, 'rad_per_hr': hour2sec, 'deg_per_min': min2sec * deg2rad,
@@ -143,7 +144,7 @@ AEDT_units = {
 }
 SI_units = {
     'AngularSpeed':  'rad_per_sec',
-    'Angle': 'deg',
+    'Angle': 'rad',
     'Current': 'A',
     'Flux': 'vs',
     'Freq': 'Hz',
@@ -212,28 +213,28 @@ def _resolve_unit_system(unit_system_1, unit_system_2, operation):
 
 class CSVDataset:
     """Reads in a CSV file and extracts data, which can be augmented with constant values.
-    
+
     Parameters
     ----------
     csv_file: str, optional
         Input file consisting of delimited data with the first line as the header.
-        The CSV value includes the header and data, which supports AEDT units information 
+        The CSV value includes the header and data, which supports AEDT units information
         such as ``"1.23Wb"``. You can also augment the data with constant values.
     separator: str, optional
-        Value to use for the delimiter. The default is``None`` in which case a comma is 
+        Value to use for the delimiter. The default is``None`` in which case a comma is
         assumed.
     units_dict: dict, optional
         Dictionary consisting of ``{Variable Name: unit}`` to rescale the data
         if it is not in the desired unit system.
     append_dict: dict, optional
-        Dictionary consisting of ``{New Variable Name: value}`` to add variables 
-        with constant values to all data points. This dictionary is used to add 
+        Dictionary consisting of ``{New Variable Name: value}`` to add variables
+        with constant values to all data points. This dictionary is used to add
         multiple sweeps to one result file.
     valid_solutions : bool, optional
         The default is ``True``.
     invalid_solutions : bool, optional
         The default is ``False``.
-         
+
     """
     @property
     def number_of_rows(self):
@@ -265,7 +266,7 @@ class CSVDataset:
         return os.path.dirname(os.path.realpath(self._csv_file))
 
     def __init__(self, csv_file=None, separator=None, units_dict=None, append_dict=None, valid_solutions=True, invalid_solutions=False):
-        
+
         self._header = []
         self._data = {}
         self._unit_dict = {}
@@ -297,7 +298,8 @@ class CSVDataset:
                             for j, value in enumerate(line_data):
                                 var_name = self._header[j]
                                 if var_name in self._unit_dict:
-                                    var_value = Variable(value).rescale_to(self._unit_dict[var_name]).numeric_value
+                                    var_value = Variable(value).rescale_to(
+                                        self._unit_dict[var_name]).numeric_value
                                 else:
                                     var_value = Variable(value).value
                                 self._data[var_name].append(var_value)
@@ -327,7 +329,8 @@ class CSVDataset:
                 if variable in key_string:
                     found_variable = True
                     break
-            assert found_variable, "Input string {} is not a key of the data dictionary.".format(variable)
+            assert found_variable, "Input string {} is not a key of the data dictionary.".format(
+                variable)
             data_out._data[variable] = self._data[key_string]
             data_out._header.append(variable)
         return data_out
@@ -355,12 +358,12 @@ class CSVDataset:
 
     def __iadd__(self, other):
         """Incrementally add the dataset in one CSV file to a dataset in another CSV file.
-        
+
         .. note:
            This assumes that the number of columns in both datasets are the same,
-           or that one of the datasets is empty. No checking is done for 
+           or that one of the datasets is empty. No checking is done for
            equivalency of units or variable names.
-          
+
          """
 
         # Handle the case of an empty data set and create empty lists for the column data
@@ -376,7 +379,6 @@ class CSVDataset:
             for value in row_data:
                 self._data[column].append(value)
 
-
         return self
 
     # Called when iteration is initialized
@@ -400,24 +402,42 @@ class CSVDataset:
         return output_string
 
     def next(self):
-        """ """
+        """Yield the next row."""
         return self.__next__()
 
 @aedt_exception_handler
-def decompose_variable_value(variable_value):
+def _find_units_in_dependent_variables(variable_value, full_variables={}):
+    m2 = re.findall(r'[0-9.]+ *([a-z_A-Z]+)', variable_value)
+    if len(m2) > 0:
+        if len(set(m2)) <= 1:
+            return m2[0]
+        else:
+            if unit_system(m2[0]):
+                return SI_units[unit_system(m2[0])]
+    else:
+        m1 = re.findall(r'(?<=[/+-/*//^/(/[])([a-z_A-Z]\w*)', variable_value.replace(" ", ""))
+        m2 = re.findall(r'^([a-z_A-Z]\w*)', variable_value.replace(" ", ""))
+        m = list(set(m1).union(m2))
+        for i,v in full_variables.items():
+            if i in m and _find_units_in_dependent_variables(v):
+                return _find_units_in_dependent_variables(v)
+    return ""
+
+@aedt_exception_handler
+def decompose_variable_value(variable_value, full_variables={}):
     """Decompose a variable value.
 
     Parameters
     ----------
     variable_value : float
-
+    full_variables : dict
     Returns
-    -------  
+    -------
 
     """
     # set default return values - then check for valid units
     float_value = variable_value
-    units =''
+    units = ''
 
     if is_number(variable_value):
         float_value = float(variable_value)
@@ -428,6 +448,8 @@ def decompose_variable_value(variable_value):
         except ValueError:
             # search for a valid units string at the end of the variable_value
             loc = re.search('[a-z_A-Z]+$', variable_value)
+            units = _find_units_in_dependent_variables(variable_value, full_variables)
+
             if loc:
                 loc_units = loc.span()[0]
                 extract_units = variable_value[loc_units:]
@@ -442,32 +464,36 @@ def decompose_variable_value(variable_value):
 
 
 class VariableManager(object):
-    """Manages design properties and project variables. 
-    
-    Design properties are the local variables in a design. Project variables are defined at the project 
-    level and start with ``$``. 
-    
-    This class provides access to all variables or a subset of the variables. Manipulation
-    of the numerical or string definitions of variable values is provided in the
+    """Manages design properties and project variables.
+
+    Design properties are the local variables in a design. Project
+    variables are defined at the project level and start with ``$``.
+
+    This class provides access to all variables or a subset of the
+    variables. Manipulation of the numerical or string definitions of
+    variable values is provided in the
     :class:`pyaedt.application.Variables.Variable` class.
 
     Parameters
     ----------
     variables : dict
-        Dictionary of all design properties and project variables in the active design.
+        Dictionary of all design properties and project variables in
+        the active design.
     design_variables : dict
         Dictionary of all design properties in the active design.
     project_variables : dict
-        Dictionary of all project variables available to the active design (key by variable name).
+        Dictionary of all project variables available to the active
+        design (key by variable name).
     dependent_variables : dict
-        Dictionary of all dependent variables available to the active design (key by variable name).
+        Dictionary of all dependent variables available to the active
+        design (key by variable name).
     independent_variables : dict
-       Dictionary of all independent variables (constant numeric values) available to the active 
-       design (key by variable name).
+       Dictionary of all independent variables (constant numeric
+       values) available to the active design (key by variable name).
     independent_design_variables : dict
 
     independent_project_variables : dict
-    
+
     variable_names : str or list
         One or more variable names.
     project_variable_names : str or list
@@ -477,12 +503,18 @@ class VariableManager(object):
     dependent_variable_names : str or list
         All dependent variable names within the project.
     independent_variable_names : list of str
-        All independent variable names within the project. These can be sweep variables for optimetrics.
+        All independent variable names within the project. These can
+        be sweep variables for optimetrics.
     independent_project_variable_names : str or list
-        All independent project variable names within the project. These can be sweep variables for optimetrics.
+        All independent project variable names within the
+        project. These can be sweep variables for optimetrics.
     independent_design_variable_names : str or list
-        All independent design properties (local variables) within the project. These can be sweep variables for optimetrics.
+        All independent design properties (local variables) within the
+        project. These can be sweep variables for optimetrics.
 
+    See Also
+    --------
+    pyaedt.application.Variables.Variable
 
     Examples
     --------
@@ -491,20 +523,20 @@ class VariableManager(object):
     >>> from pyaedt.desktop import Desktop
     >>> d = Desktop()
     >>> aedtapp = Maxwell3d()
-    
+
     Define some test variables.
-    
+
     >>> aedtapp["Var1"] = 3
     >>> aedtapp["Var2"] = "12deg"
     >>> aedtapp["Var3"] = "Var1 * Var2"
     >>> aedtapp["$PrjVar1"] = "pi"
 
     Get the variable manager for the active design.
-    
+
     >>> v = aedtapp.variable_manager
-    
+
     Get a dictionary of all project and design variables.
-    
+
     >>> v.variables
     {'Var1': <pyaedt.application.Variables.Variable at 0x2661f34c448>,
      'Var2': <pyaedt.application.Variables.Variable at 0x2661f34c308>,
@@ -519,34 +551,30 @@ class VariableManager(object):
      'Var3': <pyaedt.application.Variables.Expression at 0x2661f341808>}
 
     Get a dictionary of only the independent design variables.
-    
+
     >>> v.independent_design_variables
     {'Var1': <pyaedt.application.Variables.Variable at 0x2661f335d08>,
      'Var2': <pyaedt.application.Variables.Variable at 0x2661f3557c8>}
 
-    See Also
-    --------
-    :class:`pyaedt.application.Variables.Variable` class.
-    
     """
 
     @property
     def variables(self):
         """Variables.
-        
+
         Returns
         -------
         dict
             Dictionary of the `Variable` objects for each project variable and each
             design property in the active design.
-            
+
         """
         return self._variable_dict([self.odesign, self.oproject])
 
     @property
     def design_variables(self):
-        """Design variables
-        
+        """Design variables.
+
         Returns
         -------
         dict
@@ -557,7 +585,7 @@ class VariableManager(object):
     @property
     def project_variables(self):
         """Project variables.
-        
+
         Returns
         -------
         dict
@@ -568,18 +596,19 @@ class VariableManager(object):
     @property
     def independent_variables(self):
         """Independent variables.
-        
+
         Returns
         -------
         dict
-            Dictionary of the independent variables (constant numeric values) available to the design.
+            Dictionary of the independent variables (constant numeric
+            values) available to the design.
         """
         return self._variable_dict([self.odesign, self.oproject], dependent=False)
 
     @property
     def independent_project_variables(self):
         """Independent project variables.
-        
+
         Returns
         -------
         dict
@@ -590,52 +619,61 @@ class VariableManager(object):
     @property
     def independent_design_variables(self):
         """Independent design variables.
-        
+
         Returns
         -------
         dict
-            Dictionary of the independent design properties (local variables) available to the design.
+            Dictionary of the independent design properties (local
+            variables) available to the design.
         """
         return self._variable_dict([self.odesign], dependent=False)
 
     @property
     def dependent_variables(self):
         """Dependent variables.
-        
+
         Returns
         -------
         dict
-            Dictionary of the dependent design properties (local variables) and project variables available to the design.
-        
+            Dictionary of the dependent design properties (local
+            variables) and project variables available to the design.
+
         """
         return self._variable_dict([self.odesign, self.oproject], independent=False)
 
     @property
     def variable_names(self):
+        """List of variables."""
         return [var_name for var_name in self.variables]
 
     @property
     def project_variable_names(self):
+        """List of project variables."""
         return [var_name for var_name in self.project_variables]
 
     @property
     def independent_project_variable_names(self):
+        """List of independent project variables."""
         return [var_name for var_name in self.independent_project_variables]
 
     @property
     def design_variable_names(self):
+        """List of design variables."""
         return [var_name for var_name in self.design_variables]
 
     @property
     def independent_design_variable_names(self):
+        """List of independent design variables."""
         return [var_name for var_name in self.independent_design_variables]
 
     @property
     def independent_variable_names(self):
+        """List of independent variables."""
         return [var_name for var_name in self.independent_variables]
 
     @property
     def dependent_variable_names(self):
+        """List of dependent variables."""
         return [var_name for var_name in self.dependent_variables]
 
     @property
@@ -654,10 +692,14 @@ class VariableManager(object):
         return self._parent._messenger
 
     def __init__(self, parent):
-
         # Global Desktop Environment
         self._parent = parent
 
+    @aedt_exception_handler
+    def __delitem__(self, key):
+        """Implement del with array name or index."""
+        self.delete_variable(key)
+
     @aedt_exception_handler
     def __getitem__(self, variable_name):
         return self.variables[variable_name]
@@ -687,21 +729,22 @@ class VariableManager(object):
 
         """
         var_dict = {}
+        all_names ={}
         for obj in object_list:
             for variable_name in obj.GetVariables():
                 variable_expression = self.get_expression(variable_name)
+                all_names[variable_name] = variable_expression
                 try:
                     value = Variable(variable_expression)
                     if independent and is_number(value.value):
                         var_dict[variable_name] = value
                     elif dependent and type(value.value) is str:
                         float_value = self._parent.get_evaluated_value(variable_name)
-                        var_dict[variable_name] = Expression(variable_expression, float_value)
+                        var_dict[variable_name] = Expression(variable_expression, float_value, all_names)
                 except:
                     if dependent:
                         float_value = self._parent.get_evaluated_value(variable_name)
-                        var_dict[variable_name] = Expression(variable_expression, float_value)
-
+                        var_dict[variable_name] = Expression(variable_expression, float_value, all_names)
         return var_dict
 
     @aedt_exception_handler
@@ -712,12 +755,12 @@ class VariableManager(object):
     @aedt_exception_handler
     def aedt_object(self, variable):
         """Retrieve an AEDT object.
-        
+
         Parameters
         ----------
         variable : str
-	    Name of the variable.
-        
+        Name of the variable.
+
         """
         if variable[0] == "$":
             return self.oproject
@@ -727,29 +770,30 @@ class VariableManager(object):
     @aedt_exception_handler
     def set_variable(self, variable_name, expression=None, readonly=False, hidden=False,
                      description=None, overwrite=True):
-        """Set the value of a design property or project variable. 
+        """Set the value of a design property or project variable.
 
         Parameters
         ----------
         variable_name : str
-            Name of the design property or project variable (``$var``). If this variable 
-            does not exist, a new one is created and a value is set.
+            Name of the design property or project variable
+            (``$var``). If this variable does not exist, a new one is
+            created and a value is set.
         expression : str
-            Valid string expression within the AEDT design and project structure.
-            For example, ``"3*cos(34deg)"``.
+            Valid string expression within the AEDT design and project
+            structure.  For example, ``"3*cos(34deg)"``.
         readonly : bool, optional
-           Whether to set the design property or project variable to read-only. The 
-           default is ``False``.
+            Whether to set the design property or project variable to
+            read-only. The default is ``False``.
         hidden :  bool, optional
-            Whether to hide the design property or project variable. The 
-           default is ``False``.
-        description : str, optional 
-           Text to display for the design property or project variable in the 
-	     ``Properties`` window. The default is ``None``.
+            Whether to hide the design property or project variable. The
+            default is ``False``.
+        description : str, optional
+            Text to display for the design property or project variable in the
+            ``Properties`` window. The default is ``None``.
         overwrite : bool, optional
-            Whether to overwrite an existing value for the design property or
-            project variable. The default is ``False``, in which case this method is 
-            ignored. 
+            Whether to overwrite an existing value for the design
+            property or project variable. The default is ``False``, in
+            which case this method is ignored.
 
         Returns
         -------
@@ -758,24 +802,26 @@ class VariableManager(object):
 
         Examples
         --------
-        Set the value of design property ``p1`` to ``"10mm"``, creating the property 
-        if it does not already eixst.
-        
+        Set the value of design property ``p1`` to ``"10mm"``,
+        creating the property if it does not already eixst.
+
         >>> aedtapp.variable_manager.set_variable("p1", expression="10mm")
 
-        Set the value of design property ``p1`` to ``"20mm"`` only if the property does 
-        not already exist.
-        
+        Set the value of design property ``p1`` to ``"20mm"`` only if
+        the property does not already exist.
+
         >>> aedtapp.variable_manager.set_variable("p1", expression="20mm", overwrite=False)
 
-        Set the value of design property ``p2`` to ``"10mm"``, creating the property 
-        if it does not already exist. Also make it read-only and hidden and add a description.
-        
+        Set the value of design property ``p2`` to ``"10mm"``,
+        creating the property if it does not already exist. Also make
+        it read-only and hidden and add a description.
+
         >>> aedtapp.variable_manager.set_variable(variable_name="p2", expression="10mm", readonly=True, hidden=True,
         ...                                       description="This is the description of this variable.")
 
-        Set the value of the project variable ``$p1`` to ``"30mm"``, creating the variable if it does not exist.
-        
+        Set the value of the project variable ``$p1`` to ``"30mm"``,
+        creating the variable if it does not exist.
+
         >>> aedtapp.variable_manager.set_variable["$p1"] == "30mm"
 
         """
@@ -874,17 +920,17 @@ class VariableManager(object):
     @aedt_exception_handler
     def delete_separator(self, separator_name):
         """Delete a separator from either the active project or design.
-        
+
         Parameters
         ----------
         separator_name : str
-	      Value to use for the delimiter. 
-        
+            Value to use for the delimiter.
+
         Returns
         -------
-	  bool
+        bool
             ``True`` when the separator exists and can be deleted, ``False`` otherwise.
-            
+
         """
         object_list = [ (self.odesign, "Local"),
                         (self.oproject, "Project")]
@@ -970,19 +1016,19 @@ class Variable(object):
 
     Examples
     --------
-    
+
     >>> from pyaedt.application.Variables import Variable
 
     Define a variable using a string value consistent with the AEDT properties.
-    
+
     >>> v = Variable("45mm")
 
     Define an unitless variable with a value of 3.0.
-   
+
     >>> v = Variable(3.0)
 
     Define a variable defined by a numeric result and a unit string.
-    
+
     >>> v = Variable(3.0 * 4.5, units="mm")
     >>> assert v.numeric_value = 13.5
     >>> assert v.units = "mm"
@@ -1002,7 +1048,8 @@ class Variable(object):
         # If units have been specified, check for a conflict and otherwise use the specified unit system
         if units:
             assert not self._units, \
-                "The unit specification {} is inconsistent with the identified units {}.".format(specified_units, self._units)
+                "The unit specification {} is inconsistent with the identified units {}.".format(
+                    specified_units, self._units)
             self._units = specified_units
 
         if is_number(self._value):
@@ -1040,22 +1087,22 @@ class Variable(object):
     @property
     def string_value(self):
         """String value.
-        
-        The numeric value with the unit is concatenated and returned as a string. The numeric display 
-        in the modeler and the string value can differ. For example, you might see ``10mm`` in the 
+
+        The numeric value with the unit is concatenated and returned as a string. The numeric display
+        in the modeler and the string value can differ. For example, you might see ``10mm`` in the
         modeler and see ``10.0mm`` returned as the string value.
-        
+
         """
         return ('{}{}').format(self.numeric_value, self._units)
 
     @aedt_exception_handler
     def rescale_to(self, units):
         """Rescale the expression to a new unit within the current unit system.
-	
-	  Parameters
-	  ----------
-	  units : str
-	      Units to rescale to.
+
+        Parameters
+        ----------
+        units : str
+            Units to rescale to.
 
         Examples
         --------
@@ -1075,7 +1122,6 @@ class Variable(object):
         self._units = units
         return self
 
-
     @aedt_exception_handler
     def format(self, format):
         """Retrieve the string value with the specified numerical formatting.
@@ -1083,9 +1129,9 @@ class Variable(object):
         Parameters
         ----------
         format : str
-            Format for the numeric value of the string. For example, ``'06.2f'``. For 
+            Format for the numeric value of the string. For example, ``'06.2f'``. For
             more information, see the `PyFormat documentation <https://pyformat.info/>`_.
-		
+
         Returns
         -------
         str
@@ -1121,7 +1167,7 @@ class Variable(object):
         --------
         >>> from pyaedt.application.Variables import Variable
 
-        Multiply ``'Length1'`` by unitless ``'None'``` to obtain ``'Length'``. 
+        Multiply ``'Length1'`` by unitless ``'None'``` to obtain ``'Length'``.
         A numerical value is also considered to be unitless.
 
         >>> v1 = Variable("10mm")
@@ -1134,7 +1180,7 @@ class Variable(object):
         >>> assert result_2.unit_system == result_1.unit_system
 
         Multiply voltage times current to obtain power.
-        
+
         >>> v3 = Variable("3mA")
         >>> v4 = Variable("40V")
         >>> result_3 = v3 * v4
@@ -1143,7 +1189,8 @@ class Variable(object):
         >>> assert result_3.unit_system == "Power"
 
         """
-        assert is_number(other) or isinstance(other, Variable), "Multiplier must be a scalar quantity or a variable."
+        assert is_number(other) or isinstance(
+            other, Variable), "Multiplier must be a scalar quantity or a variable."
         if is_number(other):
             result_value = self.numeric_value * other
             result_units = self.units
@@ -1156,7 +1203,8 @@ class Variable(object):
                 result_value = self.value * other.value
                 result_units = _resolve_unit_system(self.unit_system, other.unit_system, "multiply")
                 if not result_units:
-                    result_units = _resolve_unit_system(other.unit_system, self.unit_system, "multiply")
+                    result_units = _resolve_unit_system(
+                        other.unit_system, self.unit_system, "multiply")
 
         return Variable("{}{}".format(result_value, result_units))
 
@@ -1217,7 +1265,7 @@ class Variable(object):
 
         Examples
         --------
-        
+
         >>> from pyaedt.application.Variables import Variable
         >>> v3 = Variable("3mA")
         >>> v4 = Variable("10A")
@@ -1227,7 +1275,8 @@ class Variable(object):
         >>> assert result_2.unit_system == "Current"
 
         """
-        assert isinstance(other, Variable), "You can only subtract a variable from another variable."
+        assert isinstance(
+            other, Variable), "You can only subtract a variable from another variable."
         assert self.unit_system == other.unit_system, "Only ``Variable`` objects with the same unit system can be subtracted."
         result_value = self.value - other.value
         result_units = SI_units[self.unit_system]
@@ -1257,9 +1306,9 @@ class Variable(object):
 
         Examples
         --------
-        Divide a variable with units ``"W"`` by a variable with units ``"V"`` and automatically 
+        Divide a variable with units ``"W"`` by a variable with units ``"V"`` and automatically
         resolve the new units to ``"A"``.
-	
+
         >>> from pyaedt.application.Variables import Variable
 
         >>> v1 = Variable("10W")
@@ -1270,7 +1319,8 @@ class Variable(object):
         >>> assert result_1.unit_system == "Current"
 
         """
-        assert is_number(other) or isinstance(other, Variable), "Divisor must be a scalar quantity or a variable."
+        assert is_number(other) or isinstance(
+            other, Variable), "Divisor must be a scalar quantity or a variable."
         if is_number(other):
             result_value = self.numeric_value / other
             result_units = self.units
@@ -1301,9 +1351,9 @@ class Variable(object):
 
         Examples
         --------
-        Divide a number by a variable with units ``"s"`` and automatically determine that 
+        Divide a number by a variable with units ``"s"`` and automatically determine that
         the result is in ``"Hz"``.
-        
+
         >>> from pyaedt.application.Core.Variables import Variable
         >>> v = Variable("1s")
         >>> result = 3.0 / v
@@ -1324,21 +1374,20 @@ class Variable(object):
 
 class Expression(Variable, object):
     """Provides a framework for manipulating variable expressions.
-    
+
     Parameters
     ----------
     expression :
-    
+
     float_value :
-    
+
     """
 
-    def __init__(self, expression, float_value):
+    def __init__(self, expression, float_value, full_variables={}):
         self._expression = expression
         self._value = float_value
-        # TODO. Try to identify the unit system from the expression.
         try:
-            value, units = decompose_variable_value(expression)
+            value, units = decompose_variable_value(expression, full_variables)
             self._units = units
         except:
             self._units = ''
@@ -1351,7 +1400,7 @@ class Expression(Variable, object):
 
 class DataSet(object):
     """Manages datasets.
-    
+
     Parameters
     ----------
     parent :
@@ -1369,8 +1418,8 @@ class DataSet(object):
     zunit : str, optional
        The default is ``""``.
     vunit : str, optional
-       The default is ``""``. 
-    
+       The default is ``""``.
+
     """
 
     def __init__(self, parent, name, x, y, z=None, v=None, xunit='', yunit='', zunit='', vunit=''):
@@ -1465,7 +1514,7 @@ class DataSet(object):
         Parameters
         ----------
         x : float
-       
+
         Returns
         -------
         bool
@@ -1478,7 +1527,6 @@ class DataSet(object):
         id_to_remove = self.x.index(x)
         return self.remove_point_from_index(id_to_remove)
 
-
     @aedt_exception_handler
     def remove_point_from_index(self, id_to_remove):
         """Remove a point from an index.
@@ -1507,12 +1555,12 @@ class DataSet(object):
     @aedt_exception_handler
     def update(self):
         """Update the dataset.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         args = self._args()
         if not args:
@@ -1526,12 +1574,12 @@ class DataSet(object):
     @aedt_exception_handler
     def delete(self):
         """Delete the dataset.
-        
+
         Returns
-        ------
+        -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         if self.name[0] == "$":
             self._parent._oproject.DeleteDataset(self.name)
@@ -1550,7 +1598,7 @@ class DataSet(object):
         dataset_path : str, optional
             Path to export the dataset to. The default is ``None``, in which
             case the dataset is exported to the project path.
-        
+
         Returns
         -------
         bool
