@@ -3,159 +3,18 @@
 
 from __future__ import absolute_import
 import math
-from .application.AnalysisNexxim import FieldAnalysisCircuit
-from .desktop import exception_to_desktop
-from .generic.general_methods import generate_unique_name, aedt_exception_handler
+import warnings
 import re
 import os
 
-RKM_MAPS = {
-    # Resistors
-    'L': 'm',
-    'R': '',
-    'E': '',
-    'k': 'k',
-    'K': 'k',
-    'M': 'M',
-    'G': 'G',
-    'T': 'T',
-    # Capacitors/Inductors
-    'F': '',
-    'H': '',
-    'h': '',
-    'm': 'm',
-    'u': 'μ',
-    'μ': 'μ',
-    'U': 'μ',
-    'n': 'n',
-    'N': 'n',
-    'p': 'p',
-    'P': 'p',
-    'mF': 'm',
-    'uF': 'μ',
-    'μF': 'μ',
-    'UF': 'μ',
-    'nF': 'n',
-    'NF': 'n',
-    'pF': 'p',
-    'PF': 'p',
-    'mH': 'm',
-    'uH': 'μ',
-    'μH': 'μ',
-    'UH': 'μ',
-    'nH': 'n',
-    'NH': 'n',
-    'pH': 'p',
-    'PH': 'p',
-}
-
-AEDT_MAPS = {
-    'μ': 'u'
-}
-
-
-def from_rkm(code):
-    """Convert an RKM code string to a string with a decimal point.
-
-    Parameters
-    ----------
-    code : str
-        RKM code string.
-
-    Returns
-    -------
-    str
-        String with a decimal point and an R value.
-
-    Examples
-    --------
-    >>> from pyaedt.circuit import from_rkm
-    >>> from_rkm('R47')
-    '0.47'
-
-    >>> from_rkm('4R7')
-    '4.7'
-
-    >>> from_rkm('470R')
-    '470'
-
-    >>> from_rkm('4K7')
-    '4.7k'
-
-    >>> from_rkm('47K')
-    '47k'
-
-    >>> from_rkm('47K3')
-    '47.3k'
-
-    >>> from_rkm('470K')
-    '470k'
-
-    >>> from_rkm('4M7')
-    '4.7M'
-
-    """
-
-    # Matches RKM codes that start with a digit.
-    # fd_pattern = r'([0-9]+)([LREkKMGTFmuµUnNpP]+)([0-9]*)'
-    fd_pattern = r'([0-9]+)([{}]+)([0-9]*)'.format(''.join(RKM_MAPS.keys()), )
-    # matches rkm codes that end with a digit
-    # ld_pattern = r'([0-9]*)([LREkKMGTFmuµUnNpP]+)([0-9]+)'
-    ld_pattern = r'([0-9]*)([{}]+)([0-9]+)'.format(''.join(RKM_MAPS.keys()))
-
-    fd_regex = re.compile(fd_pattern, re.I)
-    ld_regex = re.compile(ld_pattern, re.I)
-
-    for regex in [fd_regex, ld_regex]:
-        m = regex.match(code)
-        if m:
-            fd, base, ld = m.groups()
-            ps = RKM_MAPS[base]
-
-            if ld:
-                return_str = ''.join([fd, '.', ld, ps])
-            else:
-                return_str = ''.join([fd, ps])
-            return return_str
-    return code
-
-
-def to_aedt(code):
-    """
-
-    Parameters
-    ----------
-    code : str
-    
-    Returns
-    -------
-    str
-    
-    """
-    pattern = r'([{}]{})'.format(''.join(AEDT_MAPS.keys()), '{1}')
-    regex = re.compile(pattern, re.I)
-    return_code = regex.sub(lambda m: AEDT_MAPS.get(m.group(), m.group()), code)
-    return return_code
-
-
-def from_rkm_to_aedt(code):
-    """
-
-    Parameters
-    ----------
-    code : str
-        
-
-    Returns
-    -------
-    str
-    
-    """
-    return to_aedt(from_rkm(code))
+from .application.AnalysisNexxim import FieldAnalysisCircuit
+from .desktop import exception_to_desktop
+from .generic.DataHandlers import from_rkm_to_aedt
+from .generic.general_methods import aedt_exception_handler
 
 
 class Circuit(FieldAnalysisCircuit, object):
-    """Circuit application interface.
+    """Provides the Circuit application interface.
 
     Parameters
     ----------
@@ -177,18 +36,18 @@ class Circuit(FieldAnalysisCircuit, object):
         nothing is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is  used.
+        the active version or latest installed version is  used. This parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to run AEDT in the non-graphical mode. The default
-        is``False``, in which case AEDT is launched in the graphical mode.
+        is``False``, in which case AEDT is launched in the graphical mode. This parameter is ignored when Script is launched within AEDT.
     AlwaysNew : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
-        machine.  The default is ``True``.
+        machine.  The default is ``True``. This parameter is ignored when Script is launched within AEDT.
     release_on_exit : bool, optional
         Whether to release AEDT on exit.
     student_version : bool, optional
-        Whether to open the AEDT student version. The default is ``False``.
+        Whether to open the AEDT student version. The default is ``False``. This parameter is ignored when Script is launched within AEDT.
 
     Examples
     --------
@@ -225,6 +84,7 @@ class Circuit(FieldAnalysisCircuit, object):
     >>> hfss = Circuit(specified_version="2021.2", projectname="myfile.aedt", student_version=True)
 
     """
+
     def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
                  specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
         FieldAnalysisCircuit.__init__(self, "Circuit Design", projectname, designname, solution_type, setup_name,
@@ -239,11 +99,12 @@ class Circuit(FieldAnalysisCircuit, object):
 
     @property
     def onetwork_data_explorer(self):
+        """Data explorer."""
         return self._desktop.GetTool("NdExplorer")
 
-    @aedt_exception_handler
     def _get_number_from_string(self, stringval):
-        value = stringval[stringval.find("=") + 1:].strip().replace("{", "").replace("}", "").replace(",", ".")
+        value = stringval[stringval.find(
+            "=") + 1:].strip().replace("{", "").replace("}", "").replace(",", ".")
         try:
             float(value)
             return value
@@ -255,7 +116,7 @@ class Circuit(FieldAnalysisCircuit, object):
         """Create a circuit schematic from an HSpice net list.
 
         Supported currently are:
-        
+
         * R
         * L
         * C
@@ -272,7 +133,7 @@ class Circuit(FieldAnalysisCircuit, object):
         -------
         bool
              ``True`` when successful, ``False`` when failed.
-        
+
         """
         xpos = 0
         ypos = 0
@@ -462,9 +323,9 @@ class Circuit(FieldAnalysisCircuit, object):
     @aedt_exception_handler
     def create_schematic_from_mentor_netlist(self, file_to_import):
         """Create a circuit schematic from a Mentor net list.
-        
+
         Supported currently are:
-        
+
         * R
         * L
         * C
@@ -481,7 +342,7 @@ class Circuit(FieldAnalysisCircuit, object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         xpos = 0
         ypos = 0
@@ -582,7 +443,8 @@ class Circuit(FieldAnalysisCircuit, object):
             if "GND" in netname.upper():
                 self.modeler.components.create_gnd(xpos, ypos)
                 page_pos = ypos + 0.00254
-                id, name = self.modeler.components.create_page_port(netname, xpos, ypos, 6.28318530717959)
+                id, name = self.modeler.components.create_page_port(
+                    netname, xpos, ypos, 6.28318530717959)
                 mod1 = self.modeler.components[id]
                 mod1.set_location(str(xpos) + "meter", str(page_pos) + "meter")
                 ypos += delta
@@ -605,7 +467,7 @@ class Circuit(FieldAnalysisCircuit, object):
         -------
         str
             Type of the Mentor net list component.
-        
+
         """
         if refid[1] == "R":
             return "resistor:RES."
@@ -624,7 +486,7 @@ class Circuit(FieldAnalysisCircuit, object):
     def get_source_pin_names(self, source_design_name, source_project_name=None, source_project_path=None,
                              port_selector=3):
         """List the pin names.
-        
+
         Parameters
         ----------
         source_design_name : str
@@ -634,15 +496,22 @@ class Circuit(FieldAnalysisCircuit, object):
         source_project_path : str, optional
             Path to the source project if different than the existing path. The default is ``None``.
         port_selector : int, optional
-             Type of the port. Options are ``1``, ``2``, or ``3``, corresponding respectively to ``"Wave Port"``, ``"Terminal"``, or ``"Circuit Port"``.
+             Type of the port. Options are ``1``, ``2``, or ``3``, corresponding respectively to ``"Wave Port"``,
+             ``"Terminal"``, or ``"Circuit Port"``.
              The default is ``3``, which is a circuit port.
 
         Returns
         -------
         list
             List of pin names.
-        
+
         """
+        if source_project_name and self.project_name != source_project_name and not source_project_path:
+            raise AttributeError("If source project is different than the current one, "
+                                 "``source_project_path`` must be also provided.")
+        if source_project_path and not source_project_name:
+            raise AttributeError("When ``source_project_path`` is specified, "
+                                 "``source_project_name`` must be also provided.")
         if not source_project_name or self.project_name == source_project_name:
             oSrcProject = self._desktop.GetActiveProject()
         else:
@@ -673,12 +542,12 @@ class Circuit(FieldAnalysisCircuit, object):
             Name of the Touchstone file.
         solution_name : str, optional
             Name of the solution. The default is ``"Imported_Data"``.
-        
+
         Returns
         -------
         list
             List of ports.
-        
+
         """
         if filename[-2:] == "ts":
             with open(filename, "r") as f:
@@ -742,7 +611,7 @@ class Circuit(FieldAnalysisCircuit, object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         # Normalize the save path
         if not filename:
@@ -750,14 +619,16 @@ class Circuit(FieldAnalysisCircuit, object):
             for v, vv in zip(variation, variations_value):
                 appendix += "_" + v + vv.replace("\'", "")
             ext = ".S" + str(self.oboundary.GetNumExcitations()) + "p"
-            filename = os.path.join(self.project_path, solutionname + "_" + sweepname + appendix + ext)
+            filename = os.path.join(self.project_path, solutionname + \
+                                    "_" + sweepname + appendix + ext)
         else:
             filename = filename.replace("//", "/").replace("\\", "/")
         print("Exporting Touchstone " + filename)
         DesignVariations = ""
         i = 0
         for el in variation:
-            DesignVariations += str(variation[i]) + "=\'" + str(variations_value[i].replace("\'", "")) + "\' "
+            DesignVariations += str(variation[i]) + "=\'" + \
+                                    str(variations_value[i].replace("\'", "")) + "\' "
             i += 1
             # DesignVariations = "$AmbientTemp=\'22cel\' $PowerIn=\'100\'"
         # array containing "SetupName:SolutionName" pairs (note that setup and solution are separated by a colon)
@@ -766,7 +637,8 @@ class Circuit(FieldAnalysisCircuit, object):
         # 7=Matlab (.m), 8=Terminal Z0 spreadsheet
         FileFormat = 3
         OutFile = filename  # full path of output file
-        FreqsArray = ["all"]  # array containin the frequencies to export, use ["all"] for all frequencies
+        # array containin the frequencies to export, use ["all"] for all frequencies
+        FreqsArray = ["all"]
         DoRenorm = True  # perform renormalization before export
         RenormImped = 50  # Real impedance value in ohm, for renormalization
         DataType = "S"  # Type: "S", "Y", or "Z" matrix to export
@@ -796,11 +668,11 @@ class Circuit(FieldAnalysisCircuit, object):
         ----------
         designname : str, optional
             Name of the design or the full path to the solution file if it is an imported file.
-            The default is ``None``.    
+            The default is ``None``.
         setupname : str, optional
             Name of the setup if it is a design. The default is ``None``.
         is_solution_file: bool, optional
-            Whether it is an imported solution file. The default is ``False``. 
+            Whether it is an imported solution file. The default is ``False``.
         filename: str, optional
             Full path and name for exporting the HSpice file. The default is ``None``.
         passivity: bool, optional
@@ -821,7 +693,7 @@ class Circuit(FieldAnalysisCircuit, object):
         -------
         str
             Name of the HSpice file if the export is successful.
-        
+
         """
         if not designname:
             designname = self.design_name
@@ -854,10 +726,13 @@ class Circuit(FieldAnalysisCircuit, object):
                                                          "TouchStonePrecision:=", 15,
                                                          "SubcircuitName:=", "",
                                                          "SYZDataInAutoMode:=", False,
-                                                         "ExportDirectory:=", os.path.dirname(filename) + "\\",
-                                                         "ExportSpiceFileName:=", os.path.basename(filename),
+                                                         "ExportDirectory:=", os.path.dirname(
+                                                             filename) + "\\",
+                                                         "ExportSpiceFileName:=", os.path.basename(
+                                                             filename),
                                                          "FullwaveSpiceFileName:=",
-                                                         os.path.basename(filename), "UseMultipleCores:=",
+                                                         os.path.basename(
+                                                             filename), "UseMultipleCores:=",
                                                          True, "NumberOfCores:=", 20])
         return filename
 
@@ -888,7 +763,8 @@ class Circuit(FieldAnalysisCircuit, object):
         if variation_dict:
             for el in variation_dict:
                 variations[el] = [variation_dict[el]]
-        ctxt = ["NAME:Context", "SimValueContext:=",[3, 0, 2, 0, False, False, -1, 1, 0, 1, 1, "", 0, 0]]
+        ctxt = ["NAME:Context", "SimValueContext:=",[
+            3, 0, 2, 0, False, False, -1, 1, 0, 1, 1, "", 0, 0]]
         return self.post.create_rectangular_plot(curvenames,solution_name, variations, plotname=plot_name, context=ctxt)
 
     @aedt_exception_handler
@@ -916,6 +792,277 @@ class Circuit(FieldAnalysisCircuit, object):
         if variation_dict:
             for el in variation_dict:
                 variations[el] = [variation_dict[el]]
-        ctxt = ["NAME:Context", "SimValueContext:=", [3, 0, 2, 0, False, False, -1, 1, 0, 1, 1, "", 0, 0]]
+        ctxt = ["NAME:Context", "SimValueContext:=", [
+            3, 0, 2, 0, False, False, -1, 1, 0, 1, 1, "", 0, 0]]
         return self.post.get_solution_data_per_variation("Standard", solution_name, ctxt, variations, curvenames)
 
+    @aedt_exception_handler
+    def push_excitations(self, instance_name, thevenin_calculation=False, setup_name="LinearFrequency"):
+        """Push excitations.
+
+        Parameters
+        ----------
+        instance_name : str
+            Name of the instance.
+        thevenin_calculation : bool, optional
+            Whether to perform the Thevenin equivalent calculation. The default is ``False``.
+        setup_name : str
+            Name of the solution setup to push.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        arg = ["NAME:options",
+               "CalcThevenin:=", thevenin_calculation,
+               "Sol:=", setup_name]
+
+        self.modeler.oeditor.PushExcitations(instance_name, arg)
+        return True
+
+    @aedt_exception_handler
+    def assign_voltage_sinusoidal_excitation_to_ports(self, ports, settings):
+        """Assign a voltage sinusoidal excitation to circuit ports.
+
+        Parameters
+        ----------
+        ports : list
+            List of circuit ports to assign to the sinusoidal excitation.
+        settings : list
+            List of parameter values to use in voltage sinusoidal excitation creation.
+            All settings must be provided as strings.
+            An empty string (``""``) sets the parameter to its default.
+
+            Values are given in this order:
+
+            * 0: AC magnitude for small-signal analysis. For example ``"33V"``. Default = "nan V".
+            * 1: AC phase for small-signal analysis. For example ``"44deg"``. Default = "0deg".
+            * 2: DC voltage. For example ``"1V"``. Default = "0V"
+            * 3: Voltage offset from zero. For example ``"1V"``. Default = "0V".
+            * 4: Voltage amplitude. For example ``"3V"``. Default = "0V".
+            * 5: Frequency. For example ``"15GHz"``. Default = "1GHz".
+            * 6: Delay to start of sine wave. For example ``"16s"``. Default = "0s".
+            * 7: Damping factor (1/seconds). For example ``"2"``. Default = "0".
+            * 8: Phase delay. For example ``"18deg"``. Default = "0deg".
+            * 9: Frequency to use for harmonic balance analysis. For example ``"20Hz"``. Default = "0Hz".
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        # setting the defaults if no value is provided
+        defaults = ["nan V", "0deg", "0V", "0V", "0V", "1GHz", "0s", "0", "0deg", "0Hz"]
+        for i in range(len(settings)):
+            if settings[i] == "":
+                settings[i] = defaults[i]
+
+        id = self.modeler.components.create_unique_id()
+
+        arg1 = ["NAME:NexximSources",
+                ["NAME:NexximSources",
+                 ["NAME:Data",
+                  ["NAME:VoltageSinusoidal"+str(id),
+                   "DataId:=", "Source"+str(id),
+                   "Type:=", 1,
+                   "Output:=", 0,
+                   "NumPins:=", 2,
+                   "Netlist:=", "V@ID %0 %1 *DC(DC=@DC) SIN(?VO(@VO) ?VA(@VA) ?FREQ(@FREQ) ?TD(@TD) ?ALPHA(@ALPHA) ?THETA(@THETA)) *TONE(TONE=@TONE) *ACMAG(AC @ACMAG @ACPHASE)",
+                   "CompName:=", "Nexxim Circuit Elements\\Independent Sources:V_SIN",
+                   "FDSFileName:=", "",
+                   ["NAME:Properties",
+                    "TextProp:=", ["LabelID","HD","Property string for netlist ID","V@ID"],
+                    "ValueProp:=", ["ACMAG","OD","AC magnitude for small-signal analysis (Volts)",settings[0],0],
+                    "ValuePropNU:=", ["ACPHASE","OD","AC phase for small-signal analysis",settings[1],0,"deg"],
+                    "ValueProp:=", ["DC","OD","DC voltage (Volts)",settings[2],0],
+                    "ValueProp:=", ["VO","OD","Voltage offset from zero (Volts)",settings[3],0],
+                    "ValueProp:=", ["VA","OD","Voltage amplitude (Volts)",settings[4],0],
+                    "ValueProp:=", ["FREQ","OD","Frequency (Hz)",settings[5],0],
+                    "ValueProp:=", ["TD","OD","Delay to start of sine wave (seconds)",settings[6],0],
+                    "ValueProp:=", ["ALPHA","OD","Damping factor (1/seconds)",settings[7],0],
+                    "ValuePropNU:=", ["THETA","OD","Phase delay",settings[8],0,"deg"],
+                    "ValueProp:=", ["TONE","OD","Frequency (Hz) to use for harmonic balance analysis, should be a submultiple of (or equal to) the driving frequency and should also be included in the HB analysis setup",settings[9],0],
+                    "TextProp:=", ["ModelName","SHD","","V_SIN"],
+                    "MenuProp:=", ["CoSimulator","D","","DefaultNetlist",0],
+                    "ButtonProp:=", ["CosimDefinition","D","","","Edit",40501, "ButtonPropClientData:=", []]
+                    ]
+                   ]
+                  ]
+                 ]
+                ]
+
+        arg2 = ["NAME:ComponentConfigurationData"]
+
+        arg3 = ["NAME:ComponentConfigurationData", ["NAME:EnabledPorts", "VoltageSinusoidal"+str(id)+":=", ports]]
+
+        arg2.append(arg3)
+
+        self.odesign.UpdateSources(arg1, arg2)
+        return True
+
+    @aedt_exception_handler
+    def assign_current_sinusoidal_excitation_to_ports(self, ports, settings):
+        """Assign a current sinusoidal excitation to circuit ports.
+
+        Parameters
+        ----------
+        ports : list
+            List of circuit ports to assign to the sinusoidal excitation.
+        settings : list
+            List of parameter values to use in voltage sinusoidal excitation creation.
+            All settings must be provided as strings.
+            An empty string (``""``) sets the parameter to its default.
+
+            Values are given in this order:
+
+            * 0: AC magnitude for small-signal analysis. For example ``"33A"``. Default = "nan A".
+            * 1: AC phase for small-signal analysis. For example ``"44deg"``. Default = "0deg".
+            * 2: DC voltage. For example ``"1A"``. Default = "0A"
+            * 3: Current offset from zero. For example ``"1A"``. Default = "0A".
+            * 4: Current amplitude. For example ``"3A"``. Default = "0A".
+            * 5: Frequency. For example ``"15GHz"``. Default = "1GHz".
+            * 6: Delay to start of sine wave. For example ``"16s"``. Default = "0s".
+            * 7: Damping factor (1/seconds). For example ``"2"``. Default = "0".
+            * 8: Phase delay. For example ``"18deg"``. Default = "0deg".
+            * 9: Multiplier for simulating multiple parallel current sources. For example ``"4"``. Default = "1".
+            * 10: Frequency to use for harmonic balance analysis. For example ``"20Hz"``. Default = "0Hz".
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        # setting the defaults if no value is provided
+        defaults = ["nan A", "0deg", "0A", "0A", "0A", "1GHz", "0s", "0", "0deg", "1", "0Hz"]
+        for i in range(len(settings)):
+            if settings[i] == "":
+                settings[i] = defaults[i]
+
+        id = self.modeler.components.create_unique_id()
+
+        arg1 = ["NAME:NexximSources",
+                ["NAME:NexximSources",
+                 ["NAME:Data",
+                  ["NAME:CurrentSinusoidal"+str(id),
+                   "DataId:=", "Source"+str(id),
+                   "Type:=", 1,
+                   "Output:=", 1,
+                   "NumPins:=", 2,
+                   "Netlist:=", "I@ID %0 %1 *DC(DC=@DC) SIN(?VO(@VO) ?VA(@VA) ?FREQ(@FREQ) ?TD(@TD) ?ALPHA(@ALPHA) ?THETA(@THETA) *M(M=@M)) *TONE(TONE=@TONE) *ACMAG(AC @ACMAG @ACPHASE)",
+                   "CompName:=", "Nexxim Circuit Elements\\Independent Sources:I_SIN",
+                   "FDSFileName:=", "",
+                   ["NAME:Properties",
+                    "TextProp:=", ["LabelID","HD","Property string for netlist ID","I@ID"],
+                    "ValueProp:=", ["ACMAG","OD","AC magnitude for small-signal analysis (Amps)",settings[0],0],
+                    "ValuePropNU:=", ["ACPHASE","OD","AC phase for small-signal analysis",settings[1],0,"deg"],
+                    "ValueProp:=", ["DC","OD","DC current (Amps)",settings[2],0],
+                    "ValueProp:=", ["VO","OD","Current offset (Amps)",settings[3],0],
+                    "ValueProp:=", ["VA","OD","Current amplitude (Amps)",settings[4],0],
+                    "ValueProp:=", ["FREQ","OD","Frequency (Hz)",settings[5],0],
+                    "ValueProp:=", ["TD","OD","Delay to start of sine wave (seconds)",settings[6],0],
+                    "ValueProp:=", ["ALPHA","OD","Damping factor (1/seconds)",settings[7],0],
+                    "ValuePropNU:=", ["THETA","OD","Phase delay",settings[8],0,"deg"],
+                    "ValueProp:=", ["M","OD","Multiplier for simulating multiple parallel current sources",settings[9],0],
+                    "ValueProp:=", ["TONE","OD","Frequency (Hz) to use for harmonic balance analysis, should be a submultiple of (or equal to) the driving frequency and should also be included in the HB analysis setup",settings[10],0],
+                    "TextProp:=", ["ModelName","SHD","","I_SIN"],
+                    "MenuProp:=", ["CoSimulator","D","","DefaultNetlist",0],
+                    "ButtonProp:=", ["CosimDefinition","D","","","Edit",40501,"ButtonPropClientData:=", []]
+                    ]
+                   ]
+                  ]
+                 ]
+                ]
+
+        arg2 = ["NAME:ComponentConfigurationData"]
+
+        arg3 = ["NAME:ComponentConfigurationData", ["NAME:EnabledPorts", "CurrentSinusoidal"+str(id)+":=", ports]]
+
+        arg2.append(arg3)
+
+        self.odesign.UpdateSources(arg1, arg2)
+        return True
+
+    @aedt_exception_handler
+    def assign_power_sinusoidal_excitation_to_ports(self, ports, settings):
+        """Assign a power sinusoidal excitation to circuit ports.
+
+        Parameters
+        ----------
+        ports : list
+            List of circuit ports to assign to the sinusoidal excitation.
+        settings : list
+            List of parameter values to use in power sinusoidal excitation creation.
+            All settings must be provided as strings.
+            An empty string (``""``) sets the parameter to its default.
+
+            Values are given in this order:
+
+            * 0: AC magnitude for small-signal analysis. For example ``"33V"``. Default = "nan V".
+            * 1: AC phase for small-signal analysis. For example ``"44deg"``. Default = "0deg".
+            * 2: DC voltage. For example ``"1V"``. Default = "0V"
+            * 3: Power offset from zero watts. For example ``"1W"``. Default = "0W".
+            * 4: Available power of the source above VO. For example ``"3W"``. Default = "0W".
+            * 5: Frequency. For example ``"15GHz"``. Default = "1GHz".
+            * 6: Delay to start of sine wave. For example ``"16s"``. Default = "0s".
+            * 7: Damping factor (1/seconds). For example ``"2"``. Default = "0".
+            * 8: Phase delay. For example ``"18deg"``. Default = "0deg".
+            * 9: Frequency to use for harmonic balance analysis. For example ``"20Hz"``. Default = "0Hz".
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        # setting the defaults if no value is provided
+        defaults = ["nan V", "0deg", "0V", "0W", "0W", "1GHz", "0s", "0", "0deg", "0Hz"]
+        for i in range(len(settings)):
+            if settings[i] == "":
+                settings[i] = defaults[i]
+
+        id = self.modeler.components.create_unique_id()
+
+        arg1 = ["NAME:NexximSources",
+                ["NAME:NexximSources",
+                 ["NAME:Data",
+                  ["NAME:PowerSinusoidal"+str(id),
+                   "DataId:=", "Source"+str(id),
+                   "Type:=", 1,
+                   "Output:=", 2,
+                   "NumPins:=", 2,
+                   "Netlist:=", "V@ID %0 %1 *DC(DC=@DC) POWER SIN(?VO(@VO) ?POWER(@POWER) ?FREQ(@FREQ) ?TD(@TD) ?ALPHA(@ALPHA) ?THETA(@THETA)) *TONE(TONE=@TONE) *ACMAG(AC @ACMAG @ACPHASE)",
+                   "CompName:=", "Nexxim Circuit Elements\\Independent Sources:P_SIN",
+                   "FDSFileName:=", "",
+                   ["NAME:Properties",
+                    "TextProp:=", ["LabelID","HD","Property string for netlist ID","V@ID"],
+                    "ValueProp:=", ["ACMAG","OD","AC magnitude for small-signal analysis (Volts)",settings[0],0],
+                    "ValuePropNU:=", ["ACPHASE","OD","AC phase for small-signal analysis",settings[1],0,"deg"],
+                    "ValueProp:=", ["DC","OD","DC voltage (Volts)",settings[2],0],
+                    "ValuePropNU:=", ["VO","OD","Power offset from zero watts",settings[3],0,"W"],
+                    "ValueProp:=", ["POWER","OD","Available power of the source above VO",settings[4],0],
+                    "ValueProp:=", ["FREQ","OD","Frequency (Hz)",settings[5],0],
+                    "ValueProp:=", ["TD","OD","Delay to start of sine wave (seconds)",settings[6],0],
+                    "ValueProp:=", ["ALPHA","OD","Damping factor (1/seconds)",settings[7],0],
+                    "ValuePropNU:=", ["THETA","OD","Phase delay",settings[8],0,"deg"],
+                    "ValueProp:=", ["TONE","OD","Frequency (Hz) to use for harmonic balance analysis, should be a submultiple of (or equal to) the driving frequency and should also be included in the HB analysis setup",settings[9],0],
+                    "TextProp:=", ["ModelName","SHD","","P_SIN"],
+                    "ButtonProp:=", ["CosimDefinition","D","","Edit","Edit",40501,"ButtonPropClientData:=",[]],
+                    "MenuProp:=", ["CoSimulator","D","","DefaultNetlist",0]
+                    ]
+                   ]
+                  ]
+                 ]
+                ]
+
+        arg2 = ["NAME:ComponentConfigurationData"]
+
+        arg3 = ["NAME:ComponentConfigurationData", ["NAME:EnabledPorts", "PowerSinusoidal"+str(id)+":=", ports]]
+
+        arg2.append(arg3)
+
+        self.odesign.UpdateSources(arg1, arg2)
+        return True
