@@ -3,7 +3,7 @@ This module contains the `Desktop` class.
 
 This module is used to initialize AEDT and Message Manager to manage AEDT.
 
-You can initialize this module before launching an app or 
+You can initialize this module before launching an app or
 have the app automatically initialize it to the latest installed AEDT version.
 """
 from __future__ import absolute_import
@@ -15,9 +15,11 @@ import logging
 import pkgutil
 import getpass
 import re
+import warnings
+import gc
 from pyaedt.application.MessageManager import AEDTMessageManager
 from pyaedt.misc import list_installed_ansysem
-
+from pyaedt import is_ironpython, _pythonver, inside_desktop
 pathname = os.path.dirname(__file__)
 if os.path.exists(os.path.join(pathname,'version.txt')):
     with open(os.path.join(pathname,'version.txt'), "r") as f:
@@ -28,7 +30,6 @@ elif os.path.exists(os.path.join(pathname, "..", 'version.txt')):
 else:
     pyaedtversion = "X"
 
-_pythonver = sys.version_info[0]
 
 if os.name == 'nt':
     IsWindows = True
@@ -36,7 +37,7 @@ else:
     IsWindows = False
 logger = logging.getLogger(__name__)
 
-if "IronPython" in sys.version or ".NETFramework" in sys.version:
+if is_ironpython:
     import clr  # IronPython C:\Program Files\AnsysEM\AnsysEM19.4\Win64\common\IronPython\ipy64.exe
     _com = 'ironpython'
 elif IsWindows:
@@ -55,7 +56,7 @@ elif IsWindows:
 
 def exception_to_desktop(self, ex_value, tb_data):
     """Writes the trace stack to the desktop when a Python error occurs.
-    
+
     The message is added to the AEDT global Message Manager and to the log file (if present).
 
     Parameters
@@ -88,10 +89,10 @@ def exception_to_desktop(self, ex_value, tb_data):
 
 def update_aedt_registry(key, value, desktop_version="211"):
     """Update the AEDT registry key.
-    
+
     .. note::
        This method is only supported on Windows.
-    
+
     Parameters
     ----------
     key : str
@@ -99,25 +100,25 @@ def update_aedt_registry(key, value, desktop_version="211"):
     value : str
         Value for the registry key. The value includes "" if needed.
     desktop_version : str, optional
-        Version of AEDT to use. The default is ``"211"`` 
+        Version of AEDT to use. The default is ``"211"``
         to use 2021 R1.
-    
+
     Examples
     --------
     Update the HPC license type for HFSS in the AEDT registry.
-    
+
     >>> update_aedt_registry("HFSS/HPCLicenseType", "12") # doctest: +SKIP
-    
+
     Update the HPC license type for Icepak in the AEDT registry.
-    
+
     >>> update_aedt_registry("Icepak/HPCLicenseType", "8") # doctest: +SKIP
-    
+
     Update the legacy HPC license type for HFSS in the AEDT registry.
-    
+
     >>> update_aedt_registry("HFSS/UseLegacyElectronicsHPC", "0") # doctest: +SKIP
-    
+
     Update the MPI vendor for HFSS in the AEDT registry.
-    
+
     >>> update_aedt_registry("HFSS/MPIVendor", "Intel") # doctest: +SKIP
 
     """
@@ -136,6 +137,42 @@ def update_aedt_registry(key, value, desktop_version="211"):
 
     subprocess.call([command])
 
+def _delete_objects():
+    module = sys.modules['__main__']
+    if "COMUtil" in dir(module):
+        del module.COMUtil
+    if "Hfss" in dir(module):
+        del module.Hfss
+    if "Edb" in dir(module):
+        del module.Edb
+    if "Q3d" in dir(module):
+        del module.Q3d
+    if "Q2d" in dir(module):
+        del module.Q2d
+    if "Maxwell3d" in dir(module):
+        del module.Maxwell3d
+    if "Maxwell2d" in dir(module):
+        del module.Maxwell2d
+    if "Icepak" in dir(module):
+        del module.Icepak
+    if "Mechanical" in dir(module):
+        del module.Mechanical
+    if "Emit" in dir(module):
+        del module.Emit
+    if "Circuit" in dir(module):
+        del module.Circuit
+    if "Simplorer" in dir(module):
+        del module.Simplorer
+    if "Hfss3dLayout" in dir(module):
+        del module.Hfss3dLayout
+    if "oMessenger" in dir(module):
+        del module.oMessenger
+    if "oDesktop" in dir(module):
+        del module.oDesktop
+    if "pyaedt_initialized" in dir(module):
+        del module.pyaedt_initialized
+    gc.collect()
+
 
 def release_desktop(close_projects=True, close_desktop=True):
     """Release the AEDT API.
@@ -153,63 +190,35 @@ def release_desktop(close_projects=True, close_desktop=True):
         ``True`` when successful, ``False`` when failed.
 
     """
-    if _com == "pythonnet":
-        Module = sys.modules['__main__']
+
+    Module = sys.modules['__main__']
+    if "oDesktop" not in dir(Module):
+        _delete_objects()
+        return False
+    else:
         desktop = Module.oDesktop
-        scopeID = desktop.ScopeID
-        i = 0
         if close_projects:
             proj_list = desktop.GetProjectList()
             for prj in proj_list:
                 desktop.CloseProject(prj)
-
-        while i <= scopeID:
-            Module.COMUtil.ReleaseCOMObjectScope(Module.COMUtil.PInvokeProxyAPI, i)
-            i += 1
-        try:
-            del Module.oDesktop
-            return True
-        except:
-            Module.oMessenger.add_info_message("Attributes not present")
-            return False
-
-    elif _com == "pythonnet_v3":
-        Module = sys.modules['__main__']
-        desktop = Module.oDesktop
-        i = 0
-        if close_projects:
-            proj_list = desktop.GetProjectList()
-            for prj in proj_list:
-                desktop.CloseProject(prj)
-
-        if close_desktop:
-            scopeID = 5
-            while i <= scopeID:
-                Module.COMUtil.ReleaseCOMObjectScope(Module.COMUtil.PInvokeProxyAPI, 0)
-                i += 1
-            Module = sys.modules['__main__']
-            pid = Module.oDesktop.GetProcessID()
-            try:
-                os.kill(pid, 9)
-                del Module.oDesktop
-                return True
-            except:
-                Module.oMessenger.add_error_message("something went wrong in Closing AEDT")
-                return False
-        else:
+        pid = Module.oDesktop.GetProcessID()
+        if not (is_ironpython and inside_desktop):
+            i = 0
             scopeID = 5
             while i <= scopeID:
                 Module.COMUtil.ReleaseCOMObjectScope(Module.COMUtil.PInvokeProxyAPI,i)
                 i += 1
+            _delete_objects()
+
+        if close_desktop:
             try:
-                del Module.oDesktop
-            except:
-                Module.oMessenger.add_info_message("Attributes not present")
-            try:
-                del Module.pyaedt_initialized
+                os.kill(pid, 9)
+                _delete_objects()
                 return True
             except:
+                warnings.warn("Something went wrong in Closing AEDT")
                 return False
+    return True
 
 
 def force_close_desktop():
@@ -257,10 +266,9 @@ def force_close_desktop():
             return successfully_closed
 
 
-
 class Desktop:
     """Initializes AEDT based on the inputs provided.
-    
+
     .. note::
        On Windows, this class works without limitations in IronPython and CPython.
        On Linux, this class works only in embedded IronPython in AEDT.
@@ -271,10 +279,10 @@ class Desktop:
         Version of AEDT to use. The default is ``None``, in which case the
         active setup or latest installed version is used.
     NG: bool, optional
-        Whether to launch AEDT in the non-graphical mode. The default 
+        Whether to launch AEDT in the non-graphical mode. The default
         is ``False``, in which case AEDT is launched in the graphical mode.
     AlwaysNew : bool, optional
-        Whether to launch an instance of AEDT in a new thread, even if 
+        Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the machine.
         The default is ``True``.
     release_on_exit : bool, optional
@@ -300,9 +308,9 @@ class Desktop:
     pyaedt Info: pyaedt v...
     pyaedt Info: Python version ...
     >>> hfss = pyaedt.Hfss(designname="HFSSDesign1")
-    
+
     """
-            
+
     @property
     def version_keys(self):
         """Version keys for AEDT."""
@@ -342,7 +350,7 @@ class Desktop:
 
     @property
     def current_version_student(self):
-        """Current student version of AEDT. """
+        """Current student version of AEDT."""
         for el in self.version_keys:
             if "SV" in el:
                 return el
@@ -351,6 +359,8 @@ class Desktop:
     def __init__(self, specified_version=None, NG=False, AlwaysNew=True, release_on_exit=True, student_version=False):
         """Initialize desktop."""
         self._main = sys.modules['__main__']
+        self._main.interpreter = _com
+
         self._main.close_on_exit = False
         self._main.isoutsideDesktop = False
         self._main.pyaedt_version = pyaedtversion
@@ -389,7 +399,6 @@ class Desktop:
             else:
                 version = "Ansoft.ElectronicsDesktop." + version_key
             self._main.AEDTVersion = version_key
-            self._main.interpreter = _com
             self._main.interpreter_ver = _pythonver
             if "oDesktop" in dir(self._main):
                 del self._main.oDesktop
@@ -476,21 +485,25 @@ class Desktop:
                     self._main.isoutsideDesktop = True
                 elif version_key>="2021.1":
                     self._main.close_on_exit = True
-                    module_logger.debug("Info: {} Started with Process ID {}".format(version, proc[0]))
+                    module_logger.debug(
+                        "Info: {} Started with Process ID {}".format(version, proc[0]))
                     context = pythoncom.CreateBindCtx(0)
                     running_coms = pythoncom.GetRunningObjectTable()
                     monikiers = running_coms.EnumRunning()
                     for monikier in monikiers:
-                        m = re.search(version[10:]+r"\.\d:"+str(proc[0]), monikier.GetDisplayName(context, monikier))
+                        m = re.search(version[10:]+r"\.\d:"+str(proc[0]),
+                                      monikier.GetDisplayName(context, monikier))
                         if m:
                             obj = running_coms.GetObject(monikier)
                             self._main.isoutsideDesktop = True
                             # self._main.oDesktop = win32com.client.gencache.EnsureDispatch(
                             #     obj.QueryInterface(pythoncom.IID_IDispatch))
-                            self._main.oDesktop = win32com.client.Dispatch(obj.QueryInterface(pythoncom.IID_IDispatch))
+                            self._main.oDesktop = win32com.client.Dispatch(
+                                obj.QueryInterface(pythoncom.IID_IDispatch))
                             break
                 else:
-                    module_logger.warning("PyAEDT is not supported in AEDT versions older than 2021.1.")
+                    module_logger.warning(
+                        "PyAEDT is not supported in AEDT versions older than 2021.1.")
                     oAnsoftApp = win32com.client.Dispatch(version)
                     self._main.oDesktop = oAnsoftApp.GetAppDesktop()
                     self._main.isoutsideDesktop = True
@@ -550,7 +563,8 @@ class Desktop:
         if ex_type:
             err = self._exception(ex_value, ex_traceback)
         if self.release:
-            self.release_desktop(close_projects=self._main.close_on_exit, close_on_exit=self._main.close_on_exit)
+            self.release_desktop(close_projects=self._main.close_on_exit,
+                                 close_on_exit=self._main.close_on_exit)
 
     def _exception(self, ex_value, tb_data):
         """Write the trace stack to the desktop when a Python error occurs.
@@ -561,7 +575,7 @@ class Desktop:
             Type of the exception.
         tb_data : str
             Traceback data.
-            
+
         Returns
         -------
         str
@@ -594,10 +608,10 @@ class Desktop:
         Parameters
         ----------
         close_projects : bool, optional
-            Whether to close the AEDT projects opened in the session. 
+            Whether to close the AEDT projects opened in the session.
             The default is ``True``.
         close_on_exit : bool, optional
-            Whether to close the active AEDT session on exiting AEDT. 
+            Whether to close the active AEDT session on exiting AEDT.
             The default is ``True``.
 
         Examples
@@ -610,10 +624,14 @@ class Desktop:
 
         """
         release_desktop(close_projects, close_on_exit)
+        props = [a for a in dir(self) if not a.startswith('__')]
+        for a in props:
+            self.__dict__.pop(a, None)
+        gc.collect()
 
     def force_close_desktop(self):
         """Forcibly close all AEDT projects and shut down AEDT.
-    
+
         Examples
         --------
         >>> import pyaedt
@@ -627,7 +645,7 @@ class Desktop:
 
     def close_desktop(self):
         """Close all AEDT projects and shut down AEDT.
-    
+
         Examples
         --------
         >>> import pyaedt
