@@ -3,54 +3,51 @@
 This module is implicitily loaded in HFSS 3D Layout when launched.
 
 """
-
 import os
 import sys
 import traceback
 import warnings
-
-import pyaedt.edb_core.EDB_Data
+import gc
 import time
-try:
-    import ScriptEnv
-    ScriptEnv.Initialize("Ansoft.ElectronicsDesktop")
-    inside_desktop = True
-except:
-    inside_desktop = False
+if os.name == 'posix':
+    try:
+        import subprocessdotnet as subprocess
+    except:
+        warnings.warn("Pythonnet is needed to run pyaedt within Linux")
+else:
+    import subprocess
 try:
     import clr
     from System.Collections.Generic import List, Dictionary
     from System import Convert, String
     import System
-
     from System import Double, Array
     from System.Collections.Generic import List
-    _ironpython = False
-    if "IronPython" in sys.version or ".NETFramework" in sys.version:
-        _ironpython = True
     edb_initialized = True
 except ImportError:
-    warnings.warn("The clr is missing. Install Python.NET or use an IronPython version if you want to use the EDB module.")
+    warnings.warn(
+        "The clr is missing. Install Python.NET or use an IronPython version if you want to use the EDB module.")
     edb_initialized = False
 
+from pyaedt import is_ironpython, inside_desktop
+from pyaedt.application.MessageManager import EDBMessageManager
+from pyaedt.edb_core import *
 
-from .application.MessageManager import EDBMessageManager
-from .edb_core import *
+from pyaedt.generic.general_methods import env_path, env_value, env_path_student
+from pyaedt.generic.general_methods import generate_unique_name, aedt_exception_handler
+from pyaedt.generic.process import SiwaveSolve
 
-from .generic.general_methods import get_filename_without_extension, generate_unique_name, aedt_exception_handler, \
-    env_path, env_value, env_path_student, env_value_student
-from .generic.process import SiwaveSolve
 
 class Edb(object):
-    """EDB application interface.
+    """Provides the EDB application interface.
 
     This module inherits all objects that belong to EDB.
 
     Parameters
     ----------
     edbpath : str, optional
-        Full path to the ``aedb`` folder. The variable can also contain 
-        the path to a layout to import. Allowed formarts are BRD, 
+        Full path to the ``aedb`` folder. The variable can also contain
+        the path to a layout to import. Allowed formarts are BRD,
         XML (IPC2581), GDS, and DXF. The default is ``None``.
     cellname : str, optional
         Name of the cell to select. The default is ``None``.
@@ -72,25 +69,17 @@ class Edb(object):
     Create an `Edb` object and a new EDB cell.
 
     >>> from pyaedt import Edb
-    >>> app = Edb()     
+    >>> app = Edb()
 
     Create an `Edb` object and open the specified project.
 
     >>> app = Edb("myfile.aedb")
 
     """
-    def __init__(self, edbpath=None, cellname=None, isreadonly=False, edbversion="2021.1", isaedtowned=False, oproject=None, student_version=False):
-        self._components = None
-        self._core_primitives = None
-        self._stackup = None
-        self._padstack = None
-        self._siwave = None
-        self._hfss = None
-        self._nets = None
-        self._db = None
-        self._edb = None
-        self.builder = None
-        if _ironpython and inside_desktop:
+
+    def __init__(self, edbpath=None, cellname=None, isreadonly=False, edbversion="2021.1", isaedtowned=False, oproject=None, student_version=False,use_ppe=False):
+        self._clean_variables()
+        if is_ironpython and inside_desktop:
             self.standalone = False
         else:
             self.standalone = True
@@ -115,19 +104,34 @@ class Edb(object):
             # self._edb.Database.SetRunAsStandAlone(not isaedtowned)
             self.isreadonly = isreadonly
             self.cellname = cellname
+            if not edbpath:
+                if os.name != "posix":
+                    edbpath = os.getenv("USERPROFILE")
+                    if not edbpath:
+                        edbpath = os.path.expanduser("~")
+                    edbpath = os.path.join(edbpath, "Documents", generate_unique_name("layout")+".aedb")
+                else:
+                    edbpath = os.getenv("HOME")
+                    if not edbpath:
+                        edbpath = os.path.expanduser("~")
+                    edbpath = os.path.join(edbpath, generate_unique_name("layout")+".aedb")
+                self._messenger.add_info_message("No Edb Provided. Creating new EDB {}.".format(edbpath))
             self.edbpath = edbpath
-            if not os.path.exists(os.path.join(self.edbpath, "edb.def")):
+            if edbpath[-3:] in ["brd", "gds", "xml", "dxf", "tgz"]:
+                self.edbpath = edbpath[:-4] + ".aedb"
+                working_dir = os.path.dirname(edbpath)
+                self.import_layout_pcb(edbpath, working_dir, use_ppe=use_ppe)
+                self._messenger.add_info_message("Edb {} Created Correctly from {} file".format(self.edbpath, edbpath[-2:]))
+
+            elif not os.path.exists(os.path.join(self.edbpath, "edb.def")):
                 self.create_edb()
+                self._messenger.add_info_message("Edb {} Created Correctly".format(self.edbpath))
             elif ".aedb" in edbpath:
                 self.edbpath = edbpath
                 if isaedtowned and "isoutsideDesktop" in dir(self._main) and not self._main.isoutsideDesktop:
                     self.open_edb_inside_aedt()
                 else:
                     self.open_edb()
-            elif edbpath[-3:] in ["brd", "gds", "xml", "dxf"]:
-                self.edbpath = edbpath[-3:] + ".aedb"
-                working_dir = os.path.dirname(edbpath)
-                self.import_layout_pcb(edbpath, working_dir)
             if self.builder:
                 self._messenger.add_info_message("Edb Initialized")
             else:
@@ -135,8 +139,26 @@ class Edb(object):
         else:
             warnings.warn("Failed to initialize Dlls")
 
-
-
+    def _clean_variables(self):
+        """Initialize internal variables and perform garbage collection."""
+        self._components = None
+        self._core_primitives = None
+        self._stackup = None
+        self._padstack = None
+        self._siwave = None
+        self._hfss = None
+        self._nets = None
+        self._db = None
+        self._edb = None
+        self.builder = None
+        self.edblib = None
+        self.edbutils = None
+        self.simSetup = None
+        self.layout_methods = None
+        self.simsetupdata = None
+        if os.name == "posix":
+            clr.ClearProfilerData()
+        gc.collect()
 
     @aedt_exception_handler
     def _init_objects(self):
@@ -159,7 +181,7 @@ class Edb(object):
         ----------
         message_text : str
             Text to display as the info message.
-            
+
         Returns
         -------
         bool
@@ -178,14 +200,14 @@ class Edb(object):
     @aedt_exception_handler
     def add_warning_message(self, message_text):
         """Add a type 0 "Warning" message to the active design level of the Message Manager tree.
-        
+
         Also add an info message to the logger if the handler is present.
 
         Parameters
         ----------
         message_text : str
             Text to display as the warning message.
-        
+
         Returns
         -------
         bool
@@ -216,7 +238,7 @@ class Edb(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-             
+
 
         Examples
         --------
@@ -228,7 +250,6 @@ class Edb(object):
         self._messenger.add_error_message(message_text)
         return True
 
-
     @aedt_exception_handler
     def _init_dlls(self):
         """Initialize DLLs."""
@@ -246,7 +267,9 @@ class Edb(object):
             clr.AddReferenceToFile('Ansys.Ansoft.Edb.dll')
             clr.AddReferenceToFile('Ansys.Ansoft.EdbBuilderUtils.dll')
             clr.AddReferenceToFile('EdbLib.dll')
-            clr.AddReferenceToFileAndPath(os.path.join(self.base_path, 'Ansys.Ansoft.SimSetupData.dll'))
+            clr.AddReferenceToFile('DataModel.dll')
+            clr.AddReferenceToFileAndPath(os.path.join(
+                self.base_path, 'Ansys.Ansoft.SimSetupData.dll'))
         else:
             if self.student_version:
                 self.base_path = env_path_student(self.edbversion)
@@ -256,22 +279,22 @@ class Edb(object):
             clr.AddReference('Ansys.Ansoft.Edb')
             clr.AddReference('Ansys.Ansoft.EdbBuilderUtils')
             clr.AddReference('EdbLib')
+            clr.AddReference('DataModel')
             clr.AddReference('Ansys.Ansoft.SimSetupData')
         os.environ["ECAD_TRANSLATORS_INSTALL_DIR"] = self.base_path
         oaDirectory = os.path.join(self.base_path, 'common', 'oa')
         os.environ['ANSYS_OADIR'] = oaDirectory
         os.environ['PATH'] = '{};{}'.format(os.environ['PATH'], self.base_path)
-        edb =__import__('Ansys.Ansoft.Edb')
+        edb = __import__('Ansys.Ansoft.Edb')
 
         self.edb = edb.Ansoft.Edb
-        edbbuilder=__import__('Ansys.Ansoft.EdbBuilderUtils')
+        edbbuilder = __import__('Ansys.Ansoft.EdbBuilderUtils')
         self.edblib = __import__('EdbLib')
         self.edbutils = edbbuilder.Ansoft.EdbBuilderUtils
         self.simSetup = __import__('Ansys.Ansoft.SimSetupData')
         self.layout_methods = self.edblib.Layout.LayoutMethods
         self.simsetupdata = self.simSetup.Ansoft.SimSetupData.Data
 
-
     @aedt_exception_handler
     def open_edb(self, init_dlls=False):
         """Open EDB.
@@ -291,7 +314,7 @@ class Edb(object):
         self._messenger.add_info_message("EDB Version {}".format(self.edbversion))
         self.edb.Database.SetRunAsStandAlone(self.standalone)
         self._messenger.add_info_message("EDB Standalone {}".format(self.standalone))
-        db =  self.edb.Database.Open(self.edbpath, self.isreadonly)
+        db = self.edb.Database.Open(self.edbpath, self.isreadonly)
         if not db:
             self._messenger.add_warning_message("Error Opening db")
             self._db = None
@@ -299,11 +322,6 @@ class Edb(object):
             self.builder = None
             return None
         self._db = db
-        if not self._db:
-            self._messenger.add_warning_message("Error Opening DB")
-            self.builder = None
-            self._active_cell = None
-            return None
         self._messenger.add_info_message("Database Opened")
 
         self._active_cell = None
@@ -311,27 +329,32 @@ class Edb(object):
             for cell in list(self._db.TopCircuitCells):
                 if cell.GetName() == self.cellname:
                     self._active_cell = cell
-        else:
+        # if self._active_cell is still None, set it to default cell
+        if self._active_cell is None:
             self._active_cell = list(self._db.TopCircuitCells)[0]
         self._messenger.add_info_message("Cell {} Opened".format(self._active_cell.GetName()))
 
         if self._db and self._active_cell:
             time.sleep(1)
-            dllpath=os.path.join(os.path.abspath(os.path.dirname(__file__)), "dlls", "EDBLib", "DataModel.dll")
+            dllpath = os.path.join(os.path.abspath(os.path.dirname(__file__)),
+                                   "dlls", "EDBLib", "DataModel.dll")
             self._messenger.add_info_message(dllpath)
             self.layout_methods.LoadDataModel(dllpath)
             self.builder = self.layout_methods.GetBuilder(self._db, self._active_cell, self.edbpath,
                                                           self.edbversion,  self.standalone)
             self._init_objects()
+            self._messenger.add_info_message("Builder Initialized")
+
         else:
             self.builder = None
-        self._messenger.add_info_message("Builder Initialized")
+            self._messenger.add_error_message("Builder Not Initialized")
+
         return self.builder
 
     @aedt_exception_handler
     def open_edb_inside_aedt(self, init_dlls=False):
         """Open EDB inside of AEDT.
-        
+
         Parameters
         ----------
         init_dlls : bool, optional
@@ -355,21 +378,26 @@ class Edb(object):
                 self.builder = None
                 return None
             self._db = db
-            self._active_cell = self.edb.Cell.Cell.FindByName(self.db, self.edb.Cell.CellType.CircuitCell, self.cellname)
-            dllpath=os.path.join(os.path.abspath(os.path.dirname(__file__)), "dlls", "EDBLib", "DataModel.dll")
-            time.sleep(1)
+            self._active_cell = self.edb.Cell.Cell.FindByName(
+                self.db, self.edb.Cell.CellType.CircuitCell, self.cellname)
+            if self._active_cell is None:
+                self._active_cell = list(self._db.TopCircuitCells)[0]
+            dllpath = os.path.join(os.path.abspath(os.path.dirname(__file__)),
+                                   "dlls", "EDBLib", "DataModel.dll")
             if self._db and self._active_cell:
                 self.layout_methods.LoadDataModel(dllpath)
                 self.builder = self.layout_methods.GetBuilder(self._db, self._active_cell, self.edbpath,
                                                               self.edbversion, self.standalone, True)
                 self._init_objects()
                 return self.builder
+            else:
+                self.builder = None
+                return None
         else:
             self._db = None
             self._active_cell = None
             self.builder = None
             return None
-        return None
 
     @aedt_exception_handler
     def create_edb(self, init_dlls=False):
@@ -387,7 +415,7 @@ class Edb(object):
         if init_dlls:
             self._init_dlls()
         self.edb.Database.SetRunAsStandAlone(self.standalone)
-        db =  self.edb.Database.Create(self.edbpath)
+        db = self.edb.Database.Create(self.edbpath)
         if not db:
             self._messenger.add_warning_message("Error Creating db")
             self._db = None
@@ -397,19 +425,20 @@ class Edb(object):
         self._db = db
         if not self.cellname:
             self.cellname = generate_unique_name("Cell")
-        self._active_cell = self.edb.Cell.Cell.Create(self._db,  self.edb.Cell.CellType.CircuitCell, self.cellname)
-        time.sleep(1)
+        self._active_cell = self.edb.Cell.Cell.Create(
+            self._db,  self.edb.Cell.CellType.CircuitCell, self.cellname)
         dllpath = os.path.join(os.path.dirname(__file__), "dlls", "EDBLib", "DataModel.dll")
         if self._db and self._active_cell:
             self.layout_methods.LoadDataModel(dllpath)
-            self.builder = self.layout_methods.GetBuilder(self._db, self._active_cell, self.edbpath, self.edbversion, self.standalone)
+            self.builder = self.layout_methods.GetBuilder(
+                self._db, self._active_cell, self.edbpath, self.edbversion, self.standalone)
             self._init_objects()
             return self.builder
         self.builder = None
         return None
 
     @aedt_exception_handler
-    def import_layout_pcb(self, input_file, working_dir, init_dlls=False, anstranslator_full_path=None):
+    def import_layout_pcb(self, input_file, working_dir, init_dlls=False, anstranslator_full_path="", use_ppe=False):
         """Import a BRD file and generate an ``edb.def`` file in the working directory.
 
         Parameters
@@ -417,11 +446,14 @@ class Edb(object):
         input_file : str
             Full path to the BRD file.
         working_dir : str
-            Directory in which to create the ``aedb`` folder. The AEDB file name will be the 
+            Directory in which to create the ``aedb`` folder. The AEDB file name will be the
             same as the BRD file name.
         init_dlls : bool
             Whether to initialize DLLs. The default is ``False``.
-
+        anstranslator_full_path : str, optional
+            Whether to use or not PPE License. The default is ``False``.
+        use_ppe : bool
+            Whether to use or not PPE License. The default is ``False``.
         Returns
         -------
         str
@@ -438,7 +470,7 @@ class Edb(object):
         self._db = None
         if init_dlls:
             self._init_dlls()
-        aedb_name= os.path.splitext(os.path.basename(input_file))[0] + ".aedb"
+        aedb_name = os.path.splitext(os.path.basename(input_file))[0] + ".aedb"
         if anstranslator_full_path and os.path.exists(anstranslator_full_path):
             command = anstranslator_full_path
         else:
@@ -447,23 +479,18 @@ class Edb(object):
                 command += ".exe"
         if not working_dir:
             working_dir = os.path.dirname(input_file)
-
-
-        translatorSetup = self.edbutils.AnsTranslatorRunner(
-            input_file,
-            os.path.join(working_dir,aedb_name),
-            os.path.join(working_dir, "Translator.log"),
-            os.path.dirname(input_file),
-            True,
-            command)
-
-        if not translatorSetup.Translate():
+        cmd_translator = command + " " + input_file + " " + os.path.join(working_dir, aedb_name)
+        cmd_translator += " -l=" + os.path.join(working_dir, "Translator.log")
+        if not use_ppe:
+            cmd_translator += " -ppe=false"
+        p = subprocess.Popen(cmd_translator)
+        p.wait()
+        if not os.path.exists(os.path.join(working_dir,aedb_name)):
             self._messenger.add_error_message("Translator failed to translate.")
             return False
         self.edbpath = os.path.join(working_dir,aedb_name)
         return self.open_edb()
 
-
     def __enter__(self):
         return self
 
@@ -477,9 +504,9 @@ class Edb(object):
         Parameters
         ----------
         ex_value :
-            
+
         tb_data :
-            
+
 
         Returns
         -------
@@ -493,59 +520,14 @@ class Edb(object):
 
     @property
     def db(self):
-        """ """
-        # if self.builder:
-        #     self._db = self.builder.EdbHandler.dB
-        #     return self._db
-        # else:
-        #     self.db = self.edbpath
+        """Db object."""
         return self._db
 
-    # @db.setter
-    # def db(self, edbpath):
-    #     # if self.edb_core:
-    #     #     if os.path.exists(os.path.join(edbpath, "edb.def")):
-    #     #         self._db = self.edb_core.Database.Open(edbpath, self.isreadonly)
-    #     #     else:
-    #     #         self._db = None
-    #     #         self._messenger.add_error_message("Edb path not found")
-    #     try:
-    #         if self.oproject:
-    #             if self._main.isoutsideDesktop:
-    #                 self._messenger.add_info_message("Opening EDB from File")
-    #                 self.edb_core.Database.SetRunAsStandAlone(True)
-    #                 if self.edbutils:
-    #                     if os.path.exists(os.path.join(edbpath, "edb.def")):
-    #                         self.builder = self.edbutils.HfssUtilities(edbpath)
-    #                         self._db = self.builder.dB
-    #                     else:
-    #                         self._db = None
-    #                         self._messenger.add_warning_message("Edb path not found")
-    #             else:
-    #                 self._messenger.add_info_message("Opening EDB from HDL")
-    #                 self.edb_core.Database.SetRunAsStandAlone(False)
-    #                 hdl = Convert.ToUInt64(self.oproject.GetEDBHandle())
-    #                 self._db = self.edb_core.Database.Attach(hdl)
-    #
-    #         else:
-    #             self.edb_core.Database.SetRunAsStandAlone(True)
-    #             if self.edbutils:
-    #                 if os.path.exists(os.path.join(edbpath, "edb.def")):
-    #                     self.builder = self.edbutils.HfssUtilities(edbpath)
-    #                     self._db = self.builder.dB
-    #                 else:
-    #                     self._db = None
-    #                     self._messenger.add_warning_message("Edb path not found")
-    #         self.active_cell = self.cellname
-    #     except:
-    #         self._db = None
-
     @property
     def active_cell(self):
         """Active cell."""
         return self._active_cell
 
-
     @property
     def core_components(self):
         """Core components."""
@@ -609,13 +591,13 @@ class Edb(object):
     @property
     def pins(self):
         """Pins.
-        
+
         Returns
         -------
         list
             List of all pins.
         """
-        
+
         pins=[]
         if self.core_components:
             for el in self.core_components.components:
@@ -625,33 +607,32 @@ class Edb(object):
                 pins += temp
         return pins
 
-
-
     class Boundaries:
         """Boundaries.
-        
+
         Parameters
         ----------
         Port :
-        
+
         Pec :
-        
+
         RLC :
-        
+
         CurrentSource :
-        
+
         VoltageSource :
-        
+
         NexximGround :
-        
+
         NexximPort :
-        
+
         DcTerminal :
-        
+
         VoltageProbe :
-        
+
         """
-        (Port, Pec, RLC, CurrentSource, VoltageSource, NexximGround, NexximPort, DcTerminal, VoltageProbe) = range(0, 9)
+        (Port, Pec, RLC, CurrentSource, VoltageSource, NexximGround,
+         NexximPort, DcTerminal, VoltageProbe) = range(0, 9)
 
     @aedt_exception_handler
     def edb_value(self, val):
@@ -660,7 +641,7 @@ class Edb(object):
         Parameters
         ----------
         val :
-            
+
 
         Returns
         -------
@@ -671,25 +652,32 @@ class Edb(object):
     @aedt_exception_handler
     def close_edb(self):
         """Close EDB.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self._db.Close()
+
+        self._clean_variables()
+        props = [a for a in dir(self) if not a.startswith('__')]
+
+        for a in props:
+            self.__dict__.pop(a, None)
+        gc.collect()
         return True
 
     @aedt_exception_handler
     def save_edb(self):
         """Save the EDB file.
-        
+
        Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-       
+
        """
         self._db.Save()
         return True
@@ -720,7 +708,7 @@ class Edb(object):
         ----------
         func : str
             Function to execute.
-            
+
 
         Returns
         -------
@@ -730,9 +718,8 @@ class Edb(object):
         """
         return self.edb.Utility.Command.Execute(func)
 
-
     @aedt_exception_handler
-    def import_cadence_file(self, inputBrd, WorkDir=None):
+    def import_cadence_file(self, inputBrd, WorkDir=None, anstranslator_full_path="", use_ppe=False):
         """Import a BRD file and generate an ``edb.def`` file in the working directory.
 
         Parameters
@@ -740,22 +727,26 @@ class Edb(object):
         inputBrd : str
             Full path to the BRD file.
         WorkDir : str
-            Directory in which to create the ``aedb`` folder. The AEDB file name will be 
+            Directory in which to create the ``aedb`` folder. The AEDB file name will be
             the same as the BRD file name. The default value is ``None``.
-
+        anstranslator_full_path: str, Optional
+            Optional AnsTranslator full path.
+        use_ppe : bool
+            Whether to use or not PPE License. The default is ``False``.
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
 
         """
-        if self.import_layout_pcb(inputBrd, working_dir=WorkDir):
+        if self.import_layout_pcb(inputBrd, working_dir=WorkDir, anstranslator_full_path=anstranslator_full_path,
+                                  use_ppe=use_ppe):
             return True
         else:
             return False
 
     @aedt_exception_handler
-    def import_gds_file(self, inputGDS, WorkDir=None):
+    def import_gds_file(self, inputGDS, WorkDir=None, anstranslator_full_path="", use_ppe=False):
         """Import a GDS file and generate an ``edb.def`` file in the working directory.
 
         Parameters
@@ -763,16 +754,20 @@ class Edb(object):
         inputGDS : str
             Full path to the GDS file.
         WorkDir : str
-            Directory in which to create the ``aedb`` folder. The AEDB file name will be 
+            Directory in which to create the ``aedb`` folder. The AEDB file name will be
             the same as the GDS file name. The default value is ``None``.
-
+        anstranslator_full_path: str, Optional
+            Optional AnsTranslator full path.
+        use_ppe : bool
+            Whether to use or not PPE License. The default is ``False``.
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
 
         """
-        if self.import_layout_pcb(inputGDS, working_dir=WorkDir):
+        if self.import_layout_pcb(inputGDS, working_dir=WorkDir, anstranslator_full_path=anstranslator_full_path,
+                                  use_ppe=use_ppe):
             return True
         else:
             return False
@@ -788,7 +783,7 @@ class Edb(object):
         reference_list : list, optional
             List of references to add. The default is ``["GND"]``.
         extent_type : str, optional
-            Type of the extension. Options are ``"Conforming"`` and 
+            Type of the extension. Options are ``"Conforming"`` and
             ``"Bounding"``. The default is ``"Conforming"``.
         expansion_size : float, optional
             Expansion size ratio in meters. The default is ``0.002``.
@@ -797,8 +792,8 @@ class Edb(object):
         output_aedb_path : str, optional
             Full path and name for the new AEDB file.
         replace_design_with_cutout : bool, optional
-            Whether to replace the design with the cutout. The default 
-            is ``True``.      
+            Whether to replace the design with the cutout. The default
+            is ``True``.
 
         Returns
         -------
@@ -818,7 +813,6 @@ class Edb(object):
             _netobj = self.edb.Cell.Net.FindByName(self.active_layout, _ref)
             _ref_nets.append(_netobj)
 
-
         from .edb_core.general import convert_py_list_to_net_list
         _netsClip = [self.edb.Cell.Net.FindByName(self.active_layout, reference_list[i]) for i, p in
                      enumerate(reference_list)]
@@ -839,14 +833,19 @@ class Edb(object):
                                                            use_round_corner,
                                                            1)
 
-        _cutout = self.active_cell.CutOut(net_signals, _netsClip, _poly)  # Create new cutout cell/design
+        # Create new cutout cell/design
+        _cutout = self.active_cell.CutOut(net_signals, _netsClip, _poly)
 
-        for _setup in self.active_cell.SimulationSetups:  # The analysis setup(s) do not come over with the clipped design copy, so add the analysis setup(s) from the original here
-            _setup_name = _setup.GetName()  # Empty string '' if coming from setup copy and don't set explicitly.
+        # The analysis setup(s) do not come over with the clipped design copy, so add the analysis setup(s) from the original here
+        for _setup in self.active_cell.SimulationSetups:
+            # Empty string '' if coming from setup copy and don't set explicitly.
+            _setup_name = _setup.GetName()
             if "GetSimSetupInfo" in dir(_setup):
-                _hfssSimSetupInfo = _setup.GetSimSetupInfo()  # setup is an Ansys.Ansoft.Edb.Utility.HFSSSimulationSetup object
+                # setup is an Ansys.Ansoft.Edb.Utility.HFSSSimulationSetup object
+                _hfssSimSetupInfo = _setup.GetSimSetupInfo()
                 _hfssSimSetupInfo.Name = 'HFSS Setup 1'  # Set name of analysis setup
-                _setup.SetSimSetupInfo(_hfssSimSetupInfo)  # Write the simulation setup info into the cell/design setup
+                # Write the simulation setup info into the cell/design setup
+                _setup.SetSimSetupInfo(_hfssSimSetupInfo)
                 _cutout.AddSimulationSetup(_setup)  # Add simulation setup to the cutout design
 
         _dbCells = [_cutout]
@@ -869,14 +868,14 @@ class Edb(object):
     @aedt_exception_handler
     def write_export3d_option_config_file(self, path_to_output, config_dictionaries=None):
         """Write the options for a 3D export to a configuration file.
-        
+
         Parameters
         ----------
         path_to_output : str
             Full path to the configuration file where the 3D export options are to be saved.
-        
+
         config_dictionaries : dict, optional
-        
+
         """
         option_config = {
             "UNITE_NETS": 1,
@@ -961,13 +960,12 @@ class Edb(object):
         >>> edb.write_export3d_option_config_file(r"C:\temp", options_config)
         >>> edb.export_q3d(r"C:\temp")
         "C:\\temp\\q3d_siwave.aedt"
-        
+
         """
 
         siwave_s = SiwaveSolve(self.edbpath, aedt_installer_path=self.base_path)
         return siwave_s.export_3d_cad("Q3D", path_to_output, net_list)
 
-
     @aedt_exception_handler
     def export_maxwell(self, path_to_output, net_list=None):
         """Export EDB to Maxwell 3D.
@@ -996,7 +994,7 @@ class Edb(object):
         >>> edb.write_export3d_option_config_file(r"C:\temp", options_config)
         >>> edb.export_maxwell(r"C:\temp")
         "C:\\temp\\maxwell_siwave.aedt"
-        
+
         """
         siwave_s = SiwaveSolve(self.edbpath, aedt_installer_path=self.base_path)
         return siwave_s.export_3d_cad("Maxwell", path_to_output, net_list)
