@@ -4,6 +4,7 @@ from .components import Components
 from .hfss import Edb3DLayout
 from .nets import EdbNets
 from .padstack import EdbPadstacks
-from .siwave import EdBSiwave
+from .siwave import EdbSiwave
 from .stackup import EdbStackup
-from .layout import EdbLayout
\ No newline at end of file
+from .layout import EdbLayout
+
