@@ -108,7 +108,7 @@ class EdbStackup(object):
             Dictionary of materials.
         """
         mats = {}
-        for el in self.parent.edbutils.MaterialSetupInfo.GetFromLayout(self.parent._active_layout):
+        for el in self.parent.edbutils.MaterialSetupInfo.GetFromLayout(self.parent.active_layout):
             mats[el.Name] = el
         return mats
 
@@ -138,7 +138,6 @@ class EdbStackup(object):
             return material_def
         return False
 
-
     @aedt_exception_handler
     def create_conductor(self, name, conductivity=1e6):
         """Create a conductor with simple properties.
@@ -199,7 +198,6 @@ class EdbStackup(object):
                                                               self._edb_value(relative_permittivity_high))
         return self._add_dielectric_material_model(name, material_def)
 
-
     @aedt_exception_handler
     def create_djordjevicsarkar_material(self, name, relative_permittivity, loss_tangent, test_frequency):
         """Create a Djordjevic_Sarkar dielectric.
