@@ -2,7 +2,10 @@
 import shutil
 import os
 import sys
-if "IronPython" in sys.version or ".NETFramework" in sys.version:
+import zipfile,os.path
+
+from pyaedt import is_ironpython
+if is_ironpython:
     import urllib
 else:
     import urllib.request
@@ -17,7 +20,7 @@ EXAMPLES_PATH = os.path.join(tmpfold, "PyAEDTExamples")
 
 
 def delete_downloads():
-    """Delete all downloaded examples to free space or update the files"""
+    """Delete all downloaded examples to free space or update the files."""
     shutil.rmtree(EXAMPLES_PATH, ignore_errors=True)
 
 
@@ -37,7 +40,7 @@ def _retrieve_file(url, filename, directory):
         return local_path_no_zip
 
     # grab the correct url retriever
-    if "IronPython" in sys.version or ".NETFramework" in sys.version:
+    if is_ironpython:
         urlretrieve = urllib.urlretrieve
     else:
         urlretrieve = urllib.request.urlretrieve
@@ -68,12 +71,15 @@ def _download_file(directory, filename):
 
 def download_aedb():
     """Download an example of AEDB File and return the def path.
+
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
+
     Returns
     -------
     str
         Path to the example file.
+
     Examples
     --------
     Download an example result file and return the path of the file
@@ -90,13 +96,16 @@ def download_netlist():
     """Download an example of netlist File and return the def path.
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
+
     Returns
     -------
     str
         Path to the example file.
+
     Examples
     --------
     Download an example result file and return the path of the file
+
     >>> from pyaedt import examples
     >>> path = examples.download_netlist()
     >>> path
@@ -107,15 +116,20 @@ def download_netlist():
 
 def download_antenna_array():
     """Download an example of Antenna Array and return the def path.
+
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
+
     Returns
     -------
     str
         Path to the example file.
+
     Examples
     --------
+
     Download an example result file and return the path of the file
+
     >>> from pyaedt import examples
     >>> path = examples.download_antenna_array()
     >>> path
@@ -126,15 +140,19 @@ def download_antenna_array():
 
 def download_sbr():
     """Download an example of SBR+ Array and return the def path.
+
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
+
     Returns
     -------
     str
         Path to the example file.
+
     Examples
     --------
     Download an example result file and return the path of the file
+
     >>> from pyaedt import examples
     >>> path = examples.download_antenna_array()
     >>> path
@@ -143,14 +161,40 @@ def download_sbr():
 
     return _download_file('sbr', 'Cassegrain.aedt')
 
-def download_touchstone():
-    """Download an example of touchstone File and return the def path.
+def download_icepak():
+    """Download an example of Icepak Array and return the def path.
+
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
+
     Returns
     -------
     str
         Path to the example file.
+
+    Examples
+    --------
+    Download an example result file and return the path of the file
+
+    >>> from pyaedt import examples
+    >>> path = examples.download_icepak()
+    >>> path
+    'C:/Users/user/AppData/local/temp/pyaedtexamples/Graphic_Card.aedt'
+    """
+
+    return _download_file('icepak', 'Graphics_card.aedt')
+
+def download_touchstone():
+    """Download an example of touchstone File and return the def path.
+
+    Examples files are downloaded to a persistent cache to avoid
+    re-downloading the same file twice.
+
+    Returns
+    -------
+    str
+        Path to the example file.
+
     Examples
     --------
     Download an example result file and return the path of the file
@@ -165,15 +209,19 @@ def download_touchstone():
 
 def download_sherlock():
     """Download an example of sherlock needed files and return the def path.
+
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
+
     Returns
     -------
     str
         Path to the example file.
+
     Examples
     --------
     Download an example result file and return the path of the file
+
     >>> from pyaedt import examples
     >>> path = examples.download_sherlock()
     >>> path
@@ -187,3 +235,46 @@ def download_sherlock():
 
     return os.path.join(EXAMPLES_PATH, "sherlock")
 
+def download_multiparts():
+    """Download an example of 3DComponents Multiparts.
+
+    Examples files are downloaded to a persistent cache to avoid
+    re-downloading the same file twice.
+
+    Returns
+    -------
+    str
+        Path to the example file.
+
+    Examples
+    --------
+    Download an example result file and return the path of the file
+
+    >>> from pyaedt import examples
+    >>> path = examples.download_multiparts()
+    >>> path
+    'C:/Users/user/AppData/local/temp/multiparts/library'
+    """
+    _download_file('multiparts', 'library.zip')
+    dest_folder = os.path.join(EXAMPLES_PATH, "multiparts")
+    unzip(os.path.join(EXAMPLES_PATH, "multiparts", 'library.zip'), dest_folder)
+    return os.path.join(dest_folder,"library")
+
+def unzip(source_filename, dest_dir):
+    with zipfile.ZipFile(source_filename) as zf:
+        zf.extractall(dest_dir)
+        # for member in zf.infolist():
+        #     # Path traversal defense copied from
+        #     # http://hg.python.org/cpython/file/tip/Lib/http/server.py#l789
+        #     words = member.filename.split('/')
+        #     path = dest_dir
+        #     for word in words[:-1]:
+        #         while True:
+        #             drive, word = os.path.splitdrive(word)
+        #             head, word = os.path.split(word)
+        #             if not drive:
+        #                 break
+        #         if word in (os.curdir, os.pardir, ''):
+        #             continue
+        #         path = os.path.join(path, word)
+        #     zf.extract(member, path)
\ No newline at end of file
