@@ -112,9 +112,9 @@ class AedtSolve(object):
 
     def solve(self):
         if os.name == "posix":
-                self.command.append(os.path.join(self.installer_path,'ansysedt'))
+            self.command.append(os.path.join(self.installer_path,'ansysedt'))
         else:
-               self.command.append(os.path.join(self.installer_path,'ansysedt.exe'))
+            self.command.append(os.path.join(self.installer_path,'ansysedt.exe'))
         if self.nongraphical:
             self.command.append('-Batchsolve')
             self.command.append('-ng')
@@ -155,7 +155,6 @@ class SiwaveSolve(object):
         else:
             self._exe = os.path.join(self.installer_path, executable+'.exe')
 
-
     @property
     def siwave_exe(self):
         return self._exe
@@ -202,7 +201,7 @@ class SiwaveSolve(object):
             if os.name == "posix":
                 exe_path = os.path.join(self.installer_path, 'siwave_ng')
             else:
-                 exe_path = os.path.join(self.installer_path, 'siwave_ng.exe')     
+                exe_path = os.path.join(self.installer_path, 'siwave_ng.exe')
             exec_file = os.path.splitext(self._project_path)[0] + '.exec'
             if os.path.exists(exec_file):
                 with open(exec_file,"r+") as f:
@@ -211,7 +210,8 @@ class SiwaveSolve(object):
                         f.writelines(str.format('SetNumCpus {}', str(self.nbcores)) + '\n')
                         f.writelines("SaveSiw")
                     else:
-                        fstarts = [i for i in range(len(content)) if content[i].startswith('SetNumCpus')]
+                        fstarts = [i for i in range(len(content))
+                                                    if content[i].startswith('SetNumCpus')]
                         content[fstarts[0]] = str.format('SetNumCpus {}', str(self.nbcores))
                         f.close()
                         os.remove(exec_file)
@@ -257,7 +257,8 @@ class SiwaveSolve(object):
                 f.write("    if allnets[i] != 'DUMMY':\n")
                 f.write("        oDoc.ScrSelectNet(allnets[i], 1)\n")
             f.write("oDoc.ScrSetOptionsFor3DModelExport(exportOptions)\n")
-            f.write("q3d_filename = os.path.join(r'{}', '{}')\n".format(output_folder, format_3d+"_siwave.aedt"))
+            f.write("q3d_filename = os.path.join(r'{}', '{}')\n".format(
+                output_folder, format_3d+"_siwave.aedt"))
             f.write("oDoc.ScrExport3DModel('{}', q3d_filename)\n".format(format_3d))
             f.write("oDoc.ScrCloseProject()\n")
             f.write("oApp.Quit()\n")
@@ -272,5 +273,3 @@ class SiwaveSolve(object):
         os.system(" ".join(command))
 
         return os.path.join(output_folder, format_3d+"_siwave.aedt")
-
-
