@@ -1,4 +1,4 @@
-"""This module contains these classes: `Hfss3dLayout` and `SweepString`."""
+"""This module contains these classes: `Hfss3dLayout`."""
 
 from __future__ import absolute_import
 import os
@@ -9,74 +9,8 @@ from .modules.SolveSetup import Setup3DLayout
 from .generic.general_methods import generate_unique_name, aedt_exception_handler
 
 
-
-class SweepString(object):
-    """Generates a sweep string.
-    
-    For example, ``"LIN 10GHz 20GHz 0.05GHz LINC 20GHz 30GHz 10 DEC 30GHz 40GHz 10 40GHz``.
-    
-    Parameters
-    ----------
-    unit : str, optional
-        Units for the sweep string. The default is ``"GHz"``.
-     """
-        
-    def __init__(self, unit='GHz'):
-    
-        self.unit = unit
-        self.sweep_string = ""
-
-    @aedt_exception_handler
-    def add_sweep(self, sweep, line_type, unit=None):
-        """Add a line to the sweep string.
-
-        Parameters
-        ----------
-        sweep : list
-            List of frequencies,
-            if linear_step [start, stop, step]
-            if linear_count [start, stop, number of steps]
-            if log_scale [start, stop, samples]
-            if single [f1, f2,... fn]
-        line_type :
-            linear_step", "linear_count", "log_scale", "single"
-        unit : str
-            Units such as ``"MHz"`` or ``"GHz"``. The default is ``None``.
-
-        Returns
-        -------
-
-        """
-        if not unit:
-            unit = self.unit
-        if self.sweep_string != "":
-            self.sweep_string += " "
-        if line_type == "linear_step" and len(sweep) == 3:
-            string = "LIN " + str(sweep[0]) + unit + " " + str(sweep[1]) + unit + " " + str(sweep[2]) + unit
-        elif line_type == "linear_count" and len(sweep) == 3:
-            string = "LINC " + str(sweep[0]) + unit + " " + str(sweep[1]) + unit + " " + str(sweep[2])
-        elif line_type == "log_scale" and len(sweep) == 3:
-            string = "DEC " + str(sweep[0]) + unit + " " + str(sweep[1]) + unit + " " + str(sweep[2])
-        elif line_type == "single":
-            string = ""
-            for f in sweep:
-                string += str(f) + unit + " "
-            string = string[:-1]
-        else:
-            raise ValueError('Wrong format for sweep list!')
-        self.sweep_string += string
-
-    @aedt_exception_handler
-    def get_string(self):
-        """ """
-        if self.sweep_string:
-            return self.sweep_string
-        else:
-            return None
-
-
 class Hfss3dLayout(FieldAnalysis3DLayout):
-    """HFSS 3D Layout application interface.
+    """Provides the HFSS 3D Layout application interface.
 
     This class inherits all objects that belong to HFSS 3D Layout, including EDB
     API queries.
@@ -86,10 +20,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
     projectname : str, optional
         Name of the project to select or the full path to the project
         or AEDTZ archive to open.  The default is ``None``, in which
-        case an attempt is made to get an active project. If no 
+        case an attempt is made to get an active project. If no
         projects are present, an empty project is created.
     designname : str, optional
-        Name of the design to select. The default is ``None``, in 
+        Name of the design to select. The default is ``None``, in
         which case an attempt is made to get an active design. If no
         designs are present, an empty design is created.
     solution_type : str, optional
@@ -97,20 +31,20 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         ``None``, in which case the default type is applied.
     setup_name : str, optional
         Name of the setup to use as the nominal. The default is
-        ``None``, in which case the active setup is used or 
+        ``None``, in which case the active setup is used or
         nothing is used.
     specified_version : str, optional
         Version of AEDT to use. The default is ``None``, in which case
         the active version or latest installed version is used.
     NG : bool, optional
-        Whether to launch AEDT in the non-graphical mode. The default 
-        is``False``, in which case AEDT is launched in the graphical mode.  
+        Whether to launch AEDT in the non-graphical mode. The default
+        is``False``, in which case AEDT is launched in the graphical mode.
     AlwaysNew : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``.
     release_on_exit : bool, optional
-        Whether to release AEDT on exit. 
+        Whether to release AEDT on exit.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is ``False``.
 
@@ -141,8 +75,9 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
     `Hfss3dLayout` object and open the specified project.
 
     >>> aedtapp = Hfss3dLayout(specified_version="2021.1", projectname="myfile.aedt")
-    
+
     """
+
     def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
                  specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
         FieldAnalysis3DLayout.__init__(self, "HFSS 3D Layout Design", projectname, designname, solution_type,
@@ -180,8 +115,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             ["NAME:Contents", "edge:=", ["et:=", "pe", "prim:=", primivitivename, "edge:=", edgenumber], "circuit:=",
              iscircuit, "btype:=", 0])
         listnew = self.port_list
-        a=[i for i in listnew if i not in listp]
-        if len(a)>0:
+        a = [i for i in listnew if i not in listp]
+        if len(a) > 0:
             return a[0]
         else:
             return False
@@ -215,7 +150,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         str
             Name of the port when successful, ``False`` when failed.
-        
+
         """
         listp = self.port_list
         if type(layer) is str:
@@ -248,7 +183,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         rotation : float, optional
             Rotation of the pin in degrees. The default is ``0``.
         top_layer : str, optional
-            Top layer of the pin. The default is ``None``, in which case the top 
+            Top layer of the pin. The default is ``None``, in which case the top
             layer is assigned automatically.
         bot_layer : str
             Bottom layer of the pin. The default is ``None``, in which case the
@@ -258,7 +193,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self.modeler.layers.refresh_all_layers()
         layers = self.modeler.layers.all_signal_layers
@@ -275,7 +210,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
                 ],
                 "ReferencedPadstack:="	, "Padstacks:NoPad SMT East",
                 "vposition:=",
-                ["x:=", str(xpos) + self.modeler.model_units, "y:=", str(ypos) + self.modeler.model_units],
+                ["x:=", str(xpos) + self.modeler.model_units, "y:=",
+                            str(ypos) + self.modeler.model_units],
                 "vrotation:="		, [str(rotation) + "deg"],
                 "overrides hole:="	, False,
                 "hole diameter:="	, ["0mm"],
@@ -292,13 +228,13 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         Parameters
         ----------
         portname : str
-            Name of the port.          
+            Name of the port.
 
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self.oexcitation.Delete(portname)
         return True
@@ -311,12 +247,12 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         ----------
         edb_full_path : str
             Full path to EDB.
-            
+
         Returns
         -------
         bool
-            ``True`` when successful, ``False`` when failed. 
-        
+            ``True`` when successful, ``False`` when failed.
+
         """
         oTool = self.odesktop.GetTool("ImportExport")
         oTool.ImportEDB(edb_full_path)
@@ -441,7 +377,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         Families = ["Freq:=", ["All"]]
         if variations:
@@ -454,7 +390,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             port_names = self.get_excitations_name
         if not port_excited:
             port_excited= port_names
-        Trace = ["X Component:=", "Freq", "Y Component:=", ["dB(S(" + p + "," + q + "))" for p,q in zip(list(port_names), list(port_excited))]]
+        Trace = ["X Component:=", "Freq", "Y Component:=", [
+            "dB(S(" + p + "," + q + "))" for p,q in zip(list(port_names), list(port_excited))]]
         solution_data = ""
         if self.solution_type == "DrivenModal":
             solution_data = "Modal Solution Data"
@@ -480,11 +417,11 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
     @aedt_exception_handler
     def export_touchstone(self, solutionname, sweepname, filename, variation, variations_value):
         """Export a Touchstone file.
-        
+
         Parameters
         ----------
         solutionname : str
-            Name of the solution that has been solved.    
+            Name of the solution that has been solved.
         sweepname : str
             Name of the sweep that has been solved.
         filename : str
@@ -498,7 +435,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         # normalize the save path
         if not filename:
@@ -506,7 +443,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             for v, vv in zip(variation, variations_value):
                 appendix += "_" + v + vv.replace("\'", "")
             ext = ".S" + str(len(self.port_list)) + "p"
-            filename = os.path.join(self.project_path, solutionname + "_" + sweepname + appendix + ext)
+            filename = os.path.join(self.project_path, solutionname + \
+                                    "_" + sweepname + appendix + ext)
         else:
             filename = filename.replace("//", "/").replace("\\", "/")
         print("Exporting Touchstone " + filename)
@@ -516,7 +454,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         # 7=Matlab (.m), 8=Terminal Z0 spreadsheet
         FileFormat = 3
         OutFile = filename  # full path of output file
-        FreqsArray = ["all"]  # array containin the frequencies to export, use ["all"] for all frequencies
+        # array containin the frequencies to export, use ["all"] for all frequencies
+        FreqsArray = ["all"]
         DoRenorm = True  # perform renormalization before export
         RenormImped = 50  # Real impedance value in ohm, for renormalization
         DataType = "S"  # Type: "S", "Y", or "Z" matrix to export
@@ -550,7 +489,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         settings = []
         if activate:
@@ -589,16 +528,21 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         sweepname : str, optional
             Name of the sweep. The default is ``None``.
         sweeptype : str, optional
-            Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, and ``"Discrete"``. 
-            The default is ``"Interpolating"``.
+            Type of the sweep. Options are ``"Fast"``,
+            ``"Interpolating"``, and ``"Discrete"``.  The default is
+            ``"Interpolating"``.
         interpolation_tol_percent : float, optional
-            Error tolerance threshold for the interpolation process. The default is ``0.5``.
+            Error tolerance threshold for the interpolation
+            process. The default is ``0.5``.
         interpolation_max_solutions : int, optional
-            Maximum number of solutions evaluated for the interpolation process. The default is ``250``.
+            Maximum number of solutions evaluated for the
+            interpolation process. The default is ``250``.
         save_fields : bool, optional
-            Whether to save the fields for a discrete sweep only. The default is ``True``.
+            Whether to save the fields for a discrete sweep only. The
+            default is ``True``.
         save_rad_fields_only : bool, optional
-            Whether to save only the radiated fields if ``save_fields=True``. The default is ``False``.
+            Whether to save only the radiated fields if
+            ``save_fields=True``. The default is ``False``.
         use_q3d_for_dc : bool, optional
             Whether to use Q3D to solve the DC point. The default is ``False``.
 
@@ -606,7 +550,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         str
             Name of the setup when successful, ``False`` otherwise.
-        
+
         """
         if sweepname is None:
             sweepname = generate_unique_name("Sweep")
@@ -618,65 +562,21 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         if not save_fields:
             save_rad_fields_only = False
         interpolation_tol = interpolation_tol_percent / 100.
-        sweep = SweepString()
-        sweep.add_sweep([freqstart, freqstop, num_of_freq_points], "linear_count", unit)
-        # the add_sweep function supports all sweeps type e.g.
-        #   sweep.add_sweep([10, 20, 1], "linear_step", "MHz")
-        #   sweep.add_sweep([1, 1000, 100], "log_scale", "kHz")
-        #   sweep.add_sweep([7,13,17,19,23], "single", unit)
-        sweep_string = sweep.get_string()
         setup = self.get_setup(setupname)
         if sweepname in [name.name for name in setup.sweeps]:
             sweepname = generate_unique_name(sweepname)
-        sweep= setup.add_sweep(sweepname=sweepname)
-        sweep.change_range("LinearCount", freqstart,freqstop, num_of_freq_points )
-        setup.props["GenerateSurfaceCurrent"]=save_fields
-        setup.props["SaveRadFieldsOnly"] = save_rad_fields_only
-        setup.props["FastSweep"] = interpolation
-        setup.props["SAbsError"] = interpolation_tol
-        setup.props["EnforcePassivity"] = interpolation
-        setup.props["UseQ3DForDC"] = use_q3d_for_dc
-        setup.props["MaxSolutions"] = interpolation_max_solutions
-        setup.update()
-        # arg = ["NAME:" + sweepname,
-        #        [
-        #         "NAME:Properties",
-        #         "Enable:=", "true"
-        #        ],
-        #        [
-        #         "NAME:Sweeps",
-        #         "Variable:=", sweepname,
-        #         "Data:=", sweep_string,
-        #         "OffsetF1:=", False,
-        #         "Synchronize:=", 0
-        #        ],
-        #        "GenerateSurfaceCurrent:=", save_fields,
-        #        "SaveRadFieldsOnly:=", save_rad_fields_only,
-        #        "FastSweep:=", interpolation,
-        #        "ZoSelected:=", False,
-        #        "SAbsError:=", interpolation_tol,
-        #        "ZoPercentError:=", 1,
-        #        "GenerateStateSpace:=", False,
-        #        "EnforcePassivity:=", interpolation,
-        #        "PassivityTolerance:=", 0.0001,
-        #        "UseQ3DForDC:=", use_q3d_for_dc,
-        #        "ResimulateDC:=", False,
-        #        "MaxSolutions:=", interpolation_max_solutions,
-        #        "InterpUseSMatrix:=", True,
-        #        "InterpUsePortImpedance:=", True,
-        #        "InterpUsePropConst:=", True,
-        #        "InterpUseFullBasis:=", True,
-        #        "CustomFrequencyString:=", "",
-        #        "AllEntries:=", False,
-        #        "AllDiagEntries:=", False,
-        #        "AllOffDiagEntries:=", False,
-        #        "MagMinThreshold:=", 0.01
-        #        ]
-        #
-        # self.oanalysis.AddSweep(setupname, arg)
-        # self.oanalysis_setup.AddSweep(setupname, arg)
-        # self._messenger.add_debug_message("Sweep Setup created correctly")
-        return setup
+        sweep = setup.add_sweep(sweepname=sweepname)
+        sweep.change_range("LinearCount", str(freqstart)+unit, str(freqstop)+unit, num_of_freq_points )
+        sweep.props["GenerateSurfaceCurrent"] = save_fields
+        sweep.props["SaveRadFieldsOnly"] = save_rad_fields_only
+        sweep.props["FastSweep"] = interpolation
+        sweep.props["SAbsError"] = interpolation_tol
+        sweep.props["EnforcePassivity"] = interpolation
+        sweep.props["UseQ3DForDC"] = use_q3d_for_dc
+        sweep.props["MaxSolutions"] = interpolation_max_solutions
+        sweep.update()
+
+        return sweep
 
     @aedt_exception_handler
     def import_gds(self, gds_path, aedb_path=None, xml_path=None, set_as_active=True, close_active_project=False):
@@ -689,7 +589,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         aedb_path : str, optional
             Full path to the AEDB file.
         xml_path : str, optional
-            Path to the XML file with the stackup information. The default is ``None``, in 
+            Path to the XML file with the stackup information. The default is ``None``, in
             which case the stackup is not edited.
         set_as_active : bool, optional
             Whether to set the GDS file as active. The default is ``True``.
@@ -700,7 +600,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         active_project = self.project_name
         project_name = os.path.basename(gds_path)[:-4]
@@ -710,7 +610,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             old_name = project_name
             project_name = generate_unique_name(project_name)
             aedb_path = gds_path.replace(old_name + '.gds', project_name + '.aedb')
-            self._messenger.add_warning_message("aedb_exists. Renaming it to {}".format(project_name))
+            self._messenger.add_warning_message(
+                "aedb_exists. Renaming it to {}".format(project_name))
 
         oTool = self.odesktop.GetTool("ImportExport")
         oTool.ImportGDSII(gds_path, aedb_path, "", "")
@@ -723,3 +624,87 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         if close_active_project:
             self.odesktop.CloseProject(active_project)
         return True
+
+    @aedt_exception_handler
+    def edit_cosim_options(self, simulate_missing_solution=True, align_ports=True, renormalize_ports=True,
+                           renorm_impedance=50, setup_override_name=None, sweep_override_name=None,
+                           use_interpolating_sweep=False, use_y_matrix=True, interpolation_algorithm="auto"):
+        """Edit Cosimulation Options.
+
+        Parameters
+        ----------
+        simulate_missing_solution : bool, optional
+            Set this to ``True`` if the the solver has to simulate missing solution or
+            ``False`` to interpolate the missing solution.
+        align_ports : bool, Optional
+            Set this to ``True`` if the the solver has to align microwave ports.
+        renormalize_ports : bool, optional
+            Set this to ``True`` if the the port impedance has to be renormalized.
+        renorm_impedance : float, optional
+            Renormalization impedance in Ohm.
+        setup_override_name : str, optional
+            The setup name if there is a setup override.
+        sweep_override_name : str, optional
+            The sweep name if there is a sweep override.
+        use_interpolating_sweep : bool, optional
+            Set to ``True`` if the the solver has to use an interpolating sweep.
+            Set to ``False`` to use a discrete sweep.
+        use_y_matrix : bool, Optional
+            Set to ``True`` if the interpolation algorithm has to use YMatrix.
+        interpolation_algorithm : str, optional
+                Defines which interpolation algorithm to use. Default is ``"auto"``. Options are ``"auto"``, ``"lin"``, ``"shadH"``, ``"shadNH"``
+
+        Returns
+        -------
+        bool
+            ``True`` if successful and ``False`` if failed.
+
+        Examples
+        --------
+        >>> from pyaedt import Hfss3dLayout
+        >>> h3d = Hfss3dLayout()
+        >>> h3d.edit_cosim_options(simulate_missing_solution=True, align_ports=True, renormalize_ports=True,renorm_impedance=50, setup_override_name=None, sweep_override_name=None, use_interpolating_sweep=False, use_y_matrix=True, interpolation_algorithm="auto")
+
+        """
+        if interpolation_algorithm not in ["auto", "lin", "shadH", "shadNH"]:
+            self.add_error_message("Wrong Interpolation Algorithm")
+            return False
+        arg = ["NAME:CoSimOptions", "Override:="]
+
+        if setup_override_name:
+            arg.append(True)
+            arg.append("Setup:=")
+            arg.append(setup_override_name)
+        else:
+            arg.append(False)
+            arg.append("Setup:=")
+            arg.append("")
+        arg.append("OverrideSweep:=")
+
+        if sweep_override_name:
+            arg.append(True)
+            arg.append("Sweep:=")
+            arg.append(sweep_override_name)
+        else:
+            arg.append(False)
+            arg.append("Sweep:=")
+            arg.append("")
+        arg.append("SweepType:=")
+        if use_interpolating_sweep:
+            arg.append(6)
+        else:
+            arg.append(4)
+        arg.append("Interpolate:=")
+        arg.append(not simulate_missing_solution)
+        arg.append("YMatrix:=")
+        arg.append(use_y_matrix)
+        arg.append("AutoAlignPorts:=")
+        arg.append(align_ports)
+        arg.append("InterpAlg:=")
+        arg.append(interpolation_algorithm)
+        arg.append("Renormalize:=")
+        arg.append(renormalize_ports)
+        arg.append("RenormImpedance:=")
+        arg.append(renorm_impedance)
+        self.odesign.EditCoSimulationOptions(arg)
+        return True
