@@ -1,90 +1,17 @@
 """This module contains these Maxwell classes: `Maxwell`, `Maxwell2d`, and `Maxwell3d`."""
 
 from __future__ import absolute_import
-import math
 import os
 import json
-import re
 import io
 from .application.Analysis2D import FieldAnalysis2D
 from .application.Analysis3D import FieldAnalysis3D
 from .desktop import exception_to_desktop
+from .generic.DataHandlers import float_units
 from .generic.general_methods import generate_unique_name, aedt_exception_handler
 from .modules.Boundary import BoundaryObject
 from collections import OrderedDict
 
-unit_val = {
-    "": 1.0,
-    "uV": 1e-6,
-    "mV": 1e-3,
-    "V": 1.0,
-    "kV": 1e3,
-    "MegV": 1e6,
-    "ns": 1e-9,
-    "us": 1e-6,
-    "ms": 1e-3,
-    "s": 1.0,
-    "min": 60,
-    "hour": 3600,
-    "rad": 1.0,
-    "deg": math.pi / 180,
-    "Hz": 1.0,
-    "kHz": 1e3,
-    "MHz": 1e6,
-    "nm": 1e-9,
-    "um": 1e-6,
-    "mm": 1e-3,
-    "cm": 1e-2,
-    "dm": 1e-1,
-    "meter": 1.0,
-    "km": 1e3
-
-}
-
-# Utility scripts
-resynch_maxwell2D_control_program_for_design = '''
-from pyaedt.Desktop import Desktop
-from pyaedt.Maxwell import Maxwell2D
-design_name = os.getenv('design')
-setup = os.getenv('setup')
-
-with Desktop() as d:
-    mxwl = Maxwell2D(designname=design_name, setup_name=setup)
-    mxwl.setup_ctrlprog(keep_modifications=True )
-    oDesktop.AddMessage( mxwl.project_name, mxwl.design_name, 0, "Successfully updated project definitions")
-    mxwl.save_project()
-'''
-
-
-def float_units(val_str, units=""):
-    """Retrieve units for a value.
-
-    Parameters
-    ----------
-    val_str : str
-        Name of the float value.  
-        
-    units : str, optional
-         The default is ``""``.
-
-    Returns
-    -------
-
-    """
-    if not units in unit_val:
-        raise Exception("Specified unit string " + units + " not known!")
-
-    loc = re.search('[a-zA-Z]', val_str)
-    try:
-        b = loc.span()[0]
-        var = [float(val_str[0:b]), val_str[b:]]
-        val = var[0] * unit_val[var[1]]
-    except:
-        val = float(val_str)
-
-    val = val / unit_val[units]
-    return val
-
 
 class Maxwell(object):
     """Contains all methods that are common to both Maxwell 2D and Maxwell 3D.
@@ -109,18 +36,24 @@ class Maxwell(object):
         nothing is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used.
+        the active version or latest installed version is used. This
+        parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode.
+        is ``False``, in which case AEDT is launched in the graphical
+        mode. This parameter is ignored when Script is launched within
+        AEDT.
     AlwaysNew : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
-        machine. The default is ``True``.
+        machine. The default is ``True``. This parameter is ignored
+        when Script is launched within AEDT.
     release_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
-        Whether to open the AEDT student version. The default is ``False``.
+        Whether to open the AEDT student version. The default is
+        ``False``. This parameter is ignored when Script is launched
+        within AEDT.
 
     """
 
@@ -129,7 +62,7 @@ class Maxwell(object):
 
     @property
     def odefinition_manager(self):
-        """Definition manager. """
+        """Definition manager."""
         return self.oproject.GetDefinitionManager()
 
     @property
@@ -137,12 +70,10 @@ class Maxwell(object):
         """Material manager."""
         return self.odefinition_manager.GetManager("Material")
 
-    '''
-    @property
-    def oeditor(self):
-        """Editor."""
-        return self.odesign.SetActiveEditor("3D Modeler")
-    '''
+    # @property
+    # def oeditor(self):
+    #     """Editor."""
+    #     return self.odesign.SetActiveEditor("3D Modeler")
 
     @property
     def symmetry_multiplier(self):
@@ -180,7 +111,7 @@ class Maxwell(object):
             Name of the file. The default value is ``None``.
         keep_modifications : bool, optional
             Whether to save the changes. The default value is ``False``.
-        python_interpreter : optional
+        python_interpreter : bool, optional
              The default value is ``None``.
         aedt_lib_dir : str, optional
              Full path to the ``AEDTLib`` directory. The default value is ``None``.
@@ -243,7 +174,7 @@ class Maxwell(object):
         Parameters
         ----------
         object_list : list
-            List of objects.    
+            List of objects.
         activate : bool, optional
             Whether to activate eddy effects. The default is ``True``.
 
@@ -251,7 +182,7 @@ class Maxwell(object):
         -------
         bool
             ``True`` when successful and ``False`` when failed.
-        
+
         """
         EddyVector = ["NAME:EddyEffectVector"]
         for obj in object_list:
@@ -269,7 +200,7 @@ class Maxwell(object):
     def assign_current(self, object_list, amplitude=1, phase="0deg", solid=True, swap_direction=False,
                        name=None):
         """Assign the source of the current.
-        
+
         Parameters
         ----------
         object_list : list
@@ -295,7 +226,7 @@ class Maxwell(object):
 
         if not name:
             name = generate_unique_name("Current")
-        
+
         object_list = self.modeler._convert_list_to_ids(object_list)
         if self.is3d:
             if type(object_list[0]) is int:
@@ -380,7 +311,8 @@ class Maxwell(object):
             name = generate_unique_name("VoltageDrop")
         face_list = self.modeler._convert_list_to_ids(face_list)
 
-        props = OrderedDict({"Faces": face_list, "Voltage Drop": amplitude, "Point out of terminal": swap_direction})
+        props = OrderedDict({"Faces": face_list, "Voltage Drop": amplitude,
+                            "Point out of terminal": swap_direction})
         bound = BoundaryObject(self, name, props, "VoltageDrop")
         if bound.create():
             self.boundaries.append(bound)
@@ -388,7 +320,7 @@ class Maxwell(object):
         return False
 
     @aedt_exception_handler
-    def assign_winding(self, coil_terminals=None, winding_type="Current", current_value=1, res=0, ind=0, voltage=0,
+    def assign_winding(self, coil_terminals=None, winding_type="Current", is_solid=True, current_value=1, res=0, ind=0, voltage=0,
                        parallel_branches=1, name=None):
         """Assign a winding to a Maxwell design.
 
@@ -398,8 +330,10 @@ class Maxwell(object):
             List of faces to create the coil terminal on.
             The default is ``None``.
         winding_type : str, optional
-            Type of the winding. Options are ``"Current"``, ``"Voltage"``, 
+            Type of the winding. Options are ``"Current"``, ``"Voltage"``,
             and ``"External"``. The default is ``"Current"``.
+        is_solid : bool, optional
+            Type of the winding.  ``True`` is solid, ``False`` is stranded. The default is ``True``.
         current_value : float, optional
             Value of the current in amperes. The default is ``1``.
         res : float, optional
@@ -423,7 +357,7 @@ class Maxwell(object):
         if not name:
             name = generate_unique_name("Winding")
 
-        props = OrderedDict({"Type": winding_type, "IsSolid": True, "Current": str(current_value) + "A",
+        props = OrderedDict({"Type": winding_type, "IsSolid": is_solid, "Current": str(current_value) + "A",
                              "Resistance": str(res) + "ohm", "Inductance": str(ind) + "H",
                              "Voltage": str(voltage) + "V", "ParallelBranchesNum": str(parallel_branches)})
         bound = BoundaryObject(self, name, props, "Winding")
@@ -455,7 +389,7 @@ class Maxwell(object):
         Returns
         -------
         bool
-            ``True`` when successful, ``False`` when failed.   
+            ``True`` when successful, ``False`` when failed.
 
         """
         if self.modeler._is3d:
@@ -475,7 +409,7 @@ class Maxwell(object):
         conductor_number : int, optional
             Number of conductors. The default is ``1``.
         polarity : str, optional
-            Type of the polarity. The default is ``"Positive"``.         
+            Type of the polarity. The default is ``"Positive"``.
         name : str, optional
              The default is ``None``.
 
@@ -511,7 +445,8 @@ class Maxwell(object):
                 bound = BoundaryObject(self, name, props2, "CoilTerminal")
 
             else:
-                self._messenger.add_warning_message("Face Selection is not allowed in Maxwell 2D. Provide a 2D object.")
+                self._messenger.add_warning_message(
+                    "Face Selection is not allowed in Maxwell 2D. Provide a 2D object.")
                 return False
         if bound.create():
             self.boundaries.append(bound)
@@ -537,7 +472,7 @@ class Maxwell(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         input_object = self.modeler._convert_list_to_ids(input_object, True)
         if not force_name:
@@ -570,7 +505,7 @@ class Maxwell(object):
         reference_cs : str, optional
             Name of the reference coordinate system. The default is ``"Global"``.
         is_positive : bool, optional
-            Whether the torque is positive. The default is ``True``. 
+            Whether the torque is positive. The default is ``True``.
         is_virtual : bool, optional
             Whether the torque is virtual. The default is ``True``.
         axis : str, optional
@@ -582,7 +517,7 @@ class Maxwell(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         input_object = self.modeler._convert_list_to_ids(input_object, True)
         if not torque_name:
@@ -616,7 +551,7 @@ class Maxwell(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         input_object = self.modeler._convert_list_to_ids(input_object, True)
         if not force_name:
@@ -637,7 +572,7 @@ class Maxwell(object):
         Parameters
         ----------
         name : str
-            
+
         activate : bool, optional
             The default value is ``True``.
 
@@ -645,7 +580,7 @@ class Maxwell(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         self.modeler.primitives[name].solve_inside = activate
         return True
@@ -653,12 +588,12 @@ class Maxwell(object):
     @aedt_exception_handler
     def analyze_from_zero(self):
         """Analyze from zero.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self.oanalysis.ResetSetupToTimeZero(self._setup)
         self.analyze_nominal()
@@ -711,7 +646,7 @@ class Maxwell(object):
 
 
 class Maxwell3d(Maxwell, FieldAnalysis3D, object):
-    """Maxwell 3D application interface.
+    """Provides the Maxwell 3D application interface.
 
     This class allows you to connect to an existing Maxwell 3D design or create a
     new Maxwell 3D design if one does not exist.
@@ -736,31 +671,39 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
         nothing is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used.
+        the active version or latest installed version is used. This
+        parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode.
+        is ``False``, in which case AEDT is launched in the graphical
+        mode. This parameter is ignored when Script is launched within
+        AEDT.
     AlwaysNew : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
-        machine. The default is ``True``.
+        machine. The default is ``True``. This parameter is ignored
+        when Script is launched within AEDT.
     release_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
-     student_version : bool, optional
-        Whether to open the AEDT student version. The default is ``False``.
+    student_version : bool, optional
+        Whether to open the AEDT student version. The default is
+        ``False``. This parameter is ignored when Script is launched
+        within AEDT.
 
     Examples
     --------
     Create an instance of Maxwell 3D and open the specified
-    project, which is named ``myfile.aedt``.
+    project, which is named ``mymaxwell.aedt``.
 
     >>> from pyaedt import Maxwell3d
-    >>> aedtapp = Maxwell3d("myfile.aedt")
+    >>> aedtapp = Maxwell3d("mymaxwell.aedt")
+    pyaedt Info: Added design ...
 
     Create an instance of Maxwell 3D using the 2021 R1 release and open
-    the specified project, which is named ``myfile.aedt``.
+    the specified project, which is named ``mymaxwell2.aedt``.
 
-    >>> aedtapp = Maxwell3d(specified_version="2021.1", projectname="myfile.aedt")
+    >>> aedtapp = Maxwell3d(specified_version="2021.1", projectname="mymaxwell2.aedt")
+    pyaedt Info: Added design ...
 
     """
 
@@ -781,7 +724,7 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
 
 
 class Maxwell2d(Maxwell, FieldAnalysis2D, object):
-    """Maxwell 2D application interface.
+    """Provides the Maxwell 2D application interface.
 
     This class allows you to connect to an existing Maxwell 2D design or create a
     new Maxwell 2D design if one does not exist.
@@ -806,18 +749,18 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         nothing is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used.
+        the active version or latest installed version is used. This parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode.
+        is ``False``, in which case AEDT is launched in the graphical mode. This parameter is ignored when Script is launched within AEDT.
     AlwaysNew : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
-        machine. The default is ``True``.
+        machine. The default is ``True``. This parameter is ignored when Script is launched within AEDT.
     release_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
-        Whether to open the AEDT student version. The default is ``False``.
+        Whether to open the AEDT student version. The default is ``False``. This parameter is ignored when Script is launched within AEDT.
 
     Examples
     --------
@@ -899,7 +842,8 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
             return obj
         solid_bodies = self.modeler.solid_bodies
         if objectfilter:
-            solid_ids = [i for i,j in self.modeler.primitives.object_id_dict.items() if j.name in objectfilter]
+            solid_ids = [i for i,j in self.modeler.primitives.object_id_dict.items()
+                                                                                   if j.name in objectfilter]
         else:
             solid_ids = [i for i in list(self.modeler.primitives.object_id_dict.keys())]
         model_depth = self.get_model_depth()
@@ -927,12 +871,12 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
     @aedt_exception_handler
     def read_design_data(self):
         """Read back the design data as a dictionary.
-        
+
         Returns
         -------
         dict
             Dictionary of design data.
-        
+
         """
         design_file = os.path.join(self.working_directory, "design_data.json")
         with open(design_file, 'r') as fps:
