@@ -6,6 +6,7 @@ from ..edb import Edb
 from .Modeler import Modeler
 from .Primitives3DLayout import Primitives3DLayout, Geometries3DLayout
 from ..modules.LayerStackup import Layers
+from pyaedt import _pythonver
 import sys
 
 class Modeler3DLayout(Modeler):
@@ -17,6 +18,7 @@ class Modeler3DLayout(Modeler):
         Inherited parent object.
 
     """
+
     def __init__(self, parent):
         self._parent = parent
         self._messenger.add_info_message("Loading Modeler.")
@@ -108,7 +110,6 @@ class Modeler3DLayout(Modeler):
         """Bounding box."""
         return self.oeditor.GetModelBoundingBox()
 
-
     @aedt_exception_handler
     def colinear_heal(self, selection, tolerance=0.1):
         """Remove small edges of one or more primitives.
@@ -143,8 +144,6 @@ class Modeler3DLayout(Modeler):
                            self.primitives.arg_with_dim(tolerance)])
         return True
 
-
-
     @aedt_exception_handler
     def expand(self, object_to_expand,  size=1, expand_type="ROUND", replace_original=False):
         """Expand the object by a specific size.
@@ -192,7 +191,6 @@ class Modeler3DLayout(Modeler):
             return new_geom_names[0]
         return object_to_expand
 
-
     @aedt_exception_handler
     def import_cadence_brd(self, brd_filename, edb_path=None, edb_name=None):
         """Import a Cadence board.
@@ -239,13 +237,13 @@ class Modeler3DLayout(Modeler):
 
         Parameters
         ----------
-        value :      
+        value :
 
         Returns
         -------
 
         """
-        if isinstance(value, str if int(sys.version_info[0]) >= 3 else basestring):
+        if isinstance(value, str if _pythonver >= 3 else basestring):
             return value
         else:
             return str(value) + self.model_units
