@@ -1,12 +1,13 @@
 import random
+import warnings
 from collections import defaultdict
 
 from ..generic.general_methods import aedt_exception_handler, retry_ntimes
 from .Object3d import CircuitComponent
 
 class CircuitComponents(object):
-    """CircutComponents class. 
-    
+    """CircutComponents class.
+
      This is the common class for managing all circuit components for Nexxim and Simplorer.
      """
 
@@ -67,8 +68,8 @@ class CircuitComponents(object):
         Parameters
         ----------
         partname : int or str
-           Part ID or part name. 
-        
+           Part ID or part name.
+
         Returns
         -------
         type
@@ -92,12 +93,12 @@ class CircuitComponents(object):
     @aedt_exception_handler
     def create_unique_id(self):
         """Create an unique ID.
-        
+
         Returns
         -------
         int
             Unique ID in the range of ``[1, 65535]``.
-            
+
         """
         id = random.randint(1, 65535)
         while id in self.components:
@@ -107,10 +108,12 @@ class CircuitComponents(object):
     @aedt_exception_handler
     def create_wire(self, points_array):
         """Create a wire.
+
         Parameters
         ----------
         points_array : list
-            A nested list of point coordinates. For example, ``[[x1, y1], [x2, y2]....]``.
+            A nested list of point coordinates. For example,
+            ``[[x1, y1], [x2, y2], ...]``.
 
         Returns
         -------
@@ -134,7 +137,18 @@ class CircuitComponents(object):
 
     @aedt_exception_handler
     def create_iport(self, name, posx=0.1, posy=0.1, angle=0):
-        """Create a port.
+        """Create an interface port.
+
+        .. deprecated:: 0.4.0
+           Use :func:`Circuit.modeler.components.create_interface_port` instead.
+        """
+        warnings.warn('`create_iport` is deprecated. Use `create_interface_port` instead.',
+                      DeprecationWarning)
+        return self.create_interface_port(name, posx, posy, angle)
+
+    @aedt_exception_handler
+    def create_interface_port(self, name, posx=0.1, posy=0.1, angle=0):
+        """Create an interface port.
 
         Parameters
         ----------
@@ -152,7 +166,7 @@ class CircuitComponents(object):
         type
             Port object.
         str
-           Port name.
+            Port name.
 
         """
         id = self.create_unique_id()
@@ -220,7 +234,7 @@ class CircuitComponents(object):
             Position on the X axis. The default is ``0.1``.
         posy : float, optional
             Position on the Y axis. The default is ``0.1``.
-       
+
         Returns
         -------
         type
@@ -265,7 +279,7 @@ class CircuitComponents(object):
         Returns
         -------
         bool
-            ``True`` when successful, ``False`` when failed.     
+            ``True`` when successful, ``False`` when failed.
 
         """
         if not model_name:
@@ -332,14 +346,13 @@ class CircuitComponents(object):
 
         """
         id = self.create_unique_id()
-        id = self.oeditor.CreateComponent(["NAME:ComponentProps", "Name:=", modelname, "Id:=", str(id)],
-                                ["NAME:Attributes", "Page:=", 1, "X:=", xpos, "Y:=", ypos, "Angle:=", angle, "Flip:=",
-                                 False])
+        arg1 = ["NAME:ComponentProps", "Name:=", modelname, "Id:=", str(id)]
+        arg2 = ["NAME:Attributes", "Page:=", 1, "X:=", xpos, "Y:=", ypos, "Angle:=", angle, "Flip:=", False]
+        id = retry_ntimes(10, self.oeditor.CreateComponent, arg1, arg2)
         id = int(id.split(";")[1])
         self.add_id_to_component(id)
         return id, self.components[id].composed_name
 
-
     @aedt_exception_handler
     def create_component(self, inst_name=None, component_library="Resistors",
                          component_name="RES_", xpos=0.1, ypos=0.1, angle=0, use_instance_id_netlist=False,
@@ -379,20 +392,9 @@ class CircuitComponents(object):
             name = self.design_libray + "\\" + component_library + ":" + component_name
         else:
             name = component_name
-        id = self.oeditor.CreateComponent(
-            [
-                "NAME:ComponentProps",
-                "Name:=", name,
-                "Id:=", str(id)
-            ],
-            [
-                "NAME:Attributes",
-                "Page:=", 1,
-                "X:=", xpos,
-                "Y:=", ypos,
-                "Angle:=", angle,
-                "Flip:=", False
-            ])
+        arg1 = ["NAME:ComponentProps", "Name:=", name, "Id:=", str(id)]
+        arg2 = ["NAME:Attributes", "Page:=", 1, "X:=", xpos, "Y:=", ypos, "Angle:=", angle, "Flip:=", False]
+        id = retry_ntimes(10, self.oeditor.CreateComponent, arg1, arg2)
         id = int(id.split(";")[1])
         # self.refresh_all_ids()
         self.add_id_to_component(id)
@@ -780,19 +782,19 @@ class CircuitComponents(object):
 
     @aedt_exception_handler
     def arg_with_dim(self, Value, sUnits=None):
-        """
+        """Format an argument with dimensions.
 
         Parameters
         ----------
         Value : str
-            
+
         sUnits :
             The default is ``None``.
 
         Returns
         -------
         type
-            
+
 
         """
         if type(Value) is str:
