@@ -1,16 +1,18 @@
+import warnings
+
 from ..generic.general_methods import aedt_exception_handler, retry_ntimes
 from .PrimitivesCircuit import CircuitComponents
 
 
 class NexximComponents(CircuitComponents):
     """Manages circuit components for Nexxim.
-    
+
     Parameters
     ----------
     parent :
         Inherited parent object.
     modeler :
-    
+
     """
     @property
     def design_libray(self):
@@ -28,8 +30,8 @@ class NexximComponents(CircuitComponents):
         Parameters
         ----------
         partname: int or str
-            Part ID or object name. 
-        
+            Part ID or object name.
+
         Returns
         -------
         type
@@ -52,7 +54,18 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_3dlayout_subcircuit(self, sourcename):
-        """Create a subcircuit.
+        """Add a subcircuit from a HFSS 3DLayout.
+
+        .. deprecated:: 0.4.0
+           Use :func:`Circuit.modeler.components.add_subcircuit_3dlayout` instead.
+        """
+        warnings.warn('`create_3dlayout_subcircuit` is deprecated. Use `add_subcircuit_3dlayout` instead.',
+                      DeprecationWarning)
+        return self.add_subcircuit_3dlayout(sourcename)
+
+    @aedt_exception_handler
+    def add_subcircuit_3dlayout(self, sourcename):
+        """Add a subcircuit from a HFSS 3DLayout.
 
         Parameters
         ----------
@@ -88,7 +101,7 @@ class NexximComponents(CircuitComponents):
         model_type: str, optional
             Type of the model. The default is ``"hfss"``.
         posx : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         posy : float, optional.
             Position on the Y axis. The default is ``1``.
 
@@ -96,7 +109,7 @@ class NexximComponents(CircuitComponents):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         id = self.create_unique_id()
         component_name = design_name + "_" + str(id)
@@ -215,13 +228,13 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Resistance in ohms. The default is ``50``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
 
         Returns
@@ -230,7 +243,7 @@ class NexximComponents(CircuitComponents):
             ID of the resistor.
         str
             Name of the resistor.
-        
+
         """
         cmpid, cmpname = self.create_component(compname, xpos=xpos, ypos=ypos, angle=angle, use_instance_id_netlist=use_instance_id_netlist)
 
@@ -248,13 +261,13 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Inductance value. The default is ``50``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
 
         Returns
@@ -263,7 +276,7 @@ class NexximComponents(CircuitComponents):
             ID of the inductor.
         str
             Name of the inductor.
-        
+
         """
         cmpid, cmpname = self.create_component(compname, component_library="Inductors", component_name="IND_", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -283,22 +296,22 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Capacitor value. The default is ``50``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
-        
+
         Returns
         -------
         int
             ID of the capacitor.
         str
             Name of the capacitor.
-        
+
         """
         cmpid, cmpname = self.create_component(compname,component_library="Capacitors", component_name="CAP_", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -317,12 +330,12 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Voltage value. The default is ``50``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
 
         Returns
@@ -331,7 +344,7 @@ class NexximComponents(CircuitComponents):
             ID of the voltage DC source.
         str
             Name of the voltage DC source.
-        
+
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="V_DC", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -350,22 +363,22 @@ class NexximComponents(CircuitComponents):
         value_lists : list, optional
             List of values for the current pulse. The default is ``[]``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
-        
+
         Returns
         -------
         int
             ID of the current pulse.
         str
             Name of the current pulse.
-        
+
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="I_PULSE", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -385,7 +398,6 @@ class NexximComponents(CircuitComponents):
         if len(value_lists) > 6:
             self.components[cmpid].set_property("PER", value_lists[6])
 
-
         return cmpid, cmpname
 
     @aedt_exception_handler
@@ -399,22 +411,22 @@ class NexximComponents(CircuitComponents):
         value_lists : list, optional
             List of values for the voltage pulse. The default is ``[]``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
-        
+
         Returns
         -------
         int
             ID of the voltage pulse.
         str
             Name of the voltage pulse.
-        
+
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="V_PULSE", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -434,10 +446,8 @@ class NexximComponents(CircuitComponents):
         if len(value_lists) > 6:
             self.components[cmpid].set_property("PER", value_lists[6])
 
-
         return cmpid, cmpname
 
-
     @aedt_exception_handler
     def create_current_dc(self, compname=None, value=1, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
         """Create a current DC source.
@@ -449,13 +459,13 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Current value. The default is ``1``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
 
         Returns
@@ -464,7 +474,7 @@ class NexximComponents(CircuitComponents):
             ID of the current DC source.
         str
             Name of the current DC source.
-        
+
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="I_DC", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -486,14 +496,14 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Value for the coupling inductor. The default is ``1``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
-            The default is ``False``.   
+            Whether to use the instance ID in the net list.
+            The default is ``False``.
 
         Returns
         -------
@@ -501,7 +511,7 @@ class NexximComponents(CircuitComponents):
             ID of the coupling inductor.
         str
             Name of the coupling inductor.
-        
+
         """
         cmpid, cmpname = self.create_component(compname,component_library="Inductors", component_name="K_IND", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -522,22 +532,22 @@ class NexximComponents(CircuitComponents):
         model_name : str, optional
             Name of the model. The default is ``"required"``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
-       
+
         Returns
         -------
         int
             ID of the diode.
         str
             Name of the diode.
-        
+
         """
         cmpid, cmpname = self.create_component(compname,component_library="Diodes", component_name="DIODE_Level1", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -556,22 +566,22 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Value for the NPN transistor. The default is ``None``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
-        
+
         Returns
         -------
         int
             ID of the NPN transistor.
         str
             Name of the NPN transistor.
-        
+
         """
         id, name = self.create_component(compname,component_library="BJTs", component_name="Level01_NPN", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -590,22 +600,22 @@ class NexximComponents(CircuitComponents):
         value : float, optional
             Value for the PNP transistor. The default is ``None``.
         xpos : float, optional
-            Position on the X axis. The default is ``0``.    
+            Position on the X axis. The default is ``0``.
         ypos: float, optional
             Position on the Y axis. The default is ``0``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
-            Whether to use the instance ID in the net list. 
+            Whether to use the instance ID in the net list.
             The default is ``False``.
-        
+
         Returns
         -------
         int
             ID of the PNP transistor.
         str
             Name of the PNP transistor.
-        
+
         """
         id, name = self.create_component(compname, component_library="BJTs", component_name="Level01_PNP", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -635,7 +645,7 @@ class NexximComponents(CircuitComponents):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         arg = ["NAME:" + symbol_name, "Info:=",
                ["Type:=", 0, "NumTerminals:=", len(pin_lists), "DataSource:=", "", "ModifiedOn:=", 1591858313, "Manufacturer:=", "",
@@ -705,7 +715,7 @@ class NexximComponents(CircuitComponents):
         -------
         :class:`pyaedt.modeler.Object3d.CircuitComponent`
             Object with properties.
-        
+
         """
         name = o.composed_name
         proparray = self.oeditor.GetProperties("PassedParameterTab", name)
@@ -721,12 +731,12 @@ class NexximComponents(CircuitComponents):
         Parameters
         ----------
         toolNum :
-        
+
         dc :
             The default is ``0``.
         interp :
             The default is ``0``.
-        extrap : 
+        extrap :
             The default is ``1``.
         conv :
             The default is ``0``.
@@ -737,13 +747,13 @@ class NexximComponents(CircuitComponents):
         opt : str, optional
             The default is ``""``.
         data_type : optional
-            Type of the data. The default is ``1``.  
+            Type of the data. The default is ``1``.
 
         Returns
         -------
         list
             List of the custom settings for the resistor.
-        
+
         """
         if toolNum == 1:
             custom = "NAME:DesignerCustomization"
@@ -765,37 +775,38 @@ class NexximComponents(CircuitComponents):
         return res
 
     @aedt_exception_handler
-    def add_subcircuit_hfss_link(self, compName, pin_names, source_project_path, source_project_name, source_design_name, solution_name = "Setup1 : Sweep"):
+    def add_subcircuit_hfss_link(self, comp_name, pin_names, source_project_path, source_project_name,
+                                 source_design_name, solution_name="Setup1 : Sweep"):
         """Add a subcircuit HFSS link.
 
         Parameters
         ----------
-        compName : str
+        comp_name : str
             Name of the subcircuit HFSS link.
         pin_names: list
             List of the pin names.
         source_project_path : str
-            Path to the source project.      
+            Path to the source project.
         source_project_name: str
             Name  of the source project.
         source_design_name : str
             Name of the design.
         solution_name: str, optional
-            Name of the solution and sweep. The 
+            Name of the solution and sweep. The
             default is ``"Setup1 : Sweep"``.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         designer_customization = self.get_comp_custom_settings(1, 0, 0, 1, 0, 0, "False", "", 1)
         nexxim_customization = self.get_comp_custom_settings(2, 3, 1, 3, 0, 0, "False", "", 2)
         hspice_customization = self.get_comp_custom_settings(3, 1, 2, 3, 0, 0, "False", "", 3)
 
-        compInfo = ["NAME:"+str(compName),
-                    "Name:=", compName,
+        compInfo = ["NAME:" + str(comp_name),
+                    "Name:=", comp_name,
                     "ModTime:=", 1591855779,
                     "Library:=", "",
                     "LibLocation:=", "Project",
@@ -835,9 +846,7 @@ class NexximComponents(CircuitComponents):
                 "IEEE:=", "", "Author:=", "", "OriginalAuthor:=", "",	"CreationDate:=", 1591855894, "ExampleFile:=", "",
                 "HiddenComponent:=", 0, "CircuitEnv:=", 0, "GroupID:=", 0]
 
-
-
-        compInfo2 = ["NAME:"+str(compName),
+        compInfo2 = ["NAME:"+str(comp_name),
                      "Info:=", info,
                      "CircuitEnv:=", 0,
                      "Refbase:=", "S",
@@ -863,54 +872,47 @@ class NexximComponents(CircuitComponents):
                            "CosimDefName:=", "Default",
                            "IsDefinition:=", True,
                            "Connect:=", True,
-                           "ModelDefinitionName:=", compName,
+                           "ModelDefinitionName:=", comp_name,
                            "ShowRefPin2:=", 2,
                            "LenPropName:=", ""],
                           "DefaultCosim:=", "Default"])
 
         self.o_component_manager.Add(compInfo2)
-        self._parent.odesign.AddCompInstance(compName)
+        self._parent.odesign.AddCompInstance(comp_name)
         self.refresh_all_ids()
         for el in self.components:
-            item = compName
+            item = comp_name
             item2 = self.components[el].composed_name
-            if compName in self.components[el].composed_name:
+            if comp_name in self.components[el].composed_name:
                 return el, self.components[el].composed_name
         return False
 
     @aedt_exception_handler
-    def set_sim_option_on_hfss_subcircuit(self, component):
+    def set_sim_option_on_hfss_subcircuit(self, component, option="simulate"):
         """Set the simulation option on the HFSS subscircuit.
 
         Parameters
         ----------
         component : str
             Address of the component instance. For example, ``"Inst@Galileo_cutout3;87;1"``.
+        option : str
+            Set the simulation strategy. Options are ``"simulate"`` and ``"interpolate"``. The default
+            is ``"simulate"``.
 
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
-        complist = component.split(";")
-        complist2 = complist[0].split("@")
-        arg = ["NAME:AllTabs"]
-        arg1 = ["NAME:Model"]
-        arg2 = ["NAME:PropServers", "Component@"+str(complist2[1])]
-        arg3 = ["NAME:ChangedProps",["NAME:Simulation option", "Value:=", "Simulate missing solutions"]]
-
-        arg1.append(arg2)
-        arg1.append(arg3)
-        arg.append(arg1)
-
-        self._parent._oproject.ChangeProperty(arg)
-
-        argo = ["NAME:AllTabs", ["NAME:Component", ["NAME:PropServers", str(component)]]]
-
-        self.oeditor.ChangeProperty(argo)
-
-        pass
+        if option == "simulate":
+            setting = "Simulate missing solutions"
+        elif option == "interpolate":
+            setting = "Interpolate existing solutions"
+        else:
+            return False
+        arg = ["NAME:Simulation option", "Value:=", setting]
+        return self._edit_link_definition_hfss_subcircuit(component, arg)
 
     @aedt_exception_handler
     def set_sim_solution_on_hfss_subcircuit(self, component, solution_name="Setup1 : Sweep"):
@@ -927,25 +929,26 @@ class NexximComponents(CircuitComponents):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
+        arg = ["NAME:Solution", "Value:=", solution_name]
+        return self._edit_link_definition_hfss_subcircuit(component, arg)
+
+    @aedt_exception_handler
+    def _edit_link_definition_hfss_subcircuit(self, component, edited_prop):
+        """Generic function to set the link definition for an hfss subcircuit."""
         complist = component.split(";")
         complist2 = complist[0].split("@")
         arg = ["NAME:AllTabs"]
         arg1 = ["NAME:Model"]
         arg2 = ["NAME:PropServers", "Component@" + str(complist2[1])]
-        arg3 = ["NAME:ChangedProps", ["NAME:Solution", "Value:=", solution_name]]
+        arg3 = ["NAME:ChangedProps", edited_prop]
 
         arg1.append(arg2)
         arg1.append(arg3)
         arg.append(arg1)
 
         self._parent._oproject.ChangeProperty(arg)
-
-        argo = ["NAME:AllTabs", ["NAME:Component", ["NAME:PropServers", str(component)]]]
-
-        self.oeditor.ChangeProperty(argo)
-
         return True
 
     @aedt_exception_handler
@@ -956,113 +959,37 @@ class NexximComponents(CircuitComponents):
         ----------
         component_name : str
             Name of the dynamic link.
-            
+
 
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self.o_component_manager.UpdateDynamicLink(component_name)
+        return True
 
     @aedt_exception_handler
     def push_excitations(self, instance_name, thevenin_calculation=False, setup_name="LinearFrequency"):
         """Push excitations.
 
-        Parameters
-        ----------
-        instance_name : str
-            Name of the instance.
-        thevenin_calculation : bool, optional
-            Whether to perform the Thevenin equivalent calculation. The default is ``False``.
-        setup_name : str
-            Name of the solution setup to push.
-
-        Returns
-        -------
-        bool
-            ``True`` when successful, ``False`` when failed.
-        
+        .. deprecated:: 0.4.0
+           Use :func:`Circuit.push_excitations` instead.
         """
-        arg = ["NAME:options",
-               "CalcThevenin:=", thevenin_calculation,
-               "Sol:=", setup_name]
-
-        self.oeditor.PushExcitations(instance_name, arg)
-        pass
+        warnings.warn('`circuit.modeler.components.push_excitation` is deprecated. '
+                      'Use `circuit.push_excitation` instead.',
+                      DeprecationWarning)
+        return self._parent._parent.push_excitations(instance_name, thevenin_calculation, setup_name)
 
     @aedt_exception_handler
     def assign_sin_excitation2ports(self, ports, settings):
-        """Assign a sinusoidal excitation to circuit ports.
+        """Assign a voltage sinusoidal excitation to circuit ports.
 
-        Parameters
-        ----------
-        ports : list
-            List of circuit ports to assign to the sinusoidal excitation.
-        settings : list
-            List of parameter values to use in voltage sinusoidal excitation creation.
-            
-            Values are given in this order:
-        
-            * 0: AC magnitude for small-signal analysis
-            * 1: AC phase for small-signal analysis
-            * 2: DC voltage
-            * 3: Voltage offset from zero
-            * 4: Voltage amplitude
-            * 5: Frequency
-            * 6: Delay to start of sine wave
-            * 7: Damping factor
-            * 8: Phase delay
-            * 9: Frequency to use for harmonic balance analysis
-
-        Returns
-        -------
-        bool
-            ``True`` when successful, ``False`` when failed.
-        
+        .. deprecated:: 0.4.0
+           Use :func:`Circuit.modeler.components.assign_voltage_sinusoidal_excitation_to_ports` instead.
         """
-        id = self.create_unique_id()
-
-        arg1 = ["NAME:NexximSources",
-                ["NAME:NexximSources",
-                 ["NAME:Data",
-                  ["NAME:VoltageSinusoidal"+str(id),
-                   "DataId:=", "Source"+str(id),
-                   "Type:=", 1,
-                   "Output:=", 0,
-                   "NumPins:=", 2,
-                   "Netlist:=", "V@ID %0 %1 *DC(DC=@DC) SIN(?VO(@VO) ?VA(@VA) ?FREQ(@FREQ) ?TD(@TD) ?ALPHA(@ALPHA) ?THETA(@THETA)) *TONE(TONE=@TONE) *ACMAG(AC @ACMAG @ACPHASE)",
-                   "CompName:=", "Nexxim Circuit Elements\\Independent Sources:V_SIN",
-                   "FDSFileName:=", "",
-                   ["NAME:Properties",
-                    "TextProp:=", ["LabelID","HD","Property string for netlist ID","V@ID"],
-                    "ValueProp:=", ["ACMAG","OD","AC magnitude for small-signal analysis (Volts)",settings[0],0],
-                    "ValuePropNU:=", ["ACPHASE","OD","AC phase for small-signal analysis",settings[1],0,"deg"],
-                    "ValueProp:=", ["DC","OD","DC voltage (Volts)",settings[2],0],
-                    "ValueProp:=", ["VO","OD","Voltage offset from zero (Volts)",settings[3],0],
-                    "ValueProp:=", ["VA","OD","Voltage amplitude (Volts)",settings[4],0],
-                    "ValueProp:=", ["FREQ","OD","Frequency (Hz)",settings[5],0],
-                    "ValueProp:=", ["TD","OD","Delay to start of sine wave (seconds)",settings[6],0],
-                    "ValueProp:=", ["ALPHA","OD","Damping factor (1/seconds)",settings[7],0],
-                    "ValuePropNU:=", ["THETA","OD","Phase delay",settings[8],0,"deg"],
-                    "ValueProp:=", ["TONE","OD","Frequency (Hz) to use for harmonic balance analysis, should be a submultiple of (or equal to) the driving frequency and should also be included in the HB analysis setup",settings[9],0],
-                    "TextProp:=", ["ModelName","SHD","","V_SIN"],
-                    "MenuProp:=", ["CoSimulator","D","","DefaultNetlist",0],
-                    "ButtonProp:=", ["CosimDefinition","D","","","Edit",40501, "ButtonPropClientData:=", [] ] ] ] ] ] ]
-
-        arg2 = ["NAME:ComponentConfigurationData"]
-
-        arg3 = ["NAME:ComponentConfigurationData", ["NAME:EnabledPorts", "VoltageSinusoidal"+str(id)+":=", ports],
-                ["NAME:EnabledMultipleComponents", "VoltageSinusoidal"+str(id)+":=", [] ] ]
-
-        for prt in ports:
-            arg_temp = []
-            arg_temp = ["NAME:EnabledAnalyses", ["NAME:"+str(prt), str(prt)+":=", [] ], ["NAME:VoltageSinusoidal"+str(id), str(prt)+":=", [] ] ]
-            arg3.append(arg_temp)
-
-        arg2.append(arg3)
-
-        self._parent.odesign.UpdateSources(arg1,arg2)
-
-        pass
+        warnings.warn('`assign_sin_excitation2ports` is deprecated. '
+                      'Use `assign_voltage_sinusoidal_excitation_to_ports` instead.',
+                      DeprecationWarning)
+        return self._parent.assign_voltage_sinusoidal_excitation_to_ports(ports, settings)
