@@ -3,14 +3,16 @@ This module contains these classes: `BoundaryCommon` and `BoundaryObject`.
 """
 from collections import OrderedDict
 from ..generic.general_methods import aedt_exception_handler
-from ..application.DataHandlers import dict2arg
+from ..generic.DataHandlers import dict2arg
 from ..modeler.Object3d import EdgePrimitive, FacePrimitive, VertexPrimitive
+from ..generic.DataHandlers import random_string
+
 class BoundaryCommon(object):
     """ """
     @aedt_exception_handler
     def _get_args(self, props=None):
         """Retrieve boundary properties.
-        
+
         Parameters
         ----------
         props : dict, optional
@@ -31,12 +33,12 @@ class BoundaryCommon(object):
     @aedt_exception_handler
     def delete(self):
         """Delete the boundary.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self._parent.oboundary.DeleteBoundaries([self.name])
         for el in self._parent.boundaries:
@@ -44,21 +46,168 @@ class BoundaryCommon(object):
                 self._parent.boundaries.remove(el)
         return True
 
+
+class NativeComponentObject(BoundaryCommon, object):
+    """Manages Native Component data and execution.
+
+    Examples
+    --------
+    in this example the par_beam returned object is a ``pyaedt.modules.Boundary.NativeComponentObject``
+    >>> from pyaedt import Hfss
+    >>> hfss = Hfss(solution_type="SBR+")
+    >>> ffd_file ="path/to/ffdfile.ffd"
+    >>> par_beam = hfss.create_sbr_file_based_antenna(ffd_file)
+    >>> par_beam.native_properties["Size"] = "0.1mm"
+    >>> par_beam.update()
+    >>> par_beam.delete()
+    """
+
+    def __init__(self, parent,component_type, component_name, props):
+        self._parent = parent
+        self.name = "InsertNativeComponentData"
+        self.component_name = component_name
+        self.props = OrderedDict(
+            {"TargetCS": "Global", "SubmodelDefinitionName": self.component_name, "ComponentPriorityLists": OrderedDict({}),
+             "NextUniqueID": 0, "MoveBackwards": False, "DatasetType": "ComponentDatasetType",
+             "DatasetDefinitions": OrderedDict({}), "BasicComponentInfo": OrderedDict(
+                {"ComponentName": self.component_name, "Company": "", "Company URL": "", "Model Number": "", "Help URL": "",
+                 "Version": "1.0", "Notes": "", "IconType": ""}),
+             "GeometryDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
+             "DesignDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
+             "MaterialDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
+             "MapInstanceParameters": "DesignVariable",
+             "UniqueDefinitionIdentifier": "89d26167-fb77-480e-a7ab-"+random_string(12,char_set='abcdef0123456789'), "OriginFilePath": "",
+             "IsLocal": False, "ChecksumString": "", "ChecksumHistory": [], "VersionHistory": [],
+             "NativeComponentDefinitionProvider": OrderedDict({"Type": component_type}),
+             "InstanceParameters": OrderedDict(
+                 {"GeometryParameters": "", "MaterialParameters": "", "DesignParameters": ""})})
+        if props:
+            self._update_props(self.props,props)
+        self.native_properties = self.props["NativeComponentDefinitionProvider"]
+
+    @property
+    def targetcs(self):
+        """Native Component Coordinate System.
+
+        Returns
+        -------
+        str
+            Native Component Coordinate System
+        """
+        return self.props["TargetCS"]
+
+    @targetcs.setter
+    def targetcs(self, cs):
+        self.props["TargetCS"] = cs
+
+    def _update_props(self,d, u):
+        for k, v in u.items():
+            if isinstance(v, dict) or type(v) is OrderedDict:
+                if k not in d:
+                    d[k] = OrderedDict({})
+                d[k] = self._update_props(d[k], v)
+            else:
+                d[k] = v
+        return d
+
+    @aedt_exception_handler
+    def _get_args(self, props=None):
+        if props is None:
+            props = self.props
+        arg = ["NAME:" + self.name]
+        dict2arg(props, arg)
+        return arg
+
+    @aedt_exception_handler
+    def create(self):
+        """Create a Native Component in AEDT.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        self.name = "InsertNativeComponentData"
+        try:
+            names = [i for i in self._parent.modeler.get_excitations_name()]
+        except Exception as e:
+            names = []
+        self.antennaname = self._parent.modeler.oeditor.InsertNativeComponent(self._get_args())
+        try:
+            a = [i for i in self._parent.modeler.get_excitations_name() if i not in names]
+            self.excitation_name = a[0].split(":")[0]
+        except Exception as e:
+            self.excitation_name = self.antennaname
+        return True
+
+    @aedt_exception_handler
+    def update(self):
+        """Update the Native Component in AEDT.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+
+        self.name = "EditNativeComponentDefinitionData"
+        self.update_props = OrderedDict({})
+        self.update_props["DefinitionName"] = self.props["SubmodelDefinitionName"]
+        self.update_props["GeometryDefinitionParameters"] = self.props["GeometryDefinitionParameters"]
+        self.update_props["DesignDefinitionParameters"] = self.props["DesignDefinitionParameters"]
+        self.update_props["MaterialDefinitionParameters"] = self.props["MaterialDefinitionParameters"]
+        self.update_props["NextUniqueID"] = self.props["NextUniqueID"]
+        self.update_props["MoveBackwards"] = self.props["MoveBackwards"]
+        self.update_props["DatasetType"] = self.props["DatasetType"]
+        self.update_props["DatasetDefinitions"] = self.props["DatasetDefinitions"]
+        self.update_props["NativeComponentDefinitionProvider"] = self.props["NativeComponentDefinitionProvider"]
+        self.update_props["ComponentName"] = self.props["BasicComponentInfo"]["ComponentName"]
+        self.update_props["Company"] = self.props["BasicComponentInfo"]["Company"]
+        self.update_props["Model Number"] = self.props["BasicComponentInfo"]["Model Number"]
+        self.update_props["Help URL"] = self.props["BasicComponentInfo"]["Help URL"]
+        self.update_props["Version"] = self.props["BasicComponentInfo"]["Version"]
+        self.update_props["Notes"] = self.props["BasicComponentInfo"]["Notes"]
+        self.update_props["IconType"] = self.props["BasicComponentInfo"]["IconType"]
+        self._parent.modeler.oeditor.EditNativeComponentDefinition(self._get_args(self.update_props))
+
+        return True
+
+    @aedt_exception_handler
+    def delete(self):
+        """Delete the Native Component in AEDT.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        self._parent.modeler.oeditor.Delete(["NAME:Selections", "Selections:=", self.antennaname])
+        for el in self._parent.native_components:
+            if el.component_name == self.component_name:
+                self._parent.native_components.remove(el)
+        return True
+
+
 class BoundaryObject(BoundaryCommon, object):
     """Manages boundary data and execution.
-    
-    Parameters
-    ----------
-    parent:
-    
-    name :
-    
-    props :
-    
-    boundarytype :
-    
-        
+
+    Examples
+    --------
+
+    Create a cylinder at the XY working plane and assign a copper coating of 0.2 mm to it. The Coating is a boundary
+    operation and coat will return a ``pyaedt.modules.Boundary.BoundaryObject``
+
+    >>> from pyaedt import Hfss
+    >>> hfss =Hfss()
+    >>> origin = hfss.modeler.Position(0, 0, 0)
+    >>> inner = hfss.modeler.primitives.create_cylinder(hfss.CoordinateSystemPlane.XYPlane, origin, 3, 200, 0, "inner")
+    >>> inner_id = hfss.modeler.primitives.get_obj_id("inner")
+    >>> coat = hfss.assigncoating([inner_id], "copper", usethickness=True, thickness="0.2mm")
     """
+
     def __init__(self, parent, name, props, boundarytype):
         self._parent = parent
         self.name = name
@@ -78,7 +227,7 @@ class BoundaryObject(BoundaryCommon, object):
         -------
         list
             List of boundary properties.
-            
+
         """
         if props is None:
             props = self.props
@@ -89,7 +238,7 @@ class BoundaryObject(BoundaryCommon, object):
     @aedt_exception_handler
     def create(self):
         """Create a boundary.
-        
+
         Returns
         -------
         bool
@@ -206,6 +355,8 @@ class BoundaryObject(BoundaryCommon, object):
             self._parent.oboundary.AutoIdentifyPorts(["NAME:Faces", self.props["Faces"]],self.props["IsWavePort"],
                    ["NAME:ReferenceConductors", self.props["ReferenceConductors"]], self.name,
                    self.props["RenormalizeModes"])
+        elif self.type == 'SBRTxRxSettings':
+            self._parent.oboundary.SetSBRTxRxSettings(self._get_args())
         else:
             return False
         return True
@@ -213,7 +364,7 @@ class BoundaryObject(BoundaryCommon, object):
     @aedt_exception_handler
     def update(self):
         """Update the boundary.
-                
+
         Returns
         -------
         bool
@@ -312,6 +463,8 @@ class BoundaryObject(BoundaryCommon, object):
             self._parent.oboundary.EditLumpedPort(self.name, self._get_args())
         elif self.type == 'WavePort':
             self._parent.oboundary.EditWavePort(self.name, self._get_args())
+        elif self.type == 'SetSBRTxRxSettings':
+            self._parent.oboundary.SetSBRTxRxSettings(self._get_args())
         else:
             return False
         return True
@@ -319,7 +472,7 @@ class BoundaryObject(BoundaryCommon, object):
     @aedt_exception_handler
     def update_assignment(self):
         """Update the boundary assignment.
-        
+
         Returns
         -------
         bool
@@ -343,4 +496,3 @@ class BoundaryObject(BoundaryCommon, object):
         else:
             return False
         return True
-    
