@@ -1,16 +1,17 @@
 """
-This module contains the `Materials` class. 
+This module contains the `Materials` class.
 """
 from __future__ import absolute_import
 import os
 import xml.etree.ElementTree as ET
 from .Material import *
-from ..generic.general_methods import aedt_exception_handler
+from ..generic.general_methods import aedt_exception_handler, retry_ntimes
+from ..generic.DataHandlers import arg2dict
 import json
 
 class Materials(object):
     """Contains the AEDT materials database and all methods for creating and editing materials.
-    
+
     Parameters
     ----------
     parent : str
@@ -31,7 +32,7 @@ class Materials(object):
     @property
     def _messenger(self):
         """Messenger.
-        
+
         Returns
         -------
         MessageManager
@@ -65,7 +66,6 @@ class Materials(object):
         elif item in list(self.surface_material_keys.keys()):
             return self.surface_material_keys[item]
 
-
     @aedt_exception_handler
     def _get_materials(self):
         """Get materials."""
@@ -87,7 +87,6 @@ class Materials(object):
             pass
         return mats
 
-
     @aedt_exception_handler
     def checkifmaterialexists(self, mat):
         """Check if a material exists in AEDT.
@@ -95,7 +94,7 @@ class Materials(object):
         Parameters
         ----------
         mat : str
-            Name of the material. If the material exists and is not in the materials database, 
+            Name of the material. If the material exists and is not in the materials database,
             it is added to this database.
 
         Returns
@@ -148,11 +147,11 @@ class Materials(object):
 
     @aedt_exception_handler
     def add_material(self, materialname, props=None):
-        """Add a material with default values. 
-        
-        When the added material object is returned, you can customize 
+        """Add a material with default values.
+
+        When the added material object is returned, you can customize
         the material. This method does not update the material.
-        
+
         Parameters
         ----------
         materialname : str
@@ -166,12 +165,12 @@ class Materials(object):
 
         Examples
         --------
-        
+
         >>> from pyaedt import Hfss
         >>> hfss = Hfss()
         >>> mat = hfss.materials.add_material("MyMaterial")
         >>> print(mat.conductivity.value)
-        
+
         """
         materialname = materialname.lower()
         self._messenger.add_info_message('Adding new material to the Project Library: ' + materialname)
@@ -189,8 +188,8 @@ class Materials(object):
     @aedt_exception_handler
     def add_surface_material(self, material_name, emissivity=None):
         """Add a surface material.
-        
-        In AEDT, base properties are loaded from the XML database file ``amat.xml`` 
+
+        In AEDT, base properties are loaded from the XML database file ``amat.xml``
         or from the emissivity.
 
         Parameters
@@ -199,20 +198,20 @@ class Materials(object):
             Name of the surface material.
         emissivity : float, optional
             Emissivity value.
-        
+
         Returns
         -------
         :class:`pyaedt.modules.SurfaceMaterial`
-            
+
         Examples
         --------
-        
+
         >>> from pyaedt import Hfss
         >>> hfss = Hfss()
         >>> mat = hfss.materials.add_surface_material("Steel", 0.85)
         >>> print(mat.emissivity.value)
         """
-        
+
         materialname = material_name.lower()
         self._messenger.add_info_message('Adding a surface material to the project library: ' + materialname)
         if materialname in self.surface_material_keys:
@@ -228,7 +227,6 @@ class Materials(object):
             self.surface_material_keys[materialname] = material
             return self.surface_material_keys[materialname]
 
-
     @aedt_exception_handler
     def _create_mat_project_vars(self, matlist):
         matprop={}
@@ -252,11 +250,11 @@ class Materials(object):
     @aedt_exception_handler
     def add_material_sweep(self, swargs, matname):
         """Create a sweep material made of an array of materials.
-        
-        If a material needs to have a dataset (thermal modifier), then a 
-        dataset is created. Material properties are loaded from the XML file 
+
+        If a material needs to have a dataset (thermal modifier), then a
+        dataset is created. Material properties are loaded from the XML file
         database ``amat.xml``.
-        
+
         Parameters
         ----------
         swargs : list
@@ -274,13 +272,13 @@ class Materials(object):
 
         Examples
         --------
-        
+
         >>> from pyaedt import Hfss
         >>> hfss = Hfss()
         >>> hfss.materials.add_material("MyMaterial")
         >>> hfss.materials.add_material("MyMaterial2")
         >>> hfss.materials.add_material_sweep(["MyMaterial", "MyMaterial2"], "Sweep_copper")
-        
+
         """
         matsweep = []
         matname = matname.lower()
@@ -328,7 +326,7 @@ class Materials(object):
         >>> hfss = Hfss()
         >>> hfss.materials.add_material("MyMaterial")
         >>> hfss.materials.duplicate_material("MyMaterial", "MyMaterial2")
-        
+
         """
         if material.lower() not in list(self.material_keys.keys()):
             self._messenger.add_error_message("Material {} is not present".format(material))
@@ -360,7 +358,7 @@ class Materials(object):
         >>> hfss = Hfss()
         >>> hfss.materials.add_surface_material("MyMaterial")
         >>> hfss.materials.duplicate_surface_material("MyMaterial", "MyMaterial2")
-        
+
         """
         if not material.lower() in list(self.surface_material_keys.keys()):
             self._messenger.add_error_message("Material {} is not present".format(material))
@@ -412,7 +410,7 @@ class Materials(object):
         -------
         list
             List of conductors in the material database.
-            
+
         """
         data = []
         for key, mat in self.material_keys.items():
@@ -428,7 +426,7 @@ class Materials(object):
         -------
         list
             List of dielctrics in the material database.
-            
+
         """
         data = []
         for key, mat in self.material_keys.items():
@@ -449,7 +447,7 @@ class Materials(object):
     def _aedmattolibrary(self, matname):
         matname = matname.lower()
         props = {}
-        arg2dict(list(self.omaterial_manager.GetData(matname)), props)
+        arg2dict(list(retry_ntimes(10, self.omaterial_manager.GetData, matname)), props)
         values_view = props.values()
         value_iterator = iter(values_view)
         first_value = next(value_iterator)
@@ -460,7 +458,7 @@ class Materials(object):
 
     def export_materials_to_file(self, full_json_path):
         """Export all materials to a JSON file.
-        
+
         Parameters
         ----------
         full_json_path : str
@@ -470,7 +468,7 @@ class Materials(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         def find_datasets(d, out_list):
             for k, v in d.items():
@@ -517,7 +515,7 @@ class Materials(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         with open(full_json_path) as json_file:
             data = json.load(json_file)
