@@ -5,7 +5,7 @@ This module contains the `Mesh` class.
 from __future__ import absolute_import
 from ..generic.general_methods import aedt_exception_handler, generate_unique_name, MethodNotSupportedError
 
-from ..application.DataHandlers import dict2arg
+from ..generic.DataHandlers import dict2arg
 from collections import OrderedDict
 
 meshers = {"HFSS": "MeshSetup",
@@ -18,18 +18,19 @@ meshers = {"HFSS": "MeshSetup",
 
 class MeshOperation(object):
     """MeshOperation class.
-    
+
     Parameters
     ----------
     parent :
-    
+
     name:
-    
+
     props :
-    
+
     meshoptpe :
-    
+
     """
+
     def __init__(self, parent, name, props, meshoptype):
         self._parent = parent
         self.name = name
@@ -47,11 +48,11 @@ class MeshOperation(object):
     @aedt_exception_handler
     def create(self):
         """Create a mesh.
-        
+
         Returns
         -------
         type
-        
+
         """
         if self.type == "SurfApproxBased":
             self._parent.omeshmodule.AssignTrueSurfOp(self._get_args())
@@ -80,12 +81,12 @@ class MeshOperation(object):
     @aedt_exception_handler
     def update(self):
         """Update the mesh.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         if self.type == "SurfApproxBased":
             self._parent.omeshmodule.EditTrueSurfOp(self.name, self._get_args())
@@ -114,12 +115,12 @@ class MeshOperation(object):
     @aedt_exception_handler
     def delete(self):
         """Delete the mesh.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self._parent.omeshmodule.DeleteOp([self.name])
         for el in self._parent.meshoperations:
@@ -129,14 +130,14 @@ class MeshOperation(object):
 
 
 class Mesh(object):
-    """Mesh class.   
-    
+    """Mesh class.
+
     This class manages AEDT mesh functions.
-    
+
     Parameters
     ----------
     parent :
-    
+
     """
 
     def __init__(self, parent):
@@ -208,7 +209,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-            
+
         """
         names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
@@ -252,7 +253,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-            
+
         """
         names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
@@ -298,7 +299,7 @@ class Mesh(object):
         names : list
             List of objects to defeature.
         defeature_length : float, optional
-            Defeaturing length in millimeters. The default is ``None``, in which case 
+            Defeaturing length in millimeters. The default is ``None``, in which case
             automatic defeaturing is used.
         meshop_name : str, optional
             Name of the mesh operation. The default is ``None``.
@@ -307,7 +308,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-        
+
         """
         names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
@@ -342,7 +343,7 @@ class Mesh(object):
         level : int, optional
             Level of the surface mesh. Options are ``1`` through ``10``. The default is ``5.``
         method : str, optional
-            Meshing method. Options are ``"Auto"``, ``"AnsoftTAU"``, and ``"AnsoftClassic"`` 
+            Meshing method. Options are ``"Auto"``, ``"AnsoftTAU"``, and ``"AnsoftClassic"``
             The default is ``"Auto"``.
         usedynamicsurface : bool, optional
             Whether to use a dynamic surface. The default is ``True``.
@@ -353,11 +354,11 @@ class Mesh(object):
         usefallback : bool, optional
             Whether to retain as a fallback. The default is ``True``.
         usephi : bool, optional
-            Whether to use the Phi mesher for layered geometry. 
+            Whether to use the Phi mesher for layered geometry.
             The default is ``True``.
         automodelresolution : bool, optional
             Whether to automatically calculate the resolution length
-            based on each object's effective thickness. The default is ``True``.  
+            based on each object's effective thickness. The default is ``True``.
         modelresolutionlength : float, optional
              Resolution thickness with units if ``automodelresolution=False``.
              The default ``"0.0001mm"``.
@@ -366,7 +367,7 @@ class Mesh(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         if self._parent.design_type == "2D Extractor" or self._parent.design_type == "Maxwell 2D":
             mesh_methods = ["Auto", "AnsoftClassic"]
@@ -410,7 +411,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-        
+
         """
         meshop_name = generate_unique_name("SurfaceRepPriority")
         props = OrderedDict({"Type": "SurfaceRepPriority", "Objects": object_lists, "SurfaceRepPriority": surfpriority})
@@ -419,7 +420,6 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-
     @aedt_exception_handler
     def generate_mesh(self, name):
         """Generate the mesh for a design.
@@ -433,14 +433,13 @@ class Mesh(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         return self.odesign.GenerateMesh(name) == 0
 
-
     @aedt_exception_handler
     def delete_mesh_operations(self, mesh_type=None):
-        """Remove mesh operations from a design. 
+        """Remove mesh operations from a design.
 
         Parameters
         ----------
@@ -452,7 +451,7 @@ class Mesh(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         # Type "Area Based" not included since the delete command causes
         # desktop to crash
@@ -474,7 +473,6 @@ class Mesh(object):
 
         return True
 
-
     @aedt_exception_handler
     def assign_length_mesh(self, names, isinside=True, maxlength=1, maxel=1000, meshop_name=None):
         """Assign a length for the model resolution.
@@ -486,7 +484,7 @@ class Mesh(object):
         isinside : bool, optional
             Whether the length mesh is inside the selection. The default is ``True``.
         maxlength : int, optional
-            Maximum element length. The default is ``1``. When ``None``, 
+            Maximum element length. The default is ``1``. When ``None``,
             this parameter is disabled.
         maxel : int, optional
             Maximum number of elements. The default is ``1000``. When ``None``, this parameter
@@ -543,7 +541,6 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-
     @aedt_exception_handler
     def assign_skin_depth(self, names, skindepth, maxelements=None, triangulation_max_length="0.1mm", numlayers="2",
                           meshop_name=None):
@@ -554,13 +551,11 @@ class Mesh(object):
         names : list
            List of the object names or face IDs.
         skindepth : bool
-            Whether the length mesh is inside the selection. The default is ``True``. 
+            Whether the length mesh is inside the selection. The default is ``True``.
         maxelements : int, optional
-            Maximum number of elements. The default is ``None``, which means
-            this parameter is disabled.
+            Maximum number of elements. The default is ``None``, which means this parameter is disabled.
         triangulation_max_length : str, optional
-            Maximum surface triangulation length with units. The default 
-            is ``"0.1mm"`.
+            Maximum surface triangulation length with units. The default is ``"0.1mm"``.
         numlayers : str, optional
             Number of layers. The default is ``"2"``.
         meshop_name : str, optional
@@ -570,7 +565,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-            
+
         """
         names = self.modeler.convert_to_selections(names, True)
 
@@ -609,7 +604,6 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-
     @aedt_exception_handler
     def assign_curvilinear_elements(self, names, enable=True, meshop_name=None):
         """Assign curvilinear elements.
@@ -620,14 +614,14 @@ class Mesh(object):
             List of objects or faces.
         enable : bool, optional
             Whether to apply curvilinear elements. The default is ``True``.
-         meshop_name : str, optional
+        meshop_name : str, optional
             Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-            
+
         """
         names = self.modeler.convert_to_selections(names, True)
 
@@ -656,7 +650,6 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-
     @aedt_exception_handler
     def assign_curvature_extraction(self, names, disable_for_faceted_surf=True, meshop_name=None):
         """Assign curvature extraction.
@@ -666,7 +659,7 @@ class Mesh(object):
         names : list
             List of objects or faces.
         disable_for_faceted_surf : bool, optional
-            Whether curvature extraction is enabled for faceted surfaces. 
+            Whether curvature extraction is enabled for faceted surfaces.
             The default is ``True``.
         meshop_name : str, optional
             Name of the mesh operation. The default is ``None``.
@@ -675,7 +668,7 @@ class Mesh(object):
         -------
        :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-        
+
         """
         names = self.modeler.convert_to_selections(names, True)
 
@@ -704,7 +697,6 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-
     @aedt_exception_handler
     def assign_rotational_layer(self, names, num_layers=3, total_thickness="1mm", meshop_name=None):
         """Assign a rotational layer mesh.
@@ -725,7 +717,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-            
+
         """
         names = self.modeler.convert_to_selections(names, True)
 
@@ -746,7 +738,6 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-
     @aedt_exception_handler
     def assign_edge_cut(self, names, layer_thickness="1mm", meshop_name=None):
         """Assign an edge cut layer mesh.
@@ -764,7 +755,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-            
+
         """
         names = self.modeler.convert_to_selections(names, True)
 
@@ -784,7 +775,6 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-
     @aedt_exception_handler
     def assign_density_control(self, names, refine_inside=True, maxelementlength=None, layerNum=None, meshop_name=None):
         """Assign density control.
@@ -808,7 +798,7 @@ class Mesh(object):
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
-            
+
         """
         names = self.modeler.convert_to_selections(names, True)
 
