@@ -6,6 +6,7 @@ from .Mesh import meshers, MeshOperation
 
 class IcepakMesh(object):
     """Manages Icepak meshes."""
+
     def __init__(self, parent):
         self._parent = parent
         self.id = 0
@@ -19,6 +20,7 @@ class IcepakMesh(object):
     class MeshRegion(object):
         """Manages Icepak mesh region settings.
         """
+
         def __init__(self, meshmodule, dimension, units):
             self.name = "Settings"
             self.meshmodule = meshmodule
@@ -44,6 +46,7 @@ class IcepakMesh(object):
             self.MinGapY = "1"
             self.MinGapZ = "1"
             self.Objects = ["Region"]
+            self.SubModels = False
             self.Enable = True
 
         @aedt_exception_handler
@@ -64,13 +67,19 @@ class IcepakMesh(object):
             arg = ["MeshMethod:=", "MesherHD", "UserSpecifiedSettings:=", self.UserSpecifiedSettings, "ComputeGap:=",
                    self.ComputeGap, "MeshRegionResolution:=", self.Level, "MinGapX:=",
                    self._dim_arg(self.MinGapX), "MinGapY:=",
-                   self._dim_arg(self.MinGapY) , "MinGapZ:=", self._dim_arg(self.MinGapZ), "Objects:=",
-                   self.Objects]
+                   self._dim_arg(self.MinGapY) , "MinGapZ:=", self._dim_arg(self.MinGapZ)]
+            if self.SubModels:
+                arg.append("SubModels:=")
+                arg.append(self.SubModels)
+            else:
+                arg.append("Objects:=")
+                arg.append(self.Objects)
             return arg
 
         @property
         def manualsettings(self):
             """Manual mesh settings."""
+
             arg = ["MeshMethod:=", "MesherHD", "UserSpecifiedSettings:=", self.UserSpecifiedSettings, "ComputeGap:=",
                    self.ComputeGap, "MaxElementSizeX:=", self._dim_arg(self.MaxElementSizeX),
                    "MaxElementSizeY:=",
@@ -83,7 +92,13 @@ class IcepakMesh(object):
                    "UniformMeshParametersType:=", self.UniformMeshParametersType, "StairStepMeshing:=",
                    self.StairStepMeshing, "2DMLMType:=", self.DMLMType, "MinGapX:=",
                    self._dim_arg(self.MinGapX) , "MinGapY:=", self._dim_arg(self.MinGapY),
-                   "MinGapZ:=", self._dim_arg(self.MinGapZ), "Objects:=", self.Objects]
+                   "MinGapZ:=", self._dim_arg(self.MinGapZ)]
+            if self.SubModels:
+                arg.append("SubModels:=")
+                arg.append(self.SubModels)
+            else:
+                arg.append("Objects:=")
+                arg.append(self.Objects)
             return arg
 
         @property
@@ -94,7 +109,7 @@ class IcepakMesh(object):
         @aedt_exception_handler
         def update(self):
             """Update mesh region settings with the settings in the object variable.
-            
+
             Returns
             -------
             bool
@@ -117,7 +132,7 @@ class IcepakMesh(object):
         @aedt_exception_handler
         def create(self):
             """Create a new mesh region.
-            
+
             Returns
             -------
             bool
@@ -129,7 +144,6 @@ class IcepakMesh(object):
                 args += self.manualsettings
             else:
                 args += self.autosettings
-
             self.meshmodule.AssignMeshRegion(args)
             return True
 
@@ -148,23 +162,23 @@ class IcepakMesh(object):
     @property
     def odesign(self):
         """Design.
-        
+
         Returns
         -------
         type
             Design object.
-        
+
         """
         return self._parent._odesign
 
     @property
     def modeler(self):
         """Modeler.
-        
+
         Returns
         -------
         :class:`pyaedt.modules.Modeler`
-        
+
         """
         return self._parent._modeler
 
@@ -206,7 +220,7 @@ class IcepakMesh(object):
         Parameters
         ----------
         mesh_order : dict
-            Dictionary where the key is the object name and the value is 
+            Dictionary where the key is the object name and the value is
             the mesh level.
         meshop_name :  str, optional
             Name of the mesh operation. The default is ``None``.
@@ -241,7 +255,7 @@ class IcepakMesh(object):
         Parameters
         ----------
         accuracy : int, optional
-            Type of the mesh. Options are ``1``, ``2``, and ``3``, which represent 
+            Type of the mesh. Options are ``1``, ``2``, and ``3``, which represent
             respectively a coarse, standard, or very accurate mesh. The default is ``2``.
 
         Returns
@@ -274,8 +288,8 @@ class IcepakMesh(object):
         Parameters
         ----------
         accuracy2 : int
-            Type of the mesh. Options are ``1``, ``2``, and ``3``, which represent respectively 
-            a coarse, standard, or very accurate mesh. 
+            Type of the mesh. Options are ``1``, ``2``, and ``3``, which represent respectively
+            a coarse, standard, or very accurate mesh.
         stairStep : bool, optional
             Whether to enable a stair step. The default is ``True``.
 
@@ -283,7 +297,7 @@ class IcepakMesh(object):
         -------
          bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         xsize = self.boundingdimension[0] / (10 * accuracy2 * accuracy2)
         ysize = self.boundingdimension[1] / (10 * accuracy2 * accuracy2)
@@ -347,24 +361,26 @@ class IcepakMesh(object):
         return True
 
     @aedt_exception_handler
-    def assign_mesh_region(self, objectlist=[], level=5, name=None):
+    def assign_mesh_region(self, objectlist=[], level=5, is_submodel=False, name=None):
         """Assign a predefined surface mesh level to an object.
 
         Parameters
         ----------
         objectlist : list, optional
-            List of objects to apply the mesh region to. The default 
+            List of objects to apply the mesh region to. The default
             is ``[]``.
         level : int, optional
             Level of the surface mesh. Options are ``1`` through ``5``. The default
             is ``5``.
+        is_submodel : bool
+            Define if the object list is made by component models
         name : str, optional
             Name of the mesh region. The default is ``"MeshRegion1"``.
 
         Returns
         -------
         :class:`pyaedt.modules.MeshIcepak.IcepakMesh.MeshRegion`
-        
+
         """
         if not name:
             name = generate_unique_name("MeshRegion")
@@ -373,12 +389,17 @@ class IcepakMesh(object):
         meshregion.Level = level
         meshregion.name = name
         if not objectlist:
-            objectlist = self.modeler.primitives.object_names
-        all_objs = self.modeler.primitives.object_names
+            objectlist = [i for i in self.modeler.primitives.object_names]
+        if is_submodel:
+            meshregion.SubModels = objectlist
+        else:
+            meshregion.Objects = objectlist
+        all_objs = [i for i in self.modeler.primitives.object_names]
         meshregion.create()
         objectlist2 = self.modeler.primitives.object_names
         added_obj = [i for i in objectlist2 if i not in all_objs]
         meshregion.Objects = added_obj
+        meshregion.SubModels = None
         self.meshregions.append(meshregion)
         return meshregion
 
@@ -406,7 +427,7 @@ class IcepakMesh(object):
         Parameters
         ----------
         mesh_level : int
-            Level of mesh to assign. Options are ``1`` through ``5``.   
+            Level of mesh to assign. Options are ``1`` through ``5``.
         groupName : str
             Name of the group.
         localMeshParamEn : bool, optional
@@ -419,7 +440,7 @@ class IcepakMesh(object):
         Returns
         -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
-       
+
         """
         if meshop_name:
             for el in self.meshoperations:
