@@ -1,5 +1,5 @@
-from ..generic.general_methods import aedt_exception_handler, generate_unique_name
-from ..application.DataHandlers import dict2arg
+from ..generic.general_methods import aedt_exception_handler
+from ..generic.DataHandlers import dict2arg
 from collections import OrderedDict
 
 meshlink = [("ImportMesh", False)]
@@ -613,7 +613,7 @@ def HFSS3DLayout_AdaptiveFrequencyData(freq):
     ----------
     freq : float
         Adaptive frequency value.
-        
+
 
     Returns
     -------
@@ -738,20 +738,20 @@ TR = []
 
 class SweepHFSS(object):
     """Initializes, creates, and updates sweeps in HFSS.
-    
+
     Parameters
     ----------
     oanalysis :
-    
+
     setupname : str
         Name of the setup.
     sweeptype : str, optional
-        Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, 
+        Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``,
         and ``"Discrete"``. The default is ``"Interpolating"``.
     props : dict, optional
         Dictionary of the properties. The default is ``None``, in which case
         the default properties are retrieved.
-   
+
     """
 
     def __init__(self, oanalysis, setupname, sweepname, sweeptype="Interpolating", props=None):
@@ -801,7 +801,7 @@ class SweepHFSS(object):
         Parameters
         ----------
         rangetype : str
-            Type of the subrange. Options are ``"LinearCount"``, 
+            Type of the subrange. Options are ``"LinearCount"``,
             ``"LinearStep"``, and ``"LogScale"``.
         start : float
             Starting frequency.
@@ -814,7 +814,7 @@ class SweepHFSS(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         range = {}
         range["RangeType"] = rangetype
@@ -834,12 +834,12 @@ class SweepHFSS(object):
     @aedt_exception_handler
     def create(self):
         """Create a sweep.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         self.oanalysis.InsertFrequencySweep(self.setupname, self._get_args())
         return True
@@ -847,12 +847,12 @@ class SweepHFSS(object):
     @aedt_exception_handler
     def update(self):
         """Update a sweep.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         self.oanalysis.EditFrequencySweep(self.setupname, self.name, self._get_args())
         return True
@@ -886,19 +886,20 @@ class SweepHFSS3DLayout(object):
     Parameters
     ----------
     oanaysis :
-    
+
     setupname : str
         Name of the setup.
     sweepname : str
         Name of the sweep.
     sweeptype : str, optional
-        Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, 
+        Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``,
         and ``"Discrete"``. The default is ``"Interpolating"``.
     props : dict, optional
         Dictionary of the properties. The default is ``None``, in which
         case the default properties are retrieved.
-    
+
     """
+
     def __init__(self, oanalysis, setupname, sweepname, sweeptype="Interpolating", props=None):
         self.oanalysis = oanalysis
         self.props = {}
@@ -918,7 +919,7 @@ class SweepHFSS3DLayout(object):
             if sweeptype == "Interpolating":
                 self.props["FastSweep"] = True
             else:
-                self.props["FastSweep"] = True
+                self.props["FastSweep"] = False
 
             self.props["SaveSingleField"] = False
             self.props["ZoSelected"] = False
@@ -942,7 +943,6 @@ class SweepHFSS3DLayout(object):
             self.props["AllOffDiagEntries"] = False
             self.props["MagMinThreshold"] = 0.01
 
-
     @aedt_exception_handler
     def add_subrange(self, rangetype, start, end, count):
         """Add a subrange to the sweep.
@@ -950,8 +950,8 @@ class SweepHFSS3DLayout(object):
         Parameters
         ----------
         rangetype : str
-            Type of the subrange. Options are ``"LinearCount"``, 
-           ``"LinearStep"``, and ``"LogScale"``.      
+            Type of the subrange. Options are ``"LinearCount"``,
+            ``"LinearStep"``, and ``"LogScale"``.
         start : float
             Starting frequency.
         end : float
@@ -982,8 +982,8 @@ class SweepHFSS3DLayout(object):
         ----------
         rangetype : str
             rangetype : str
-            Type of the subrange. Options are ``"LinearCount"``, 
-            ``"LinearStep"``, and ``"LogScale"``.   
+            Type of the subrange. Options are ``"LinearCount"``,
+            ``"LinearStep"``, and ``"LogScale"``.
         start : float
             Starting frequency.
         end : float
@@ -995,7 +995,7 @@ class SweepHFSS3DLayout(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         range = ""
         if rangetype == "LinearCount":
@@ -1015,7 +1015,7 @@ class SweepHFSS3DLayout(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         self.oanalysis.AddSweep(self.setupname, self._get_args())
         return True
@@ -1028,7 +1028,7 @@ class SweepHFSS3DLayout(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         self.oanalysis.EditSweep(self.setupname, self.name, self._get_args())
         return True
@@ -1062,19 +1062,20 @@ class SweepQ3D(object):
     Parameters
     ----------
     oanaysis :
-    
+
     setupname :str
         Name of the setup.
     sweepname: str
         Name of the sweep.
     sweeptype : str, optional
-        Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, 
+        Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``,
         and ``"Discrete"``. The default is ``"Interpolating"``.
     props : dict
         Dictionary of the properties.  The default is ``None``, in which case
         the default properties are retrieved.
-        
+
     """
+
     def __init__(self, oanalysis, setupname, sweepname, sweeptype="Interpolating", props=None):
         self.oanalysis = oanalysis
         self.setupname = setupname
@@ -1104,8 +1105,8 @@ class SweepQ3D(object):
         Parameters
         ----------
         type : str
-            Type of the subrange. Options are ``"LinearCount"``, 
-           ``"LinearStep"``, and ``"LogScale"``.   
+            Type of the subrange. Options are ``"LinearCount"``,
+            ``"LinearStep"``, and ``"LogScale"``.
         start : float
             Starting frequency.
         end : float
@@ -1117,7 +1118,7 @@ class SweepQ3D(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         range = {}
         range["RangeType"] = type
@@ -1136,12 +1137,12 @@ class SweepQ3D(object):
     @aedt_exception_handler
     def create(self):
         """Create a sweep.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self.oanalysis.InsertSweep(self.setupname, self._get_args())
         return True
@@ -1149,12 +1150,12 @@ class SweepQ3D(object):
     @aedt_exception_handler
     def update(self):
         """Update the sweep.
-        
+
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-        
+
         """
         self.oanalysis.EditSweep(self.setupname, self.name, self._get_args())
 
