@@ -13,24 +13,24 @@ import os.path
 from ..generic.general_methods import aedt_exception_handler, generate_unique_name
 
 from .SetupTemplates import SweepHFSS, SweepQ3D, SetupKeys, SweepHFSS3DLayout
-from ..application.DataHandlers import tuple2dict, dict2arg
+from ..generic.DataHandlers import tuple2dict, dict2arg
 
 
 class Setup(object):
     """Initializes, creates, and updates a 3D setup.
-    
+
     Parameters
     ----------
     parent: str
         Inherited parent object.
-    solutiontype: 
+    solutiontype:
         Type of the setup.
     setupname: str, optional
         Name of the setup. The default is ``"MySetupAuto"``.
     isnewsetup: bool, optional
         Whether to create the setup from a template. The default is ``True``.
         If ``False``, access is to the existing setup.
-     
+
     """
 
     @property
@@ -51,7 +51,7 @@ class Setup(object):
         return "SetupName " + self.name + " with " + str(len(self.sweeps)) + " Sweeps"
 
     def __init__(self, parent, solutiontype, setupname="MySetupAuto", isnewsetup=True):
-        
+
         self._parent = None
         self.parent = parent
         if isinstance(solutiontype, int):
@@ -94,7 +94,7 @@ class Setup(object):
     @aedt_exception_handler
     def create(self):
         """Add a new setup based on class settings in AEDT.
-              
+
         Returns
         -------
         dict
@@ -139,18 +139,18 @@ class Setup(object):
         Parameters
         ----------
         expressions_list : list
-            List of formulas to retrieve. 
+            List of formulas to retrieve.
         report_type_list : list
-            List of report types for the expressions. 
+            List of report types for the expressions.
         intrinsics_list : list
-            List of intrinsic expressions for the expressions. 
+            List of intrinsic expressions for the expressions.
         isconvergence_list : list
-            List of Boolean values indicating whether the expressions are in 
+            List of Boolean values indicating whether the expressions are in
             the convergence criteria.
         isrelativeconvergence : bool
-            
+
         conv_criteria:
-        
+
         Returns
         -------
         list
@@ -228,7 +228,7 @@ class Setup(object):
         Parameters
         ----------
         expressions : str or list
-            One or more formulas to add to the expression cache. 
+            One or more formulas to add to the expression cache.
         report_type : str or list, optional
             Type of the report for the expression. The default is ``Fields``. If a list of expressions
             is supplied, supply a corresponding list of report types.
@@ -243,7 +243,7 @@ class Setup(object):
             The default is ``True``.
         conv_criteria :
             The default is ``1``.
-                
+
         Returns
         -------
         bool
@@ -293,7 +293,7 @@ class Setup(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         if not setup_name:
             setup_name = self.name
@@ -320,7 +320,7 @@ class Setup(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         if not setup_name:
             setup_name = self.name
@@ -363,11 +363,11 @@ class Setup(object):
 
     @aedt_exception_handler
     def add_mesh_link(self, design_name, solution_name, parameters_dict, project_name="This Project*"):
-        """Add a mesh link to another design. 
+        """Add a mesh link to another design.
 
         Parameters
         ----------
-        design_name : str, 
+        design_name : str
             Name of the design.
         solution_name : str
             Name of the solution in the format ``"setupname : solutionname"``.
@@ -375,11 +375,11 @@ class Setup(object):
             nominal adaptive or :attr:`appname.nominal_sweep` to get the
             nominal sweep.
         parameters_dict : dict
-            Dictionary of the parameters. Optionally use 
+            Dictionary of the parameters. Optionally use
             :attr:`appname.available_variations.nominal_w_values_dict`
             to get the nominal values.
         project_name : str, optional
-            Name of the project with the design. The default is ``"This Project*"``. 
+            Name of the project with the design. The default is ``"This Project*"``.
             However, you can supply the full path and name to another project.
 
         Returns
@@ -409,18 +409,18 @@ class Setup(object):
 
 class SetupCircuit(object):
     """Initializes, creates, and updates a circuit setup.
-    
+
     Parameters
     ----------
     parent: str
         Inherited parent object.
-    solutiontype: 
+    solutiontype:
         Type of the setup.
     setupname: str, optional
         Name of the setup. The default is ``"MySetupAuto"``.
     isnewsetup: bool, optional
       Whether to create the setup from a template. The default is ``True.``
-      If ``False``, access is to the existing setup.     
+      If ``False``, access is to the existing setup.
 
     """
     @property
@@ -501,7 +501,7 @@ class SetupCircuit(object):
     @aedt_exception_handler
     def create(self):
         """Add a new setup based on class settings in AEDT.
-        
+
         Returns
         -------
         dict
@@ -522,9 +522,9 @@ class SetupCircuit(object):
         ----------
         soltype : str
             Type of the solution.
-            
+
         arg :
-            
+
         newsetup : bool, optional
             Whether this is a new setup. The default is ``True``.
 
@@ -599,23 +599,23 @@ class SetupCircuit(object):
         Parameters
         ----------
         expressions_list : list
-            List of formulas to retrieve. 
+            List of formulas to retrieve.
         report_type_list : list
-            List of report types for the expressions. 
+            List of report types for the expressions.
         intrinsics_list : list
             List of intrinsic functions for the expressions.
         isconvergence_list : list
-            List of Boolean values indicating whether the expressions are in 
+            List of Boolean values indicating whether the expressions are in
             the convergence criteria.
-        isrelativeconvergence : 
-            
+        isrelativeconvergence :
+
         conv_criteria:
-        
+
         Returns
         -------
         list
             List of the data.
-        
+
         """
 
         if isrelativeconvergence:
@@ -689,7 +689,7 @@ class SetupCircuit(object):
         Parameters
         ----------
         expressions : str or list
-            One or more formulas to add to the expression cache. 
+            One or more formulas to add to the expression cache.
         report_type : str or list, optional
             Type of the report for the expression. The default is ``"Fields"``. If a list of expressions
             is supplied, a corresponding list of report types must be supplied.
@@ -697,14 +697,14 @@ class SetupCircuit(object):
             Intrinsic functions for the expressions. The default is ``""``. If a list of expressions
             is supplied, a corresponding list of intrinsic expressesions must be supplied.
         isconvergence : bool, str, or list, optional
-            Whether the expression is in the convergence criteria. The  default is ``True``.  
+            Whether the expression is in the convergence criteria. The  default is ``True``.
             If a list of expressions is supplied, a corresponding list of Boolean values must be
             supplied.
         isrelativeconvergence : bool, optional
             The default is ``True``.
         conv_criteria
             The default is ``1``.
-                
+
         Returns
         -------
         bool
@@ -754,7 +754,7 @@ class SetupCircuit(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         if not setup_name:
             setup_name = self.name
@@ -774,7 +774,7 @@ class SetupCircuit(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-            
+
         """
         if not setup_name:
             setup_name = self.name
@@ -784,25 +784,25 @@ class SetupCircuit(object):
 
 class Setup3DLayout(object):
     """Initializes, creates, and updates a 3D Layout setup.
-    
+
     Parameters
     ----------
     parent: str
         Inherited parent object.
-    solutiontype: 
+    solutiontype:
         Type of the setup.
     setupname: str, optional
         Name of the setup. The default is ``"MySetupAuto"``.
     isnewsetup: bool, optional
         Whether to create the setup from a template. The default is ``True.``
         If ``False``, access is to the existing setup.
-    
+
     """
 
     @property
     def omodule(self):
         """Analysis module.
-      
+
         Returns
         -------
         type
@@ -847,13 +847,13 @@ class Setup3DLayout(object):
     @property
     def setup_type(self):
         """Setup type.
-        
+
         Returns
         -------
         type
             Setup type.
         """
-        
+
         if 'SolveSetupType' in self.props:
             return self.props['SolveSetupType']
         else:
@@ -862,7 +862,7 @@ class Setup3DLayout(object):
     @aedt_exception_handler
     def create(self):
         """Add a new setup based on class settings in AEDT.
-        
+
         Returns
         -------
         bool
@@ -955,7 +955,6 @@ class Setup3DLayout(object):
         self.omodule.ExportToHfss(self.name, file_fullname)
         return True
 
-
     @aedt_exception_handler
     def add_sweep(self, sweepname=None, sweeptype="Interpolating"):
         """Add a frequency sweep.
@@ -965,7 +964,7 @@ class Setup3DLayout(object):
         sweepname : str, optional
             Name of the sweep. The default is ``None``.
         sweeptype : str, optional
-            Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, and 
+            Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, and
             ``"Discrete"``. The default is ``"Interpolating"``.
 
         Returns
